@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,8 +31,10 @@ class CremaDTest(testing.DatasetBuilderTestCase):
       'summary_table':
           'summary_table.csv',
       'all_files': [
-          '1000_AA_HAP_XX.wav', '1001_AA_HAP_XX.wav',
-          '1002_AA_ANG_XX.wav', '1003_AA_FEA_XX.wav',
+          '1000_AA_HAP_XX.wav',
+          '1001_AA_HAP_XX.wav',
+          '1002_AA_ANG_XX.wav',
+          '1003_AA_FEA_XX.wav',
       ]
   }
 
