@@ -73,8 +73,7 @@ class Libritts(tfds.core.BeamBasedBuilder):
         builder=self,
         description=_DESCRIPTION,
         features=tfds.features.FeaturesDict({
-            "speech": tfds.features.Audio(
-                file_format="wav", sample_rate=24000),
+            "speech": tfds.features.Audio(file_format="wav", sample_rate=24000),
             "text_original": tfds.features.Text(),
             "text_normalized": tfds.features.Text(),
             "speaker_id": tf.int64,
