@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,10 +18,13 @@
 # needs to happen before anything else, since the imports below will try to
 # import tensorflow, too.
 from tensorflow_datasets.core import tf_compat
+
 tf_compat.ensure_tf_install()
 
 # pylint:disable=g-import-not-at-top
 
+from tensorflow_datasets.core import community  # pylint: disable=g-bad-import-order
+
 from tensorflow_datasets.core.constants import add_data_dir
 
 from tensorflow_datasets.core.dataset_builder import BeamBasedBuilder
@@ -38,6 +41,8 @@ from tensorflow_datasets.core.lazy_imports_lib import lazy_imports
 
 from tensorflow_datasets.core.read_only_builder import builder_from_directory
 
+from tensorflow_datasets.core.registered import DatasetNotFoundError
+
 from tensorflow_datasets.core.split_builder import SplitGeneratorLegacy as SplitGenerator
 
 from tensorflow_datasets.core.splits import Split
@@ -51,28 +56,36 @@ from tensorflow_datasets.core.utils import Experiment
 from tensorflow_datasets.core.utils import gcs_path
 from tensorflow_datasets.core.utils import tfds_path
 from tensorflow_datasets.core.utils import Version
-from tensorflow_datasets.core.utils.benchmark import benchmark
+from tensorflow_datasets.core.utils.benchmark import BenchmarkResult
 from tensorflow_datasets.core.utils.generic_path import as_path
+from tensorflow_datasets.core.utils.type_utils import PathLike
 from tensorflow_datasets.core.utils.type_utils import ReadOnlyPath
 from tensorflow_datasets.core.utils.type_utils import ReadWritePath
 
 
+def benchmark(*args, **kwargs):
+  raise DeprecationWarning(
+      "`tfds.core.benchmark` has been renamed to `tfds.benchmark`")
+
+
 __all__ = [
     "add_data_dir",
     "as_path",
-    "benchmark",
+    "BenchmarkResult",
     "BeamBasedBuilder",
     "BeamMetadataDict",
     "BuilderConfig",
     "builder_from_directory",
     "DatasetBuilder",
     "DatasetInfo",
+    "DatasetNotFoundError",
     "Experiment",
     "GeneratorBasedBuilder",
     "gcs_path",
     "lazy_imports",
     "Metadata",
     "MetadataDict",
+    "PathLike",
     "ReadInstruction",
     "ReadOnlyPath",
     "ReadWritePath",
