@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,9 +18,10 @@
 import abc
 import functools
 import inspect
+import json
 import os
 import sys
-from typing import Any, ClassVar, Dict, Iterable, List, Optional, Union
+from typing import Any, ClassVar, Dict, Iterable, List, Optional, Type, Union
 
 from absl import logging
 import dataclasses
@@ -29,10 +30,14 @@ import tensorflow.compat.v2 as tf
 
 from tensorflow_datasets.core import constants
 from tensorflow_datasets.core import dataset_info
+from tensorflow_datasets.core import decode
 from tensorflow_datasets.core import download
+from tensorflow_datasets.core import file_adapters
+from tensorflow_datasets.core import logging as tfds_logging
 from tensorflow_datasets.core import registered
 from tensorflow_datasets.core import split_builder as split_builder_lib
 from tensorflow_datasets.core import splits as splits_lib
+from tensorflow_datasets.core import tf_compat
 from tensorflow_datasets.core import tfrecords_reader
 from tensorflow_datasets.core import units
 from tensorflow_datasets.core import utils
@@ -43,9 +48,10 @@ from tensorflow_datasets.core.utils import type_utils
 import termcolor
 
 ReadOnlyPath = type_utils.ReadOnlyPath
+ReadWritePath = type_utils.ReadWritePath
+TreeDict = type_utils.TreeDict
 VersionOrStr = Union[utils.Version, str]
 
-
 FORCE_REDOWNLOAD = download.GenerateMode.FORCE_REDOWNLOAD
 REUSE_CACHE_IF_EXISTS = download.GenerateMode.REUSE_CACHE_IF_EXISTS
 REUSE_DATASET_IF_EXISTS = download.GenerateMode.REUSE_DATASET_IF_EXISTS
@@ -81,17 +87,17 @@ class DatasetBuilder(registered.RegisteredDataset):
 
   `DatasetBuilder` has 3 key methods:
 
-    * `tfds.DatasetBuilder.info`: documents the dataset, including feature
+    * `DatasetBuilder.info`: documents the dataset, including feature
       names, types, and shapes, version, splits, citation, etc.
-    * `tfds.DatasetBuilder.download_and_prepare`: downloads the source data
+    * `DatasetBuilder.download_and_prepare`: downloads the source data
       and writes it to disk.
-    * `tfds.DatasetBuilder.as_dataset`: builds an input pipeline using
+    * `DatasetBuilder.as_dataset`: builds an input pipeline using
       `tf.data.Dataset`s.
 
   **Configuration**: Some `DatasetBuilder`s expose multiple variants of the
   dataset by defining a `tfds.core.BuilderConfig` subclass and accepting a
   config object (or name) on construction. Configurable datasets expose a
-  pre-defined set of configurations in `tfds.DatasetBuilder.builder_configs`.
+  pre-defined set of configurations in `DatasetBuilder.builder_configs`.
 
   Typical `DatasetBuilder` usage:
 
@@ -148,24 +154,24 @@ class DatasetBuilder(registered.RegisteredDataset):
     Callers must pass arguments as keyword arguments.
 
     Args:
-      data_dir: directory to read/write data. Defaults to the value of
-        the environment variable TFDS_DATA_DIR, if set, otherwise falls back to
+      data_dir: directory to read/write data. Defaults to the value of the
+        environment variable TFDS_DATA_DIR, if set, otherwise falls back to
         "~/tensorflow_datasets".
       config: `tfds.core.BuilderConfig` or `str` name, optional configuration
         for the dataset that affects the data generated on disk. Different
         `builder_config`s will have their own subdirectories and versions.
       version: Optional version at which to load the dataset. An error is
         raised if specified version cannot be satisfied. Eg: '1.2.3', '1.2.*'.
-        The special value "experimental_latest" will use the highest version,
-        even if not default. This is not recommended unless you know what you
-        are doing, as the version could be broken.
+          The special value "experimental_latest" will use the highest version,
+          even if not default. This is not recommended unless you know what you
+          are doing, as the version could be broken.
     """
     if data_dir:
       data_dir = os.fspath(data_dir)  # Pathlib -> str
 
     # For pickling:
-    self._original_state = dict(data_dir=data_dir, config=config,
-                                version=version)
+    self._original_state = dict(
+        data_dir=data_dir, config=config, version=version)
     # To do the work:
     self._builder_config = self._create_builder_config(config)
     # Extract code version (VERSION or config)
@@ -179,6 +185,7 @@ class DatasetBuilder(registered.RegisteredDataset):
 
   @utils.classproperty
   @classmethod
+  @utils.memoize()
   def code_path(cls) -> ReadOnlyPath:
     """Returns the path to the file where the Dataset class is located.
 
@@ -199,8 +206,13 @@ class DatasetBuilder(registered.RegisteredDataset):
       except TypeError:  # Module is not a package
         pass
       else:
-        modules[-1] += ".py"
-        return path.joinpath(*modules[1:])
+        # For dynamically added modules, `importlib.resources` returns
+        # `pathlib.Path('.')` rather than the real path, so filter those by
+        # checking for `parts`.
+        # Check for `zipfile.Path` (`ResourcePath`) as it does not have `.parts`
+        if isinstance(path, utils.ResourcePath) or path.parts:
+          modules[-1] += ".py"
+          return path.joinpath(*modules[1:])
     # Otherwise, fallback to `pathlib.Path`. For non-zipapp, it should be
     # equivalent to the above return.
     return utils.as_path(inspect.getfile(cls))
@@ -212,21 +224,18 @@ class DatasetBuilder(registered.RegisteredDataset):
     self.__init__(**state)
 
   @utils.memoized_property
-  def canonical_version(self):
-    if self._builder_config:
-      return self._builder_config.version
-    else:
-      return self.VERSION
+  def canonical_version(self) -> utils.Version:
+    return cannonical_version_for_config(self, self._builder_config)
 
   @utils.memoized_property
   def supported_versions(self):
-    if self._builder_config:
+    if self._builder_config and self._builder_config.supported_versions:
       return self._builder_config.supported_versions
     else:
       return self.SUPPORTED_VERSIONS
 
   @utils.memoized_property
-  def versions(self):
+  def versions(self) -> List[utils.Version]:
     """Versions (canonical + availables), in preference order."""
     return [
         utils.Version(v) if isinstance(v, six.string_types) else v
@@ -235,11 +244,8 @@ class DatasetBuilder(registered.RegisteredDataset):
 
   def _pick_version(self, requested_version):
     """Returns utils.Version instance, or raise AssertionError."""
-    if not self._builder_config and not self.VERSION:
-      raise AssertionError(
-          "DatasetBuilder {} does not have a defined version. Please add a "
-          "`VERSION = tfds.core.Version('x.y.z')` to the class.".format(
-              self.name))
+    # Validate that `canonical_version` is correctly defined
+    assert self.canonical_version
 
     if requested_version == "experimental_latest":
       return max(self.versions)
@@ -255,12 +261,19 @@ class DatasetBuilder(registered.RegisteredDataset):
   def version(self):
     return self._version
 
+  @property
+  def release_notes(self) -> Dict[str, str]:
+    if self.builder_config and self.builder_config.release_notes:
+      return self.builder_config.release_notes
+    else:
+      return self.RELEASE_NOTES
+
   @property
   def data_dir(self):
     return self._data_dir
 
   @property
-  def _data_path(self) -> type_utils.ReadWritePath:
+  def data_path(self) -> type_utils.ReadWritePath:
     # Instead, should make `_data_dir` be Path everywhere
     return utils.as_path(self._data_dir)
 
@@ -271,7 +284,17 @@ class DatasetBuilder(registered.RegisteredDataset):
     # Used:
     # * To load the checksums (in url_infos)
     # * To save the checksums (in DownloadManager)
-    return cls.code_path.parent / "checksums.tsv"
+    new_path = cls.code_path.parent / "checksums.tsv"
+    # Checksums of legacy datasets are located in a separate dir.
+    legacy_path = utils.tfds_path() / "url_checksums" / f"{cls.name}.txt"
+    if (
+        # zipfile.Path does not have `.parts`. Additionally, `os.fspath`
+        # will extract the file, so use `str`.
+        "tensorflow_datasets" in str(new_path) and legacy_path.exists() and
+        not new_path.exists()):
+      return legacy_path
+    else:
+      return new_path
 
   @utils.classproperty
   @classmethod
@@ -302,14 +325,19 @@ class DatasetBuilder(registered.RegisteredDataset):
           "Info should not been called before version has been defined. "
           "Otherwise, the created .info may not match the info version from "
           "the restored dataset.")
-    return self._info()
+    info = self._info()
+    if not isinstance(info, dataset_info.DatasetInfo):
+      raise TypeError(
+          "DatasetBuilder._info should returns `tfds.core.DatasetInfo`, not "
+          f" {type(info)}.")
+    return info
 
   def download_and_prepare(self, *, download_dir=None, download_config=None):
     """Downloads and prepares dataset for reading.
 
     Args:
-      download_dir: `str`, directory where downloaded files are stored.
-        Defaults to "~/tensorflow-datasets/downloads".
+      download_dir: `str`, directory where downloaded files are stored. Defaults
+        to "~/tensorflow-datasets/downloads".
       download_config: `tfds.download.DownloadConfig`, further configuration for
         downloading and preparing dataset.
 
@@ -324,16 +352,16 @@ class DatasetBuilder(registered.RegisteredDataset):
       return
 
     if self.version.tfds_version_to_prepare:
-      available_to_prepare = ", ".join(str(v) for v in self.versions
-                                       if not v.tfds_version_to_prepare)
+      available_to_prepare = ", ".join(
+          str(v) for v in self.versions if not v.tfds_version_to_prepare)
       raise AssertionError(
           "The version of the dataset you are trying to use ({}:{}) can only "
           "be generated using TFDS code synced @ {} or earlier. Either sync to "
           "that version of TFDS to first prepare the data or use another "
           "version of the dataset (available for `download_and_prepare`: "
-          "{}).".format(
-              self.name, self.version, self.version.tfds_version_to_prepare,
-              available_to_prepare))
+          "{}).".format(self.name, self.version,
+                        self.version.tfds_version_to_prepare,
+                        available_to_prepare))
 
     # Only `cls.VERSION` or `experimental_latest` versions can be generated.
     # Otherwise, users may accidentally generate an old version using the
@@ -342,21 +370,19 @@ class DatasetBuilder(registered.RegisteredDataset):
         str(v) for v in (self.canonical_version, max(self.versions))
     }
     if str(self.version) not in installable_versions:
-      msg = (
-          "The version of the dataset you are trying to use ({}) is too "
-          "old for this version of TFDS so cannot be generated."
-      ).format(self.info.full_name)
+      msg = ("The version of the dataset you are trying to use ({}) is too "
+             "old for this version of TFDS so cannot be generated.").format(
+                 self.info.full_name)
       if self.version.tfds_version_to_prepare:
         msg += (
             "{} can only be generated using TFDS code synced @ {} or earlier "
             "Either sync to that version of TFDS to first prepare the data or "
-            "use another version of the dataset. "
-        ).format(self.version, self.version.tfds_version_to_prepare)
+            "use another version of the dataset. ").format(
+                self.version, self.version.tfds_version_to_prepare)
       else:
         msg += (
             "Either sync to a previous version of TFDS to first prepare the "
-            "data or use another version of the dataset. "
-        )
+            "data or use another version of the dataset. ")
       msg += "Available for `download_and_prepare`: {}".format(
           list(sorted(installable_versions)))
       raise ValueError(msg)
@@ -378,15 +404,24 @@ class DatasetBuilder(registered.RegisteredDataset):
       raise IOError(
           "Not enough disk space. Needed: {} (download: {}, generated: {})"
           .format(
-              units.size_str(self.info.dataset_size + self.info.download_size),
-              units.size_str(self.info.download_size),
-              units.size_str(self.info.dataset_size),
+              self.info.dataset_size + self.info.download_size,
+              self.info.download_size,
+              self.info.dataset_size,
           ))
     self._log_download_bytes()
 
     dl_manager = self._make_download_manager(
         download_dir=download_dir,
-        download_config=download_config)
+        download_config=download_config,
+    )
+
+    # Maybe save the `builder_cls` metadata common to all builder configs.
+    if self.BUILDER_CONFIGS:
+      _save_default_config_name(
+          # `data_dir/ds_name/config/version/` -> `data_dir/ds_name/`
+          common_dir=self.data_path.parent.parent,
+          default_config_name=self.BUILDER_CONFIGS[0].name,
+      )
 
     # Create a tmp dir and rename to self._data_dir on successful exit.
     with utils.incomplete_dir(self._data_dir) as tmp_data_dir:
@@ -395,56 +430,36 @@ class DatasetBuilder(registered.RegisteredDataset):
       with utils.temporary_assignment(self, "_data_dir", tmp_data_dir):
         if (download_config.try_download_gcs and
             gcs_utils.is_dataset_on_gcs(self.info.full_name)):
-          logging.warning(GCS_HOSTED_MSG, self.name)
+          logging.info(GCS_HOSTED_MSG, self.name)
           gcs_utils.download_gcs_dataset(self.info.full_name, self._data_dir)
           self.info.read_from_directory(self._data_dir)
         else:
-          self._download_and_prepare(
-              dl_manager=dl_manager,
-              download_config=download_config,
-          )
+          # Old version of TF are not os.PathLike compatible
+          with tf_compat.mock_gfile_pathlike():
+            self._download_and_prepare(
+                dl_manager=dl_manager,
+                download_config=download_config,
+            )
 
           # NOTE: If modifying the lines below to put additional information in
           # DatasetInfo, you'll likely also want to update
           # DatasetInfo.read_from_directory to possibly restore these attributes
           # when reading from package data.
-
-          # Skip statistics computation if tfdv isn't present
-          try:
-            import tensorflow_data_validation  # pylint: disable=g-import-not-at-top,import-outside-toplevel,unused-import  # pytype: disable=import-error
-            skip_stats_computation = False
-          except ImportError:
-            skip_stats_computation = True
-
-          splits = list(self.info.splits.values())
-          statistics_already_computed = bool(
-              splits and splits[0].statistics.num_examples)
-          # Update DatasetInfo metadata by computing statistics from the data.
-          if (skip_stats_computation or
-              download_config.compute_stats == download.ComputeStatsMode.SKIP or
-              download_config.compute_stats == download.ComputeStatsMode.AUTO
-              and statistics_already_computed
-             ):
-            logging.info(
-                "Skipping computing stats for mode %s.",
-                download_config.compute_stats)
-          else:  # Mode is forced or stats do not exists yet
-            logging.info("Computing statistics.")
-            self.info.compute_dynamic_properties()
           self.info.download_size = dl_manager.downloaded_size
           # Write DatasetInfo to disk, even if we haven't computed statistics.
           self.info.write_to_directory(self._data_dir)
     self._log_download_done()
 
+  @tfds_logging.as_dataset()
   def as_dataset(
       self,
-      split=None,
+      split: Optional[Union[str, tfrecords_reader.ReadInstruction]] = None,
       *,
-      batch_size=None,
-      shuffle_files=False,
-      decoders=None,
-      read_config=None,
-      as_supervised=False,
+      batch_size: Optional[int] = None,
+      shuffle_files: bool = False,
+      decoders: Optional[TreeDict[decode.Decoder]] = None,
+      read_config: Optional[read_config_lib.ReadConfig] = None,
+      as_supervised: bool = False,
   ):
     # pylint: disable=line-too-long
     """Constructs a `tf.data.Dataset`.
@@ -494,28 +509,26 @@ class DatasetBuilder(registered.RegisteredDataset):
     Args:
       split: Which split of the data to load (e.g. `'train'`, `'test'`,
         `['train', 'test']`, `'train[80%:]'`,...). See our
-        [split API guide](https://www.tensorflow.org/datasets/splits).
-        If `None`, will return all splits in a `Dict[Split, tf.data.Dataset]`.
-      batch_size: `int`, batch size. Note that variable-length features will
-        be 0-padded if `batch_size` is set. Users that want more custom behavior
+        [split API guide](https://www.tensorflow.org/datasets/splits). If
+          `None`, will return all splits in a `Dict[Split, tf.data.Dataset]`.
+      batch_size: `int`, batch size. Note that variable-length features will be
+        0-padded if `batch_size` is set. Users that want more custom behavior
         should use `batch_size=None` and use the `tf.data` API to construct a
-        custom pipeline. If `batch_size == -1`, will return feature
-        dictionaries of the whole dataset with `tf.Tensor`s instead of a
-        `tf.data.Dataset`.
+        custom pipeline. If `batch_size == -1`, will return feature dictionaries
+        of the whole dataset with `tf.Tensor`s instead of a `tf.data.Dataset`.
       shuffle_files: `bool`, whether to shuffle the input files. Defaults to
         `False`.
       decoders: Nested dict of `Decoder` objects which allow to customize the
         decoding. The structure should match the feature structure, but only
-        customized feature keys need to be present. See
-        [the guide](https://github.com/tensorflow/datasets/tree/master/docs/decode.md)
-        for more info.
-      read_config: `tfds.ReadConfig`, Additional options to configure the
-        input pipeline (e.g. seed, num parallel reads,...).
-      as_supervised: `bool`, if `True`, the returned `tf.data.Dataset`
-        will have a 2-tuple structure `(input, label)` according to
-        `builder.info.supervised_keys`. If `False`, the default,
-        the returned `tf.data.Dataset` will have a dictionary with all the
-        features.
+        customized feature keys need to be present. See [the
+          guide](https://github.com/tensorflow/datasets/tree/master/docs/decode.md)
+            for more info.
+      read_config: `tfds.ReadConfig`, Additional options to configure the input
+        pipeline (e.g. seed, num parallel reads,...).
+      as_supervised: `bool`, if `True`, the returned `tf.data.Dataset` will have
+        a 2-tuple structure `(input, label)` according to
+        `builder.info.supervised_keys`. If `False`, the default, the returned
+        `tf.data.Dataset` will have a dictionary with all the features.
 
     Returns:
       `tf.data.Dataset`, or if `split=None`, `dict<key: tfds.Split, value:
@@ -525,14 +538,12 @@ class DatasetBuilder(registered.RegisteredDataset):
       the entire dataset in `tf.Tensor`s instead of a `tf.data.Dataset`.
     """
     # pylint: enable=line-too-long
-    logging.info("Constructing tf.data.Dataset for split %s, from %s",
-                 split, self._data_dir)
     if not tf.io.gfile.exists(self._data_dir):
       raise AssertionError(
           ("Dataset %s: could not find data in %s. Please make sure to call "
            "dataset_builder.download_and_prepare(), or pass download=True to "
-           "tfds.load() before trying to access the tf.data.Dataset object."
-          ) % (self.name, self._data_dir_root))
+           "tfds.load() before trying to access the tf.data.Dataset object.") %
+          (self.name, self._data_dir_root))
 
     # By default, return all splits
     if split is None:
@@ -575,16 +586,12 @@ class DatasetBuilder(registered.RegisteredDataset):
     )
     # Auto-cache small datasets which are small enough to fit in memory.
     if self._should_cache_ds(
-        split=split,
-        shuffle_files=shuffle_files,
-        read_config=read_config
-    ):
+        split=split, shuffle_files=shuffle_files, read_config=read_config):
       ds = ds.cache()
 
     if batch_size:
       # Use padded_batch so that features with unknown shape are supported.
-      ds = ds.padded_batch(
-          batch_size, tf.compat.v1.data.get_output_shapes(ds))
+      ds = ds.padded_batch(batch_size, tf.compat.v1.data.get_output_shapes(ds))
 
     if as_supervised:
       if not self.info.supervised_keys:
@@ -592,8 +599,7 @@ class DatasetBuilder(registered.RegisteredDataset):
             "as_supervised=True but %s does not support a supervised "
             "(input, label) structure." % self.name)
       input_f, target_f = self.info.supervised_keys
-      ds = ds.map(lambda fs: (fs[input_f], fs[target_f]),
-                  num_parallel_calls=tf.data.experimental.AUTOTUNE)
+      ds = ds.map(lambda fs: (fs[input_f], fs[target_f]))
 
     # Add prefetch by default
     if not read_config.skip_prefetch:
@@ -670,8 +676,8 @@ class DatasetBuilder(registered.RegisteredDataset):
     """Return the data directory for the current version.
 
     Args:
-      given_data_dir: `Optional[str]`, root `data_dir` passed as
-        `__init__` argument.
+      given_data_dir: `Optional[str]`, root `data_dir` passed as `__init__`
+        argument.
 
     Returns:
       data_dir_root: `str`, The root dir containing all datasets, downloads,...
@@ -682,8 +688,7 @@ class DatasetBuilder(registered.RegisteredDataset):
     version_dir = self._relative_data_dir(with_version=True)
 
     default_data_dir = constants.get_default_data_dir(
-        given_data_dir=given_data_dir
-    )
+        given_data_dir=given_data_dir)
     all_data_dirs = constants.list_data_dirs(given_data_dir=given_data_dir)
 
     all_versions = set()
@@ -695,16 +700,14 @@ class DatasetBuilder(registered.RegisteredDataset):
       # Check for existance of the requested version
       if self.version in data_dir_versions:
         requested_version_dirs[data_dir_root] = os.path.join(
-            data_dir_root, version_dir
-        )
+            data_dir_root, version_dir)
       all_versions.update(data_dir_versions)
 
     if len(requested_version_dirs) > 1:
       raise ValueError(
           "Dataset was found in more than one directory: {}. Please resolve "
           "the ambiguity by explicitly specifying `data_dir=`."
-          "".format(requested_version_dirs.values())
-      )
+          "".format(requested_version_dirs.values()))
     elif len(requested_version_dirs) == 1:  # The dataset is found once
       return next(iter(requested_version_dirs.items()))
 
@@ -714,18 +717,13 @@ class DatasetBuilder(registered.RegisteredDataset):
       logging.warning(
           "Found a different version of the requested dataset:\n"
           "%s\n"
-          "Using %s instead.",
-          "\n".join(str(v) for v in sorted(all_versions)),
-          data_dir
-      )
+          "Using %s instead.", "\n".join(str(v) for v in sorted(all_versions)),
+          data_dir)
     return default_data_dir, data_dir
 
   def _log_download_done(self):
-    msg = ("Dataset {name} downloaded and prepared to {data_dir}. "
-           "Subsequent calls will reuse this data.").format(
-               name=self.name,
-               data_dir=self._data_dir,
-           )
+    msg = (f"Dataset {self.name} downloaded and prepared to {self._data_dir}. "
+           "Subsequent calls will reuse this data.")
     termcolor.cprint(msg, attrs=["bold"])
 
   def _log_download_bytes(self):
@@ -733,14 +731,13 @@ class DatasetBuilder(registered.RegisteredDataset):
     # information needed to cancel download/preparation if needed.
     # This comes right before the progress bar.
     termcolor.cprint(
-        "Downloading and preparing dataset {} (download: {}, generated: {}, "
-        "total: {}) to {}...".format(
-            self.info.full_name,
-            units.size_str(self.info.download_size),
-            units.size_str(self.info.dataset_size),
-            units.size_str(self.info.download_size + self.info.dataset_size),
-            self._data_dir,
-        ), attrs=["bold"])
+        f"Downloading and preparing dataset {self.info.download_size} "
+        f"(download: {self.info.download_size}, "
+        f"generated: {self.info.dataset_size}, "
+        f"total: {self.info.download_size + self.info.dataset_size}) "
+        f"to {self._data_dir}...",
+        attrs=["bold"],
+    )
 
   @abc.abstractmethod
   @utils.docs.doc_private
@@ -772,8 +769,11 @@ class DatasetBuilder(registered.RegisteredDataset):
     raise NotImplementedError
 
   @abc.abstractmethod
-  def _as_dataset(
-      self, split, decoders=None, read_config=None, shuffle_files=False):
+  def _as_dataset(self,
+                  split,
+                  decoders=None,
+                  read_config=None,
+                  shuffle_files=False):
     """Constructs a `tf.data.Dataset`.
 
     Internal implementation to overwrite when inheriting from DatasetBuilder.
@@ -797,14 +797,11 @@ class DatasetBuilder(registered.RegisteredDataset):
   def _make_download_manager(self, download_dir, download_config):
     """Creates a new download manager object."""
     download_dir = (
-        download_dir or os.path.join(self._data_dir_root, "downloads")
-    )
+        download_dir or os.path.join(self._data_dir_root, "downloads"))
     extract_dir = (
-        download_config.extract_dir or os.path.join(download_dir, "extracted")
-    )
+        download_config.extract_dir or os.path.join(download_dir, "extracted"))
     manual_dir = (
-        download_config.manual_dir or os.path.join(download_dir, "manual")
-    )
+        download_config.manual_dir or os.path.join(download_dir, "manual"))
 
     if download_config.register_checksums:
       # Note: Error will be raised here if user try to record checksums
@@ -859,10 +856,6 @@ class DatasetBuilder(registered.RegisteredDataset):
             "Cannot name a custom BuilderConfig the same as an available "
             "BuilderConfig. Change the name. Available BuilderConfigs: %s" %
             (list(self.builder_configs.keys())))
-      if not builder_config.version:
-        raise ValueError("BuilderConfig %s must have a version" % name)
-      if not builder_config.description:
-        raise ValueError("BuilderConfig %s must have a description" % name)
     return builder_config
 
   @utils.classproperty
@@ -883,36 +876,67 @@ class FileReaderBuilder(DatasetBuilder):
 
   Subclasses are:
 
-   * `FileAdapterBuilder`: Can both generate and read generated dataset.
-   * `ReadOnlyBuilder`: Can only read pre-generated datasets.
+   * `GeneratorBasedBuilder`: Can both generate and read generated dataset.
+   * `ReadOnlyBuilder`: Can only read pre-generated datasets. A user can
+     generate a dataset with `GeneratorBasedBuilder`, and read them with
+     `ReadOnlyBuilder` without requiring the original generation code.
 
   """
 
+  def __init__(self,
+               *,
+               file_format: Union[None, str, file_adapters.FileFormat] = None,
+               **kwargs: Any):
+    """Initializes an instance of FileReaderBuilder.
+
+    Callers must pass arguments as keyword arguments.
+
+    Args:
+      file_format: EXPERIMENTAL, may change at any time; Format of the record
+        files in which dataset will be read/written to. If `None`, defaults to
+        `tfrecord`.
+      **kwargs: Arguments passed to `DatasetBuilder`.
+    """
+    super().__init__(**kwargs)
+    self.info.set_file_format(file_format)
+
   @utils.memoized_property
   def _example_specs(self):
     return self.info.features.get_serialized_info()
 
-  @property
-  def _tfrecords_reader(self):
-    return tfrecords_reader.Reader(self._data_dir, self._example_specs)
-
   def _as_dataset(
       self,
       split=splits_lib.Split.TRAIN,
       decoders=None,
       read_config=None,
-      shuffle_files=False):
-    ds = self._tfrecords_reader.read(
+      shuffle_files=False,
+  ) -> tf.data.Dataset:
+    # Partial decoding
+    if isinstance(decoders, decode.PartialDecoding):
+      features = decoders.extract_features(self.info.features)
+      example_specs = features.get_serialized_info()
+      decoders = decoders.decoders
+    # Full decoding (all features decoded)
+    else:
+      features = self.info.features
+      example_specs = self._example_specs
+      decoders = decoders  # pylint: disable=self-assigning-variable
+
+    reader = tfrecords_reader.Reader(
+        self._data_dir,
+        example_specs=example_specs,
+        file_format=self.info.file_format,
+    )
+    decode_fn = functools.partial(features.decode_example, decoders=decoders)
+    return reader.read(
         name=self.name,
         instructions=split,
         split_infos=self.info.splits.values(),
+        decode_fn=decode_fn,
         read_config=read_config,
         shuffle_files=shuffle_files,
+        disable_shuffling=self.info.disable_shuffling,
     )
-    decode_fn = functools.partial(
-        self.info.features.decode_example, decoders=decoders)
-    ds = ds.map(decode_fn, num_parallel_calls=tf.data.experimental.AUTOTUNE)
-    return ds
 
 
 class GeneratorBasedBuilder(FileReaderBuilder):
@@ -941,8 +965,8 @@ class GeneratorBasedBuilder(FileReaderBuilder):
     def _split_generators(self, dl_manager):
       path = dl_manager.download_and_extract('http://dataset.org/my_data.zip')
       return {
-          'train': self._generate_examples(path=f'{path}/train/'),
-          'test': self._generate_examples(path=f'{path}/test/'),
+          'train': self._generate_examples(path=path / 'train_imgs'),
+          'test': self._generate_examples(path=path / 'test_imgs'),
       }
     ```
 
@@ -975,9 +999,8 @@ class GeneratorBasedBuilder(FileReaderBuilder):
   @abc.abstractmethod
   @utils.docs.do_not_doc_in_subclasses
   @utils.docs.doc_private
-  def _generate_examples(
-      self, **kwargs: Any
-  ) -> split_builder_lib.SplitGenerator:
+  def _generate_examples(self,
+                         **kwargs: Any) -> split_builder_lib.SplitGenerator:
     """Default function to generate examples for each split.
 
     The function should return a collection of `(key, examples)`. Examples
@@ -1042,10 +1065,13 @@ class GeneratorBasedBuilder(FileReaderBuilder):
           same key.
         * Deterministic: When generating the dataset twice, the same example
           should have the same key.
+        * Comparable: If shuffling is disabled the key will be used to sort the
+        dataset.
         Good keys can be the image id, or line number if examples are extracted
         from a text file.
-        The key will be hashed and sorted to shuffle examples deterministically,
-        such as generating the dataset multiple times keep examples in the
+        The example will be sorted by `hash(key)` if shuffling is enabled, and
+        otherwise by `key`.
+        Generating the dataset multiple times will keep examples in the
         same order.
       example: `dict<str feature_name, feature_value>`, a feature dictionary
         ready to be encoded and written to disk. The example will be
@@ -1065,23 +1091,28 @@ class GeneratorBasedBuilder(FileReaderBuilder):
         max_examples_per_split=download_config.max_examples_per_split,
         beam_options=download_config.beam_options,
         beam_runner=download_config.beam_runner,
+        file_format=self.info.file_format,
     )
     # Wrap the generation inside a context manager.
     # If `beam` is used during generation (when a pipeline gets created),
     # the context manager is equivalent to `with beam.Pipeline()`.
     # Otherwise, this is a no-op.
+    # By auto-detecting Beam, the user only has to change `_generate_examples`
+    # to go from non-beam to beam dataset:
+    # https://www.tensorflow.org/datasets/beam_datasets#instructions
     with split_builder.maybe_beam_pipeline():
       # If the signature has a `pipeline` kwargs, create the pipeline now and
       # forward it to `self._split_generators`
+      # We add this magic because the pipeline kwargs is only used by c4 and
+      # we do not want to make the API more verbose for a single advanced case.
       signature = inspect.signature(self._split_generators)
       if "pipeline" in signature.parameters.keys():
         optional_pipeline_kwargs = dict(pipeline=split_builder.beam_pipeline)
       else:
         optional_pipeline_kwargs = {}
       split_generators = self._split_generators(  # pylint: disable=unexpected-keyword-arg
-          dl_manager, **optional_pipeline_kwargs
-      )
-      # TODO(tfds): Could be removed one all datasets are migrated.
+          dl_manager, **optional_pipeline_kwargs)
+      # TODO(tfds): Could be removed once all datasets are migrated.
       # https://github.com/tensorflow/datasets/issues/2537
       # Legacy mode (eventually convert list[SplitGeneratorLegacy] -> dict)
       split_generators = split_builder.normalize_legacy_split_generators(
@@ -1093,25 +1124,33 @@ class GeneratorBasedBuilder(FileReaderBuilder):
       # Ensure `all` isn't used as key.
       _check_split_names(split_generators.keys())
 
+      # Writer fail if the number of example yield is `0`, so we return here.
+      if download_config.max_examples_per_split == 0:
+        return
+
       # Start generating data for all splits
+      path_suffix = file_adapters.ADAPTER_FOR_FORMAT[
+          self.info.file_format].FILE_SUFFIX
+
       split_info_futures = [
           split_builder.submit_split_generation(  # pylint: disable=g-complex-comprehension
               split_name=split_name,
               generator=generator,
-              path=self._data_path / f"{self.name}-{split_name}.tfrecord",
+              path=self.data_path / f"{self.name}-{split_name}.{path_suffix}",
+              disable_shuffling=self.info.disable_shuffling,
+          ) for split_name, generator in utils.tqdm(
+              split_generators.items(),
+              desc="Generating splits...",
+              unit=" splits",
+              leave=False,
           )
-          for split_name, generator
-          in utils.tqdm(split_generators.items(), unit=" splits", leave=False)
       ]
     # Finalize the splits (after apache beam completed, if it was used)
     split_infos = [future.result() for future in split_info_futures]
 
     # Update the info object with the splits.
-    # TODO(tfds): Should improve the API.
-    split_dict = splits_lib.SplitDict(dataset_name=self.name)
-    for split_info in split_infos:
-      split_dict.add(split_info)
-    self.info.update_splits_if_different(split_dict)
+    split_dict = splits_lib.SplitDict(split_infos, dataset_name=self.name)
+    self.info.set_splits(split_dict)
 
 
 @utils.docs.deprecated
@@ -1121,9 +1160,8 @@ class BeamBasedBuilder(GeneratorBasedBuilder):
   DEPRECATED: Please use `tfds.core.GeneratorBasedBuilder` instead.
   """
 
-  def _generate_examples(
-      self, *args: Any, **kwargs: Any
-  ) -> split_builder_lib.SplitGenerator:
+  def _generate_examples(self, *args: Any,
+                         **kwargs: Any) -> split_builder_lib.SplitGenerator:
     return self._build_pcollection(*args, **kwargs)
 
 
@@ -1131,5 +1169,68 @@ def _check_split_names(split_names: Iterable[str]) -> None:
   """Check that split names are valid."""
   if "all" in set(str(s).lower() for s in split_names):
     raise ValueError(
-        "`all` is a reserved keyword. Split cannot be named like this."
-    )
+        "`all` is a reserved keyword. Split cannot be named like this.")
+
+
+def _save_default_config_name(
+    common_dir: ReadWritePath,
+    *,
+    default_config_name: str,
+) -> None:
+  """Saves `builder_cls` metadata (common to all builder configs)."""
+  data = {
+      "default_config_name": default_config_name,
+  }
+  # `data_dir/ds_name/config/version/` -> `data_dir/ds_name/.config`
+  config_dir = common_dir / ".config"
+  config_dir.mkdir(parents=True, exist_ok=True)
+  # Note:
+  # * Save inside a dir to support some replicated filesystem
+  # * Write inside a `.incomplete` file and rename to avoid multiple configs
+  #   writing concurently the same file
+  # * Config file is overwritten each time a config is generated. If the
+  #   default config is changed, this will be updated.
+  config_path = config_dir / "metadata.json"
+  with utils.incomplete_file(config_path) as tmp_config_path:
+    tmp_config_path.write_text(json.dumps(data))
+
+
+def load_default_config_name(common_dir: ReadOnlyPath,) -> Optional[str]:
+  """Load `builder_cls` metadata (common to all builder configs)."""
+  config_path = common_dir / ".config/metadata.json"
+  if not config_path.exists():
+    return None
+  data = json.loads(config_path.read_text())
+  return data.get("default_config_name")
+
+
+def cannonical_version_for_config(
+    instance_or_cls: Union[DatasetBuilder, Type[DatasetBuilder]],
+    config: Optional[BuilderConfig] = None,
+) -> utils.Version:
+  """Get the cannonical version for the given config.
+
+  This allow to get the version without instanciating the class.
+  The version can be stored either at the class or in the config object.
+
+  Args:
+    instance_or_cls: The instance or class on which get the version
+    config: The config which might contain the version, or None if the dataset
+      do not have config.
+
+  Returns:
+    version: The extracted version.
+  """
+  if instance_or_cls.BUILDER_CONFIGS and config is None:
+    raise ValueError(
+        f"Cannot infer version on {instance_or_cls.name}. Unknown config.")
+
+  if config and config.version:
+    return utils.Version(config.version)
+  elif instance_or_cls.VERSION:
+    return utils.Version(instance_or_cls.VERSION)
+  else:
+    raise ValueError(
+        f"DatasetBuilder {instance_or_cls.name} does not have a defined "
+        "version. Please add a `VERSION = tfds.core.Version('x.y.z')` to the "
+        "class.")
