@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@ import os
 import tempfile
 from unittest import mock
 
-from absl.testing import absltest
+import dataclasses
 import dill
 import numpy as np
 import tensorflow.compat.v2 as tf
@@ -40,11 +40,9 @@ tf.enable_v2_behavior()
 DummyDatasetSharedGenerator = testing.DummyDatasetSharedGenerator
 
 
+@dataclasses.dataclass
 class DummyBuilderConfig(dataset_builder.BuilderConfig):
-
-  def __init__(self, increment=0, **kwargs):
-    super(DummyBuilderConfig, self).__init__(**kwargs)
-    self.increment = increment
+  increment: int = 0
 
 
 class DummyDatasetWithConfigs(dataset_builder.GeneratorBasedBuilder):
@@ -125,51 +123,44 @@ class DatasetBuilderTest(testing.TestCase):
     # ...), and so our datasets aren't guaranteed either.
     l = list(range(20))
     np.random.RandomState(42).shuffle(l)
-    self.assertEqual(l, [
-        0, 17, 15, 1, 8, 5, 11, 3, 18, 16, 13, 2, 9, 19, 4, 12, 7, 10, 14, 6
-    ])
+    self.assertEqual(
+        l,
+        [0, 17, 15, 1, 8, 5, 11, 3, 18, 16, 13, 2, 9, 19, 4, 12, 7, 10, 14, 6])
 
     # Ensure determinism. If this test fails, this mean the dataset are not
     # deterministically generated.
     self.assertEqual(
         [e["x"] for e in ds_values],
-        [6, 16, 19, 12, 14, 18, 5, 13, 15, 4, 10, 17, 0, 8, 3, 1, 9, 7, 11,
-         2],
+        [6, 16, 19, 12, 14, 18, 5, 13, 15, 4, 10, 17, 0, 8, 3, 1, 9, 7, 11, 2],
     )
 
   @testing.run_in_graph_and_eager_modes()
   def test_load_from_gcs(self):
     from tensorflow_datasets.image_classification import mnist  # pylint:disable=import-outside-toplevel,g-import-not-at-top
     with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      with absltest.mock.patch.object(
+      with mock.patch.object(
           mnist.MNIST, "_download_and_prepare",
           side_effect=NotImplementedError):
         # Make sure the dataset cannot be generated.
         with self.assertRaises(NotImplementedError):
-          load.load(
-              name="mnist",
-              data_dir=tmp_dir)
+          load.load(name="mnist", data_dir=tmp_dir)
         # Enable GCS access so that dataset will be loaded from GCS.
         with self.gcs_access():
-          _, info = load.load(
-              name="mnist",
-              data_dir=tmp_dir,
-              with_info=True)
+          _, info = load.load(name="mnist", data_dir=tmp_dir, with_info=True)
       self.assertSetEqual(
-          set(["dataset_info.json",
-               "image.image.json",
-               "mnist-test.tfrecord-00000-of-00001",
-               "mnist-train.tfrecord-00000-of-00001",
-              ]),
-          set(tf.io.gfile.listdir(os.path.join(tmp_dir, "mnist/3.0.1"))))
+          set([
+              "dataset_info.json",
+              "image.image.json",
+              "mnist-test.tfrecord-00000-of-00001",
+              "mnist-train.tfrecord-00000-of-00001",
+          ]), set(tf.io.gfile.listdir(os.path.join(tmp_dir, "mnist/3.0.1"))))
 
       self.assertEqual(set(info.splits.keys()), set(["train", "test"]))
 
   @testing.run_in_graph_and_eager_modes()
   def test_multi_split(self):
     ds_train, ds_test = self.builder.as_dataset(
-        split=["train", "test"],
-        shuffle_files=False)
+        split=["train", "test"], shuffle_files=False)
 
     data = list(dataset_utils.as_numpy(ds_train))
     self.assertEqual(20, len(data))
@@ -241,29 +232,28 @@ class DatasetBuilderTest(testing.TestCase):
       # Test that the config was used and they didn't collide.
       splits_list = ["train", "test"]
       for builder, incr in [(builder1, 1), (builder2, 2)]:
-        train_data, test_data = [   # pylint: disable=g-complex-comprehension
-            [el["x"] for el in   # pylint: disable=g-complex-comprehension
-             dataset_utils.as_numpy(builder.as_dataset(split=split))]
-            for split in splits_list
+        train_data, test_data = [  # pylint: disable=g-complex-comprehension
+            [
+                el["x"] for el in  # pylint: disable=g-complex-comprehension
+                dataset_utils.as_numpy(builder.as_dataset(split=split))
+            ] for split in splits_list
         ]
 
         self.assertEqual(20, len(train_data))
         self.assertEqual(10, len(test_data))
-        self.assertCountEqual(
-            [incr + el for el in range(30)],
-            train_data + test_data
-        )
+        self.assertCountEqual([incr + el for el in range(30)],
+                              train_data + test_data)
 
   def test_read_config(self):
     is_called = []
+
     def interleave_sort(lists):
       is_called.append(True)
       return lists
 
     read_config = read_config_lib.ReadConfig(
-        experimental_interleave_sort_fn=interleave_sort,
-    )
-    read_config.options.experimental_stats.prefix = "tfds_prefix"
+        experimental_interleave_sort_fn=interleave_sort,)
+    read_config.options.experimental_slack = True
     ds = self.builder.as_dataset(
         split="train",
         read_config=read_config,
@@ -271,7 +261,7 @@ class DatasetBuilderTest(testing.TestCase):
     )
 
     # Check that the ReadConfig options are properly set
-    self.assertEqual(ds.options().experimental_stats.prefix, "tfds_prefix")
+    self.assertTrue(ds.options().experimental_slack)
 
     # The instruction function should have been called
     self.assertEqual(is_called, [True])
@@ -335,14 +325,53 @@ class DatasetBuilderTest(testing.TestCase):
 
   def test_invalid_split_dataset(self):
     with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      with self.assertRaisesWithPredicateMatch(
-          ValueError, "`all` is a reserved keyword"):
+      with self.assertRaisesWithPredicateMatch(ValueError,
+                                               "`all` is a reserved keyword"):
         # Raise error during .download_and_prepare()
         load.load(
             name="invalid_split_dataset",
             data_dir=tmp_dir,
         )
 
+  def test_global_version(self):
+    global_version = utils.Version("1.0.0")
+    global_release_notes = {
+        "1.0.0": "Global release",
+    }
+    config_version = utils.Version("1.1.0")
+    config_release_notes = {
+        "1.1.0": "Some update",
+    }
+
+    class VersionDummyDataset(DummyDatasetWithConfigs):
+
+      BUILDER_CONFIGS = [
+          dataset_builder.BuilderConfig(
+              name="default",
+              description="Add 1 to the records",
+          ),
+          dataset_builder.BuilderConfig(
+              name="custom",
+              description="Add 2 to the records",
+              version=config_version,
+              release_notes=config_release_notes,
+          ),
+      ]
+      VERSION = global_version
+      RELEASE_NOTES = global_release_notes
+
+    tmp_path = "/tmp/non-existing-dir/"
+
+    # If version is not specified at the BuilderConfig level, then
+    # the default global values are used.
+    builder = VersionDummyDataset(config="default", data_dir=tmp_path)
+    self.assertEqual(builder.version, global_version)
+    self.assertEqual(builder.release_notes, global_release_notes)
+
+    builder = VersionDummyDataset(config="custom", data_dir=tmp_path)
+    self.assertEqual(builder.version, config_version)
+    self.assertEqual(builder.release_notes, config_release_notes)
+
 
 class DatasetBuilderMultiDirTest(testing.TestCase):
   """Tests for multi-dir."""
@@ -406,10 +435,12 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
     # Data dir contains old versions
     # -> use default path
     constants.add_data_dir(self.other_data_dir)
-    tf.io.gfile.makedirs(os.path.join(
-        self.other_data_dir, "dummy_dataset_shared_generator", "0.1.0"))
-    tf.io.gfile.makedirs(os.path.join(
-        self.other_data_dir, "dummy_dataset_shared_generator", "0.2.0"))
+    tf.io.gfile.makedirs(
+        os.path.join(self.other_data_dir, "dummy_dataset_shared_generator",
+                     "0.1.0"))
+    tf.io.gfile.makedirs(
+        os.path.join(self.other_data_dir, "dummy_dataset_shared_generator",
+                     "0.2.0"))
     self.assertBuildDataDir(
         self.builder._build_data_dir(None), self.default_data_dir)
 
@@ -419,18 +450,21 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
     # Data found
     # -> Re-load existing data
     constants.add_data_dir(self.other_data_dir)
-    tf.io.gfile.makedirs(os.path.join(
-        self.other_data_dir, "dummy_dataset_shared_generator", "1.0.0"))
+    tf.io.gfile.makedirs(
+        os.path.join(self.other_data_dir, "dummy_dataset_shared_generator",
+                     "1.0.0"))
     self.assertBuildDataDir(
         self.builder._build_data_dir(None), self.other_data_dir)
 
   def test_default_multi_dir_duplicate(self):
     # If two data dirs contains the dataset, raise an error...
     constants.add_data_dir(self.other_data_dir)
-    tf.io.gfile.makedirs(os.path.join(
-        self.default_data_dir, "dummy_dataset_shared_generator", "1.0.0"))
-    tf.io.gfile.makedirs(os.path.join(
-        self.other_data_dir, "dummy_dataset_shared_generator", "1.0.0"))
+    tf.io.gfile.makedirs(
+        os.path.join(self.default_data_dir, "dummy_dataset_shared_generator",
+                     "1.0.0"))
+    tf.io.gfile.makedirs(
+        os.path.join(self.other_data_dir, "dummy_dataset_shared_generator",
+                     "1.0.0"))
     with self.assertRaisesRegex(ValueError, "found in more than one directory"):
       self.builder._build_data_dir(None)
 
@@ -438,10 +472,12 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
     # If two data dirs contains the same version
     # Data dir is explicitly passed
     constants.add_data_dir(self.other_data_dir)
-    tf.io.gfile.makedirs(os.path.join(
-        self.default_data_dir, "dummy_dataset_shared_generator", "1.0.0"))
-    tf.io.gfile.makedirs(os.path.join(
-        self.other_data_dir, "dummy_dataset_shared_generator", "1.0.0"))
+    tf.io.gfile.makedirs(
+        os.path.join(self.default_data_dir, "dummy_dataset_shared_generator",
+                     "1.0.0"))
+    tf.io.gfile.makedirs(
+        os.path.join(self.other_data_dir, "dummy_dataset_shared_generator",
+                     "1.0.0"))
     self.assertBuildDataDir(
         self.builder._build_data_dir(self.other_data_dir), self.other_data_dir)
 
@@ -452,9 +488,7 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
     class MultiDirDataset(DummyDatasetSharedGenerator):  # pylint: disable=unused-variable
       VERSION = utils.Version("1.2.0")
 
-    data_dir = os.path.join(
-        self.other_data_dir, "multi_dir_dataset", "1.2.0"
-    )
+    data_dir = os.path.join(self.other_data_dir, "multi_dir_dataset", "1.2.0")
     tf.io.gfile.makedirs(data_dir)
 
     with mock.patch.object(dataset_info.DatasetInfo, "read_from_directory"):
@@ -462,6 +496,54 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
     self.assertEqual(info.data_dir, data_dir)
 
 
+class DummyOrderedDataset(dataset_builder.GeneratorBasedBuilder):
+  VERSION = utils.Version("1.0.0")
+
+  def _info(self):
+    return dataset_info.DatasetInfo(
+        builder=self,
+        features=features.FeaturesDict({"x": tf.int64}),
+        disable_shuffling=True,
+    )
+
+  def _split_generators(self, dl_manager):
+    del dl_manager
+    return {"train": self._generate_examples(range_=range(500))}
+
+  def _generate_examples(self, range_):
+    for i in range_:
+      yield i, {"x": i}
+
+
+class OrderedDatasetBuilderTest(testing.TestCase):
+
+  @classmethod
+  def setUpClass(cls):
+    super(OrderedDatasetBuilderTest, cls).setUpClass()
+    with mock.patch(
+        "tensorflow_datasets.core.tfrecords_writer._get_number_shards",
+        lambda x, y: 10):
+      cls.builder = DummyOrderedDataset(
+          data_dir=os.path.join(tempfile.gettempdir(), "tfds"))
+      cls.builder.download_and_prepare()
+
+  @testing.run_in_graph_and_eager_modes()
+  def test_sorted_by_key(self):
+    # For ordered dataset ReadConfig.interleave_cycle_length=1 by default
+    read_config = read_config_lib.ReadConfig()
+    ds = self.builder.as_dataset(
+        split=splits_lib.Split.TRAIN,
+        shuffle_files=False,
+        read_config=read_config)
+    ds_values = list(dataset_utils.as_numpy(ds))
+    self.assertListEqual(self.builder.info.splits["train"].shard_lengths,
+                         [50] * 10)
+    self.assertEqual(
+        [e["x"] for e in ds_values],
+        list(range(500)),
+    )
+
+
 class BuilderPickleTest(testing.TestCase):
 
   def test_load_dump(self):
@@ -485,49 +567,24 @@ class BuilderRestoreGcsTest(testing.TestCase):
       mnist_info_path = os.path.normpath(mnist_info_path)
       self.read_from_directory(mnist_info_path)
 
-    patcher = absltest.mock.patch.object(
+    patcher = mock.patch.object(
         dataset_info.DatasetInfo,
         "initialize_from_bucket",
-        new=load_mnist_dataset_info
-    )
+        new=load_mnist_dataset_info)
     patcher.start()
     self.patch_gcs = patcher
     self.addCleanup(patcher.stop)
 
-    patcher = absltest.mock.patch.object(
-        dataset_info.DatasetInfo, "compute_dynamic_properties",
-    )
-    self.compute_dynamic_property = patcher.start()
-    self.addCleanup(patcher.stop)
-
   def test_stats_restored_from_gcs(self):
     with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
       builder = testing.DummyMnist(data_dir=tmp_dir)
-      self.assertEqual(builder.info.splits["train"].statistics.num_examples, 20)
-      self.assertFalse(self.compute_dynamic_property.called)
-
-      builder.download_and_prepare()
-
-      # Statistics shouldn't have been recomputed
-      self.assertEqual(builder.info.splits["train"].statistics.num_examples, 20)
-      self.assertFalse(self.compute_dynamic_property.called)
+      self.assertEqual(builder.info.splits["train"].num_examples, 20)
 
   def test_stats_not_restored_gcs_overwritten(self):
     with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
       # If split are different that the one restored, stats should be recomputed
       builder = testing.DummyMnist(data_dir=tmp_dir)
-      self.assertEqual(builder.info.splits["train"].statistics.num_examples, 20)
-      self.assertFalse(self.compute_dynamic_property.called)
-
-      dl_config = download.DownloadConfig(
-          max_examples_per_split=5,
-          compute_stats=download.ComputeStatsMode.AUTO,
-      )
-      builder.download_and_prepare(download_config=dl_config)
-
-      # Statistics should have been recomputed (split different from the
-      # restored ones)
-      self.assertTrue(self.compute_dynamic_property.called)
+      self.assertEqual(builder.info.splits["train"].num_examples, 20)
 
   def test_gcs_not_exists(self):
     # By disabling the patch, and because DummyMnist is not on GCS, we can
@@ -537,69 +594,27 @@ class BuilderRestoreGcsTest(testing.TestCase):
       builder = testing.DummyMnist(data_dir=tmp_dir)
       # No dataset_info restored, so stats are empty
       self.assertEqual(builder.info.splits.total_num_examples, 0)
-      self.assertFalse(self.compute_dynamic_property.called)
 
-      dl_config = download.DownloadConfig(
-          compute_stats=download.ComputeStatsMode.AUTO,
-      )
+      dl_config = download.DownloadConfig()
       builder.download_and_prepare(download_config=dl_config)
 
       # Statistics should have been recomputed
-      self.assertTrue(self.compute_dynamic_property.called)
+      self.assertEqual(builder.info.splits["train"].num_examples, 20)
     self.patch_gcs.start()
 
-  def test_skip_stats(self):
-    # Test when stats do not exists yet and compute_stats='skip'
-
-    # By disabling the patch, and because DummyMnist is not on GCS, we can
-    # simulate a new dataset starting from scratch
-    self.patch_gcs.stop()
-    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      # No dataset_info restored, so stats are empty
-      builder = testing.DummyMnist(data_dir=tmp_dir)
-      self.assertEqual(builder.info.splits, {})
-      self.assertFalse(self.compute_dynamic_property.called)
-
-      download_config = download.DownloadConfig(
-          compute_stats=download.ComputeStatsMode.SKIP,
-      )
-      builder.download_and_prepare(download_config=download_config)
-
-      # Statistics computation should have been skipped
-      self.assertEqual(builder.info.splits["train"].statistics.num_examples, 0)
-      self.assertFalse(self.compute_dynamic_property.called)
-    self.patch_gcs.start()
-
-  def test_force_stats(self):
-    # Test when stats already exists but compute_stats='force'
-
-    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      # No dataset_info restored, so stats are empty
-      builder = testing.DummyMnist(data_dir=tmp_dir)
-      self.assertEqual(builder.info.splits.total_num_examples, 40)
-      self.assertFalse(self.compute_dynamic_property.called)
-
-      download_config = download.DownloadConfig(
-          compute_stats=download.ComputeStatsMode.FORCE,
-      )
-      builder.download_and_prepare(download_config=download_config)
-
-      # Statistics computation should have been recomputed
-      self.assertTrue(self.compute_dynamic_property.called)
-
 
 class DatasetBuilderReadTest(testing.TestCase):
 
   @classmethod
   def setUpClass(cls):
-    super(DatasetBuilderReadTest, cls).setUpClass()
+    super().setUpClass()
     cls._tfds_tmp_dir = testing.make_tmp_dir()
     builder = DummyDatasetSharedGenerator(data_dir=cls._tfds_tmp_dir)
     builder.download_and_prepare()
 
   @classmethod
   def tearDownClass(cls):
-    super(DatasetBuilderReadTest, cls).tearDownClass()
+    super().tearDownClass()
     testing.rm_tmp_dir(cls._tfds_tmp_dir)
 
   def setUp(self):
@@ -608,10 +623,10 @@ class DatasetBuilderReadTest(testing.TestCase):
 
   @testing.run_in_graph_and_eager_modes()
   def test_all_splits(self):
-    splits = dataset_utils.as_numpy(
-        self.builder.as_dataset(batch_size=-1))
-    self.assertSetEqual(set(splits.keys()),
-                        set([splits_lib.Split.TRAIN, splits_lib.Split.TEST]))
+    splits = dataset_utils.as_numpy(self.builder.as_dataset(batch_size=-1))
+    self.assertSetEqual(
+        set(splits.keys()), set([splits_lib.Split.TRAIN,
+                                 splits_lib.Split.TEST]))
 
     # Test that enum and string both access same object
     self.assertIs(splits["train"], splits[splits_lib.Split.TRAIN])
@@ -625,8 +640,9 @@ class DatasetBuilderReadTest(testing.TestCase):
 
   @testing.run_in_graph_and_eager_modes()
   def test_with_batch_size(self):
-    items = list(dataset_utils.as_numpy(self.builder.as_dataset(
-        split="train+test", batch_size=10)))
+    items = list(
+        dataset_utils.as_numpy(
+            self.builder.as_dataset(split="train+test", batch_size=10)))
     # 3 batches of 10
     self.assertEqual(3, len(items))
     x1, x2, x3 = items[0]["x"], items[1]["x"], items[2]["x"]
@@ -647,57 +663,68 @@ class DatasetBuilderReadTest(testing.TestCase):
 
   @testing.run_in_graph_and_eager_modes()
   def test_supervised_keys(self):
-    x, _ = dataset_utils.as_numpy(self.builder.as_dataset(
-        split=splits_lib.Split.TRAIN, as_supervised=True, batch_size=-1))
+    x, _ = dataset_utils.as_numpy(
+        self.builder.as_dataset(
+            split=splits_lib.Split.TRAIN, as_supervised=True, batch_size=-1))
     self.assertEqual(x.shape[0], 20)
 
   def test_autocache(self):
     # All the following should cache
 
     # Default should cache as dataset is small and has a single shard
-    self.assertTrue(self.builder._should_cache_ds(
-        split="train",
-        shuffle_files=True,
-        read_config=read_config_lib.ReadConfig(),
-    ))
+    self.assertTrue(
+        self.builder._should_cache_ds(
+            split="train",
+            shuffle_files=True,
+            read_config=read_config_lib.ReadConfig(),
+        ))
 
     # Multiple shards should cache when shuffling is disabled
-    self.assertTrue(self.builder._should_cache_ds(
-        split="train+test",
-        shuffle_files=False,
-        read_config=read_config_lib.ReadConfig(),
-    ))
+    self.assertTrue(
+        self.builder._should_cache_ds(
+            split="train+test",
+            shuffle_files=False,
+            read_config=read_config_lib.ReadConfig(),
+        ))
 
     # Multiple shards should cache when re-shuffling is disabled
-    self.assertTrue(self.builder._should_cache_ds(
-        split="train+test",
-        shuffle_files=True,
-        read_config=read_config_lib.ReadConfig(
-            shuffle_reshuffle_each_iteration=False),
-    ))
+    self.assertTrue(
+        self.builder._should_cache_ds(
+            split="train+test",
+            shuffle_files=True,
+            read_config=read_config_lib.ReadConfig(
+                shuffle_reshuffle_each_iteration=False),
+        ))
 
     # Sub-split API can cache if only a single shard is selected.
-    self.assertTrue(self.builder._should_cache_ds(
-        split="train+test[:0]",
-        shuffle_files=True,
-        read_config=read_config_lib.ReadConfig(),
-    ))
+    self.assertTrue(
+        self.builder._should_cache_ds(
+            split="train+test[:0]",
+            shuffle_files=True,
+            read_config=read_config_lib.ReadConfig(),
+        ))
 
     # All the following should NOT cache
 
     # Default should not cache if try_autocache is disabled
-    self.assertFalse(self.builder._should_cache_ds(
-        split="train",
-        shuffle_files=True,
-        read_config=read_config_lib.ReadConfig(try_autocache=False),
-    ))
+    self.assertFalse(
+        self.builder._should_cache_ds(
+            split="train",
+            shuffle_files=True,
+            read_config=read_config_lib.ReadConfig(try_autocache=False),
+        ))
 
     # Multiple shards should not cache when shuffling is enabled
-    self.assertFalse(self.builder._should_cache_ds(
-        split="train+test",
-        shuffle_files=True,
-        read_config=read_config_lib.ReadConfig(),
-    ))
+    self.assertFalse(
+        self.builder._should_cache_ds(
+            split="train+test",
+            shuffle_files=True,
+            read_config=read_config_lib.ReadConfig(),
+        ))
+
+  def test_with_tfds_info(self):
+    ds = self.builder.as_dataset(split=splits_lib.Split.TRAIN)
+    self.assertEqual(0, len(tf.compat.v1.data.get_output_shapes(ds)["x"]))
 
 
 
@@ -711,11 +738,12 @@ class NestedSequenceBuilder(dataset_builder.GeneratorBasedBuilder):
     return dataset_info.DatasetInfo(
         builder=self,
         features=features.FeaturesDict({
-            "frames": features.Sequence({
-                "coordinates": features.Sequence(
-                    features.Tensor(shape=(2,), dtype=tf.int32)
-                ),
-            }),
+            "frames":
+                features.Sequence({
+                    "coordinates":
+                        features.Sequence(
+                            features.Tensor(shape=(2,), dtype=tf.int32)),
+                }),
         }),
     )
 
@@ -724,11 +752,7 @@ class NestedSequenceBuilder(dataset_builder.GeneratorBasedBuilder):
     return {"train": self._generate_examples()}
 
   def _generate_examples(self):
-    ex0 = [
-        [[0, 1], [2, 3], [4, 5]],
-        [],
-        [[6, 7]]
-    ]
+    ex0 = [[[0, 1], [2, 3], [4, 5]], [], [[6, 7]]]
     ex1 = []
     ex2 = [
         [[10, 11]],
@@ -761,27 +785,36 @@ class NestedSequenceBuilderTest(testing.TestCase):
           with_info=True,
           shuffle_files=False)
       ex0, ex1, ex2 = [
-          ex["frames"]["coordinates"]
-          for ex in dataset_utils.as_numpy(ds_train)
+          ex["frames"]["coordinates"] for ex in dataset_utils.as_numpy(ds_train)
       ]
-      self.assertAllEqual(ex0, tf.ragged.constant([
-          [[0, 1], [2, 3], [4, 5]],
-          [],
-          [[6, 7]],
-      ], inner_shape=(2,)))
+      self.assertAllEqual(
+          ex0,
+          tf.ragged.constant([
+              [[0, 1], [2, 3], [4, 5]],
+              [],
+              [[6, 7]],
+          ],
+                             inner_shape=(2,)))
       self.assertAllEqual(ex1, tf.ragged.constant([], ragged_rank=1))
-      self.assertAllEqual(ex2, tf.ragged.constant([
-          [[10, 11]],
-          [[12, 13], [14, 15]],
-      ], inner_shape=(2,)))
+      self.assertAllEqual(
+          ex2,
+          tf.ragged.constant([
+              [[10, 11]],
+              [[12, 13], [14, 15]],
+          ],
+                             inner_shape=(2,)))
 
       self.assertEqual(
           ds_info.features.dtype,
-          {"frames": {"coordinates": tf.int32}},
+          {"frames": {
+              "coordinates": tf.int32
+          }},
       )
       self.assertEqual(
           ds_info.features.shape,
-          {"frames": {"coordinates": (None, None, 2)}},
+          {"frames": {
+              "coordinates": (None, None, 2)
+          }},
       )
       nested_tensor_info = ds_info.features.get_tensor_info()
       self.assertEqual(
