@@ -35,12 +35,13 @@ import json
 import os
 import posixpath
 import tempfile
-from typing import Optional
+from typing import Optional, Union
 
 from absl import logging
 import six
 import tensorflow.compat.v2 as tf
 
+from tensorflow_datasets.core import file_adapters
 from tensorflow_datasets.core import lazy_imports_lib
 from tensorflow_datasets.core import naming
 from tensorflow_datasets.core import splits as splits_lib
@@ -53,15 +54,12 @@ from tensorflow_datasets.core.utils import type_utils
 
 from google.protobuf import json_format
 
-
 # Name of the file to output the DatasetInfo protobuf object.
 DATASET_INFO_FILENAME = "dataset_info.json"
 LICENSE_FILENAME = "LICENSE"
 METADATA_FILENAME = "metadata.json"
 
 
-# TODO(tfds): Do we require to warn the user about the peak memory used while
-# constructing the dataset?
 class DatasetInfo(object):
   """Information about a dataset.
 
@@ -74,32 +72,32 @@ class DatasetInfo(object):
   builder.download_and_prepare()`).
   """
 
-  def __init__(self,
-               *,
-               builder,
-               description=None,
-               features=None,
-               supervised_keys=None,
-               disable_shuffling: bool = False,
-               homepage=None,
-               citation=None,
-               metadata=None,
-               license: Optional[str] = None,  # pylint: disable=redefined-builtin
-               redistribution_info=None):
+  def __init__(
+      self,
+      *,
+      builder,
+      description=None,
+      features=None,
+      supervised_keys=None,
+      disable_shuffling: bool = False,
+      homepage=None,
+      citation=None,
+      metadata=None,
+      license: Optional[str] = None,  # pylint: disable=redefined-builtin
+      redistribution_info=None):
     """Constructs DatasetInfo.
 
     Args:
       builder: `DatasetBuilder`, dataset builder for this info.
       description: `str`, description of this dataset.
-      features: `tfds.features.FeaturesDict`, Information on the feature dict
-        of the `tf.data.Dataset()` object from the `builder.as_dataset()`
-        method.
-      supervised_keys: `tuple` of `(input_key, target_key)`, Specifies the
-        input feature and the label for supervised learning, if applicable for
-        the dataset. The keys correspond to the feature names to select in
+      features: `tfds.features.FeaturesDict`, Information on the feature dict of
+        the `tf.data.Dataset()` object from the `builder.as_dataset()` method.
+      supervised_keys: `tuple` of `(input_key, target_key)`, Specifies the input
+        feature and the label for supervised learning, if applicable for the
+        dataset. The keys correspond to the feature names to select in
         `info.features`. When calling `tfds.core.DatasetBuilder.as_dataset()`
-        with `as_supervised=True`, the `tf.data.Dataset` object will yield
-        the (input, target) defined here.
+        with `as_supervised=True`, the `tf.data.Dataset` object will yield the
+        (input, target) defined here.
       disable_shuffling: `bool`, specify whether to shuffle the examples.
       homepage: `str`, optional, the homepage for this dataset.
       citation: `str`, optional, the citation to use for this dataset.
@@ -191,8 +189,7 @@ class DatasetInfo(object):
   @property
   def homepage(self):
     urls = self.as_proto.location.urls
-    tfds_homepage = "https://www.tensorflow.org/datasets/catalog/{}".format(
-        self.name)
+    tfds_homepage = f"https://www.tensorflow.org/datasets/catalog/{self.name}"
     return urls and urls[0] or tfds_homepage
 
   @property
@@ -213,9 +210,8 @@ class DatasetInfo(object):
   def download_size(self) -> utils.Size:
     """Downloaded files size, in bytes."""
     # Fallback to deprecated `size_in_bytes` if `download_size` is empty.
-    return utils.Size(
-        self.as_proto.download_size or self.as_proto.size_in_bytes
-    )
+    return utils.Size(self.as_proto.download_size or
+                      self.as_proto.size_in_bytes)
 
   @download_size.setter
   def download_size(self, size):
@@ -244,6 +240,41 @@ class DatasetInfo(object):
   def module_name(self):
     return self.as_proto.module_name
 
+  @property
+  def file_format(self) -> Optional[file_adapters.FileFormat]:
+    if not self.as_proto.file_format:
+      return None
+    return file_adapters.FileFormat(self.as_proto.file_format)
+
+  def set_file_format(
+      self,
+      file_format: Union[None, str, file_adapters.FileFormat],
+  ) -> None:
+    """Internal function to define the file format.
+
+    The file format is set during `FileReaderBuilder.__init__`,
+    not `DatasetInfo.__init__`.
+
+    Args:
+      file_format: The file format.
+    """
+    # If file format isn't present already, fallback to `DEFAULT_FILE_FORMAT`
+    file_format = (
+        file_format  # Format explicitly given: tfds.builder(..., file_format=x)
+        or self.file_format  # Format restored from dataset_info.json
+        or file_adapters.DEFAULT_FILE_FORMAT)
+    try:
+      new_file_format = file_adapters.FileFormat(file_format)
+    except ValueError as e:
+      all_values = [f.value for f in file_adapters.FileFormat]
+      utils.reraise(e, suffix=f". Valid file formats: {all_values}")
+
+    # If the file format has been set once, file format should be consistent
+    if self.file_format and self.file_format != new_file_format:
+      raise ValueError(f"File format is already set to {self.file_format}. "
+                       f"Got {new_file_format}")
+    self.as_proto.file_format = new_file_format.value
+
   @property
   def splits(self):
     return self._splits
@@ -253,26 +284,23 @@ class DatasetInfo(object):
     if self._builder.name != split_dict._dataset_name:  # pylint: disable=protected-access
       raise AssertionError(
           "SplitDict dataset_name does not seems to match dataset_info. "  # pylint: disable=protected-access
-          f"{self._builder.name} != {split_dict._dataset_name}"
-      )
+          f"{self._builder.name} != {split_dict._dataset_name}")
 
     # If the statistics have been pre-loaded, forward the statistics
     # into the new split_dict
     new_split_infos = []
     for split_info in split_dict.values():
       old_split_info = self._splits.get(split_info.name)
-      if (
-          not split_info.statistics.ByteSize()
-          and old_split_info
-          and old_split_info.statistics.ByteSize()
-          and old_split_info.shard_lengths == split_info.shard_lengths
-      ):
+      if (not split_info.statistics.ByteSize() and old_split_info and
+          old_split_info.statistics.ByteSize() and
+          old_split_info.shard_lengths == split_info.shard_lengths):
         split_info = split_info.replace(statistics=old_split_info.statistics)
       new_split_infos.append(split_info)
 
     # Update the dictionary representation.
     self._splits = splits_lib.SplitDict(
-        new_split_infos, dataset_name=self._builder.name,
+        new_split_infos,
+        dataset_name=self._builder.name,
     )
 
     # Update the proto
@@ -291,41 +319,6 @@ class DatasetInfo(object):
   def _license_path(self, dataset_info_dir):
     return os.path.join(dataset_info_dir, LICENSE_FILENAME)
 
-  def compute_dynamic_properties(self):
-    self._compute_dynamic_properties(self._builder)
-    self._fully_initialized = True
-
-  def _compute_dynamic_properties(self, builder):
-    """Update from the DatasetBuilder."""
-    # Fill other things by going over the dataset.
-    splits = self.splits
-    for split_info in utils.tqdm(
-        splits.values(), desc="Computing statistics...", unit=" split"):
-      try:
-        split_name = split_info.name
-        # Fill DatasetFeatureStatistics.
-        dataset_feature_statistics, schema = get_dataset_feature_statistics(
-            builder, split_name)
-
-        # Add the statistics to this split.
-        split_info.statistics.CopyFrom(dataset_feature_statistics)
-
-        # Set the schema at the top-level since this is independent of the
-        # split.
-        self.as_proto.schema.CopyFrom(schema)
-
-      except tf.errors.InvalidArgumentError:
-        # This means there is no such split, even though it was specified in the
-        # info, the least we can do is to log this.
-        logging.error(("%s's info() property specifies split %s, but it "
-                       "doesn't seem to have been generated. Please ensure "
-                       "that the data was downloaded for this split and re-run "
-                       "download_and_prepare."), self.name, split_name)
-        raise
-
-    # Set splits to trigger proto update in setter
-    self.set_splits(splits)
-
   @property
   def as_json(self):
     return json_format.MessageToJson(self.as_proto, sort_keys=True)
@@ -370,8 +363,7 @@ class DatasetInfo(object):
           "Try to load `DatasetInfo` from a directory which does not exist or "
           "does not contain `dataset_info.json`. Please delete the directory "
           f"`{dataset_info_dir}`  if you are trying to re-generate the "
-          "dataset."
-      )
+          "dataset.")
 
     # Load the metadata from disk
     parsed_proto = read_from_json(json_filename)
@@ -386,13 +378,10 @@ class DatasetInfo(object):
     # For `ReadOnlyBuilder`, reconstruct the features from the config.
     elif tf.io.gfile.exists(feature_lib.make_config_path(dataset_info_dir)):
       self._features = feature_lib.FeatureConnector.from_config(
-          dataset_info_dir
-      )
+          dataset_info_dir)
     # Restore the MetaDataDict from metadata.json if there is any
-    if (
-        self.metadata is not None
-        or tf.io.gfile.exists(_metadata_filepath(dataset_info_dir))
-    ):
+    if (self.metadata is not None or
+        tf.io.gfile.exists(_metadata_filepath(dataset_info_dir))):
       # If the dataset was loaded from file, self.metadata will be `None`, so
       # we create a MetadataDict first.
       if self.metadata is None:
@@ -449,8 +438,9 @@ class DatasetInfo(object):
     data_files = gcs_utils.gcs_dataset_info_files(self.full_name)
     if not data_files:
       return
-    logging.info("Load pre-computed DatasetInfo (eg: splits, num examples,...) "
-                 "from GCS: %s", self.full_name)
+    logging.info(
+        "Load pre-computed DatasetInfo (eg: splits, num examples,...) "
+        "from GCS: %s", self.full_name)
     for fname in data_files:
       out_fname = os.path.join(tmp_dir, os.path.basename(fname))
       tf.io.gfile.copy(os.fspath(gcs_utils.gcs_path(fname)), out_fname)
@@ -460,15 +450,13 @@ class DatasetInfo(object):
     SKIP = object()  # pylint: disable=invalid-name
 
     splits = _indent("\n".join(
-        ["{"]
-        + [f"    '{k}': {split}," for k, split in sorted(self.splits.items())]
-        + ["}"]
-    ))
+        ["{"] +
+        [f"    '{k}': {split}," for k, split in sorted(self.splits.items())] +
+        ["}"]))
 
     if self._info_proto.config_description:
       config_description = _indent(
-          f'"""\n{self._info_proto.config_description}\n"""'
-      )
+          f'"""\n{self._info_proto.config_description}\n"""')
     else:
       config_description = SKIP
 
@@ -527,12 +515,13 @@ def get_dataset_feature_statistics(builder, split):
   if filetype_suffix not in ["tfrecord", "csv"]:
     raise ValueError(
         "Cannot generate statistics for filetype {}".format(filetype_suffix))
-  filepattern = naming.filepattern_for_dataset_split(
-      builder.name, split, builder.data_dir, filetype_suffix)
+  filepattern = naming.filepattern_for_dataset_split(builder.name, split,
+                                                     builder.data_dir,
+                                                     filetype_suffix)
   # Avoid generating a large number of buckets in rank histogram
   # (default is 1000).
-  stats_options = tfdv.StatsOptions(num_top_values=10,
-                                    num_rank_histogram_buckets=10)
+  stats_options = tfdv.StatsOptions(
+      num_top_values=10, num_rank_histogram_buckets=10)
   if filetype_suffix == "csv":
     statistics = tfdv.generate_statistics_from_csv(
         filepattern, stats_options=stats_options)
@@ -564,11 +553,8 @@ def pack_as_supervised_ds(
     ds_info: DatasetInfo,
 ) -> tf.data.Dataset:
   """Pack `(input, label)` dataset as `{'key0': input, 'key1': label}`."""
-  if (
-      ds_info.supervised_keys
-      and isinstance(ds.element_spec, tuple)
-      and len(ds.element_spec) == 2
-  ):
+  if (ds_info.supervised_keys and isinstance(ds.element_spec, tuple) and
+      len(ds.element_spec) == 2):
     x_key, y_key = ds_info.supervised_keys
     ds = ds.map(lambda x, y: {x_key: x, y_key: y})
     return ds
@@ -655,12 +641,12 @@ class BeamMetadataDict(MetadataDict):
           "`tfds.core.BeamMetadataDict` can\'t be used on `beam.PTransform`, "
           "only on `beam.PCollection`. See `_generate_examples` doc on how "
           "to use `beam.PCollection`, or wrap your `_generate_examples` inside "
-          f"a @beam.ptransform_fn. Got: {key}: {item}"
-      )
+          f"a @beam.ptransform_fn. Got: {key}: {item}")
     elif isinstance(item, beam.pvalue.PValue):
       if key in self:
         raise ValueError("Already added PValue with key: %s" % key)
       logging.info("Lazily adding metadata item with Beam: %s", key)
+
       def _to_json(item_list):
         if len(item_list) != 1:
           raise ValueError(
@@ -668,6 +654,7 @@ class BeamMetadataDict(MetadataDict):
               len(item_list))
         item = item_list[0]
         return json.dumps(item)
+
       _ = (
           item
           | "metadata_%s_tolist" % key >> beam.combiners.ToList()
@@ -676,8 +663,7 @@ class BeamMetadataDict(MetadataDict):
               self._temp_filepath(key),
               num_shards=1,
               shard_name_template="",
-          )
-      )
+          ))
     super(BeamMetadataDict, self).__setitem__(key, item)
 
   def save_metadata(self, data_dir):
