@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,31 +17,29 @@
 
 import json
 import os
+import pathlib
 import tempfile
 import numpy as np
-import six
+import pytest
+
 import tensorflow.compat.v2 as tf
 from tensorflow_datasets import testing
-from tensorflow_datasets.core import dataset_builder
 from tensorflow_datasets.core import dataset_info
-from tensorflow_datasets.core import download
 from tensorflow_datasets.core import features
-from tensorflow_datasets.core.utils import py_utils
+from tensorflow_datasets.core import file_adapters
+from tensorflow_datasets.core import read_only_builder
+from tensorflow_datasets.core import utils
 from tensorflow_datasets.image_classification import mnist
 
-from google.protobuf import text_format
-from tensorflow_metadata.proto.v0 import schema_pb2
-
 tf.enable_v2_behavior()
 
-_TFDS_DIR = py_utils.tfds_dir()
+_TFDS_DIR = utils.tfds_path()
 _INFO_DIR = os.path.join(_TFDS_DIR, "testing", "test_data", "dataset_info",
                          "mnist", "3.0.1")
 _INFO_DIR_UNLABELED = os.path.join(_TFDS_DIR, "testing", "test_data",
                                    "dataset_info", "mnist_unlabeled", "3.0.1")
 _NON_EXISTENT_DIR = os.path.join(_TFDS_DIR, "non_existent_dir")
 
-
 DummyDatasetSharedGenerator = testing.DummyDatasetSharedGenerator
 
 
@@ -73,31 +71,18 @@ class DatasetInfoTest(testing.TestCase):
   @classmethod
   def setUpClass(cls):
     super(DatasetInfoTest, cls).setUpClass()
-    dataset_builder._is_py2_download_and_prepare_disabled = False
     cls._tfds_tmp_dir = testing.make_tmp_dir()
     cls._builder = DummyDatasetSharedGenerator(data_dir=cls._tfds_tmp_dir)
 
   @classmethod
   def tearDownClass(cls):
     super(DatasetInfoTest, cls).tearDownClass()
-    dataset_builder._is_py2_download_and_prepare_disabled = True
     testing.rm_tmp_dir(cls._tfds_tmp_dir)
 
-  def test_undefined_dir(self):
-    with self.assertRaisesWithPredicateMatch(ValueError,
-                                             "undefined dataset_info_dir"):
-      info = dataset_info.DatasetInfo(builder=self._builder)
-      info.read_from_directory(None)
-
   def test_non_existent_dir(self):
-    # The error messages raised by Windows is different from Unix.
-    if os.name == "nt":
-      err = "The system cannot find the path specified"
-    else:
-      err = "No such file or dir"
     info = dataset_info.DatasetInfo(builder=self._builder)
     with self.assertRaisesWithPredicateMatch(
-        tf.errors.NotFoundError, err):
+        FileNotFoundError, "from a directory which does not exist"):
       info.read_from_directory(_NON_EXISTENT_DIR)
 
   def test_reading(self):
@@ -125,6 +110,15 @@ class DatasetInfoTest(testing.TestCase):
 
     self.assertEqual("image", info.supervised_keys[0])
     self.assertEqual("label", info.supervised_keys[1])
+    self.assertEqual(info.module_name, "tensorflow_datasets.testing.test_utils")
+    self.assertEqual(False, info.disable_shuffling)
+
+  def test_disable_shuffling(self):
+    info = dataset_info.DatasetInfo(
+        builder=self._builder, disable_shuffling=True)
+    info.read_from_directory(_INFO_DIR)
+
+    self.assertEqual(True, info.disable_shuffling)
 
   def test_reading_empty_properties(self):
     info = dataset_info.DatasetInfo(builder=self._builder)
@@ -164,9 +158,9 @@ class DatasetInfoTest(testing.TestCase):
     # Assert correct license was written.
     self.assertEqual(existing_json["redistributionInfo"]["license"], license_)
 
-    if six.PY3:
-      # Only test on Python 3 to avoid u'' formatting issues
-      self.assertEqual(repr(info), INFO_STR)
+    # Do not check the full string as it display the generated path.
+    self.assertEqual(_INFO_STR % mnist_builder.data_dir, repr(info))
+    self.assertIn("'test': <SplitInfo num_examples=", repr(info))
 
   def test_restore_after_modification(self):
     # Create a DatasetInfo
@@ -176,7 +170,7 @@ class DatasetInfoTest(testing.TestCase):
         supervised_keys=("input", "output"),
         homepage="http://some-location",
         citation="some citation",
-        redistribution_info={"license": "some license"}
+        license="some license",
     )
     info.download_size = 456
     info.as_proto.splits.add(name="train", num_bytes=512)
@@ -207,8 +201,7 @@ class DatasetInfoTest(testing.TestCase):
           supervised_keys=("input (new)", "output (new)"),
           homepage="http://some-location-new",
           citation="some citation (new)",
-          redistribution_info={"license": "some license (new)"}
-      )
+          redistribution_info={"license": "some license (new)"})
       restored_info.download_size = 789
       restored_info.as_proto.splits.add(name="validation", num_bytes=288)
       restored_info.as_proto.schema.feature.add()
@@ -225,8 +218,8 @@ class DatasetInfoTest(testing.TestCase):
       # Even though restored_info has been restored, informations defined in
       # the code overwrite informations from the json file.
       self.assertEqual(restored_info.description, "A description")
-      self.assertEqual(
-          restored_info.supervised_keys, ("input (new)", "output (new)"))
+      self.assertEqual(restored_info.supervised_keys,
+                       ("input (new)", "output (new)"))
       self.assertEqual(restored_info.homepage, "http://some-location-new")
       self.assertEqual(restored_info.citation, "some citation (new)")
       self.assertEqual(restored_info.redistribution_info.license,
@@ -256,90 +249,6 @@ class DatasetInfoTest(testing.TestCase):
     info = mnist.MNIST(data_dir="/tmp/some_dummy_dir").info
     _ = str(info)
 
-  @testing.run_in_graph_and_eager_modes()
-  def test_statistics_generation(self):
-    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      builder = DummyDatasetSharedGenerator(data_dir=tmp_dir)
-      builder.download_and_prepare(
-          download_config=download.DownloadConfig(
-              compute_stats=download.ComputeStatsMode.AUTO,
-          ),
-      )
-
-      # Overall
-      self.assertEqual(30, builder.info.splits.total_num_examples)
-
-      # Per split.
-      test_split = builder.info.splits["test"].get_proto()
-      train_split = builder.info.splits["train"].get_proto()
-      expected_schema = text_format.Parse("""
-      feature {
-        name: "x"
-        type: INT
-        presence {
-          min_fraction: 1.0
-          min_count: 1
-        }
-        shape {
-          dim {
-            size: 1
-          }
-        }
-      }""", schema_pb2.Schema())
-      self.assertEqual(train_split.statistics.num_examples, 20)
-      self.assertLen(train_split.statistics.features, 1)
-      self.assertEqual(
-          train_split.statistics.features[0].path.step[0], "x")
-      self.assertLen(
-          train_split.statistics.features[0].num_stats.common_stats.
-          num_values_histogram.buckets, 10)
-      self.assertLen(
-          train_split.statistics.features[0].num_stats.histograms, 2)
-
-      self.assertEqual(test_split.statistics.num_examples, 10)
-      self.assertLen(test_split.statistics.features, 1)
-      self.assertEqual(
-          test_split.statistics.features[0].path.step[0], "x")
-      self.assertLen(
-          test_split.statistics.features[0].num_stats.common_stats.
-          num_values_histogram.buckets, 10)
-      self.assertLen(
-          test_split.statistics.features[0].num_stats.histograms, 2)
-      self.assertEqual(builder.info.as_proto.schema, expected_schema)
-
-  @testing.run_in_graph_and_eager_modes()
-  def test_schema_generation_variable_sizes(self):
-    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
-      builder = RandomShapedImageGenerator(data_dir=tmp_dir)
-      builder.download_and_prepare(
-          download_config=download.DownloadConfig(
-              compute_stats=download.ComputeStatsMode.AUTO,
-          ),
-      )
-
-      expected_schema = text_format.Parse(
-          """
-feature {
-  name: "im"
-  type: BYTES
-  presence {
-    min_fraction: 1.0
-    min_count: 1
-  }
-  shape {
-    dim {
-      size: -1
-    }
-    dim {
-      size: -1
-    }
-    dim {
-      size: 3
-    }
-  }
-}""", schema_pb2.Schema())
-      self.assertEqual(builder.info.as_proto.schema, expected_schema)
-
   def test_metadata(self):
     with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
       builder = RandomShapedImageGenerator(data_dir=tmp_dir)
@@ -351,10 +260,18 @@ feature {
       builder2 = RandomShapedImageGenerator(data_dir=tmp_dir)
       self.assertEqual(builder2.info.metadata, {"some_key": 123})
 
+      # Metadata should have been restored even if the builder code was not
+      # available and we restored from files.
+      builder3 = read_only_builder.builder_from_files(
+          builder.name,
+          data_dir=tmp_dir,
+      )
+      self.assertEqual(builder3.info.metadata, {"some_key": 123})
+
   def test_updates_on_bucket_info(self):
 
-    info = dataset_info.DatasetInfo(builder=self._builder,
-                                    description="won't be updated")
+    info = dataset_info.DatasetInfo(
+        builder=self._builder, description="won't be updated")
     # No statistics in the above.
     self.assertEqual(0, info.splits.total_num_examples)
     self.assertEqual(0, len(info.as_proto.schema.feature))
@@ -371,32 +288,91 @@ feature {
     self.assertEqual(2, len(info.as_proto.schema.feature))
 
 
-INFO_STR = """tfds.core.DatasetInfo(
+@pytest.mark.parametrize(
+    "file_format",
+    [
+        file_adapters.FileFormat.TFRECORD,
+    ])
+def test_file_format_save_restore(
+    tmp_path: pathlib.Path,
+    file_format: file_adapters.FileFormat,
+):
+  builder = testing.DummyDataset(data_dir=tmp_path, file_format=file_format)
+
+  assert isinstance(builder.info.file_format, file_adapters.FileFormat)
+  assert builder.info.file_format is file_format
+
+  builder.download_and_prepare()
+
+  # When restoring the builder, we do not provide the `file_format=`
+  # yet it is correctly restored
+  builder2 = testing.DummyDataset(data_dir=tmp_path)
+  assert builder2.info.file_format is file_format
+
+  # Explicitly passing the correct format is accepted.
+  builder3 = testing.DummyDataset(data_dir=tmp_path, file_format=file_format)
+  assert builder3.info.file_format is file_format
+
+  # Providing an inconsistent format is rejected.
+  with pytest.raises(ValueError, match="File format is already set to"):
+    different_file_format = {
+        file_adapters.FileFormat.TFRECORD: file_adapters.FileFormat.RIEGELI,
+        file_adapters.FileFormat.RIEGELI: file_adapters.FileFormat.TFRECORD,
+    }[file_format]
+    testing.DummyDataset(data_dir=tmp_path, file_format=different_file_format)
+
+
+def test_file_format_values(tmp_path: pathlib.Path):
+  # Default file format
+  builder = testing.DummyDataset(data_dir=tmp_path, file_format=None)
+  assert builder.info.file_format == file_adapters.FileFormat.TFRECORD
+
+  # str accepted
+  builder = testing.DummyDataset(data_dir=tmp_path, file_format="riegeli")
+  assert builder.info.file_format == file_adapters.FileFormat.RIEGELI
+
+  # file_adapters.FileFormat accepted
+  builder = testing.DummyDataset(
+      data_dir=tmp_path, file_format=file_adapters.FileFormat.RIEGELI)
+  assert builder.info.file_format == file_adapters.FileFormat.RIEGELI
+
+  # Unknown value
+  with pytest.raises(ValueError, match="is not a valid FileFormat"):
+    testing.DummyDataset(data_dir=tmp_path, file_format="arrow")
+
+
+# pylint: disable=g-inconsistent-quotes
+_INFO_STR = '''tfds.core.DatasetInfo(
     name='mnist',
-    version=3.0.1,
-    description='The MNIST database of handwritten digits.',
+    full_name='mnist/3.0.1',
+    description="""
+    The MNIST database of handwritten digits.
+    """,
     homepage='https://storage.googleapis.com/cvdf-datasets/mnist/',
+    data_path='%s',
+    download_size=1.95 KiB,
+    dataset_size=11.06 MiB,
     features=FeaturesDict({
         'image': Image(shape=(28, 28, 1), dtype=tf.uint8),
         'label': ClassLabel(shape=(), dtype=tf.int64, num_classes=10),
     }),
-    total_num_examples=40,
-    splits={
-        'test': 20,
-        'train': 20,
-    },
     supervised_keys=('image', 'label'),
-    citation=\"\"\"@article{lecun2010mnist,
+    disable_shuffling=False,
+    splits={
+        'test': <SplitInfo num_examples=20, num_shards=1>,
+        'train': <SplitInfo num_examples=20, num_shards=1>,
+    },
+    citation="""@article{lecun2010mnist,
       title={MNIST handwritten digit database},
       author={LeCun, Yann and Cortes, Corinna and Burges, CJ},
       journal={ATT Labs [Online]. Available: http://yann. lecun. com/exdb/mnist},
       volume={2},
       year={2010}
-    }\"\"\",
+    }
+    """,
     redistribution_info=license: "test license",
-)
-"""
-
+)'''
+# pylint: enable=g-inconsistent-quotes
 
 if __name__ == "__main__":
   testing.test_main()
