@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,16 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Decoder public API.
-
-"""
+"""Decoder public API."""
 
 from tensorflow_datasets.core.decode.base import Decoder
 from tensorflow_datasets.core.decode.base import make_decoder
 from tensorflow_datasets.core.decode.base import SkipDecoding
+from tensorflow_datasets.core.decode.partial_decode import PartialDecoding
 
 __all__ = [
     'Decoder',
     'make_decoder',
+    'PartialDecoding',
     'SkipDecoding',
 ]
