@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,6 +15,8 @@
 
 """Tests for tensorflow_datasets.core.transform.image.image_transform."""
 
+import os
+
 import numpy as np
 import tensorflow.compat.v2 as tf
 from tensorflow_datasets import testing
@@ -55,7 +57,7 @@ class BaseDecodeTest(testing.FeatureExpectationsTestCase):
           channels=feature.shape[-1],
       )
 
-    image_path = utils.get_tfds_path('testing/test_data/test_image.jpg')
+    image_path = os.fspath(utils.tfds_path('testing/test_data/test_image.jpg'))
     with tf.io.gfile.GFile(image_path, 'rb') as f:
       serialized_img = f.read()
 
@@ -89,7 +91,7 @@ class BaseDecodeTest(testing.FeatureExpectationsTestCase):
 
   def test_video_custom_decode(self):
 
-    image_path = utils.get_tfds_path('testing/test_data/test_image.jpg')
+    image_path = os.fspath(utils.tfds_path('testing/test_data/test_image.jpg'))
     with tf.io.gfile.GFile(image_path, 'rb') as f:
       serialized_img = f.read()
 
@@ -112,9 +114,10 @@ class BaseDecodeTest(testing.FeatureExpectationsTestCase):
     # Test with FeatureDict
     self.assertFeature(
         feature=features_lib.FeaturesDict({
-            'image': features_lib.Image(
-                shape=(30, 60, 3), encoding_format='jpeg'),
-            'label': tf.int64,
+            'image':
+                features_lib.Image(shape=(30, 60, 3), encoding_format='jpeg'),
+            'label':
+                tf.int64,
         }),
         shape={
             'image': (30, 60, 3),
