@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,6 +25,7 @@ import re
 from typing import Any, ContextManager, Iterable, Iterator, Optional, Tuple, Union
 import urllib
 
+import dataclasses
 import promise
 import requests
 
@@ -35,19 +36,23 @@ from tensorflow_datasets.core.download import checksums as checksums_lib
 
 _DRIVE_URL = re.compile(r'^https://drive\.google\.com/')
 
-
 # Response interface. Has `.url` and `.headers` attribute
 Response = Union[requests.Response, urllib.response.addinfourl]
 
 
+@dataclasses.dataclass(eq=False, frozen=True)
+class DownloadResult:
+  path: utils.ReadWritePath
+  url_info: checksums_lib.UrlInfo
+
+
 @utils.memoize()
 def get_downloader(*args: Any, **kwargs: Any) -> '_Downloader':
   return _Downloader(*args, **kwargs)
 
 
 def _filename_from_content_disposition(
-    content_disposition: str,
-) -> Optional[str]:
+    content_disposition: str,) -> Optional[str]:
   """Extract the filename from the content disposition.
 
   Parse the content_definition as defined in:
@@ -83,9 +88,8 @@ def _filename_from_content_disposition(
   elif len(match) != 1:
     raise ValueError(
         f'Error while parsing filename for: {content_disposition}\n'
-        f'Multiple filename detected: {list(match)}'
-    )
-  return match[0].rstrip()
+        f'Multiple filename detected: {list(match)}')
+  return os.path.basename(match[0].rstrip())
 
 
 def _get_filename(response: Response) -> str:
@@ -131,7 +135,20 @@ class _Downloader(object):
         self._pbar_dl_size = pbar_dl_size
         yield
 
-  def download(self, url: str, destination_path: str, verify: bool = True):
+  def increase_tqdm(self, dl_result: DownloadResult) -> None:
+    """Update the tqdm bars to visually indicate the dl_result is downloaded."""
+    self._pbar_url.update_total(1)
+    self._pbar_url.update(1)
+    if dl_result.url_info:  # Info unknown for manually downloaded files
+      self._pbar_dl_size.update_total(dl_result.url_info.size)
+      self._pbar_dl_size.update(dl_result.url_info.size)
+
+  def download(
+      self,
+      url: str,
+      destination_path: str,
+      verify: bool = True
+  ) -> 'promise.Promise[concurrent.futures.Future[DownloadResult]]':
     """Download url to given path.
 
     Returns Promise -> sha256 of downloaded file.
@@ -144,28 +161,32 @@ class _Downloader(object):
     Returns:
       Promise obj -> (`str`, int): (downloaded object checksum, size in bytes).
     """
+    destination_path = os.fspath(destination_path)
     self._pbar_url.update_total(1)
-    future = self._executor.submit(
-        self._sync_download, url, destination_path, verify)
+    future = self._executor.submit(self._sync_download, url, destination_path,
+                                   verify)
     return promise.Promise.resolve(future)
 
   def _sync_file_copy(
-      self, filepath: str, destination_path: str) -> checksums_lib.UrlInfo:
+      self,
+      filepath: str,
+      destination_path: str,
+  ) -> DownloadResult:
+    """Downloads the file through `tf.io.gfile` API."""
     filename = os.path.basename(filepath)
     out_path = os.path.join(destination_path, filename)
     tf.io.gfile.copy(filepath, out_path)
-    hexdigest, size = utils.read_checksum_digest(
-        out_path, checksum_cls=self._checksumer_cls
-    )
-    return checksums_lib.UrlInfo(
-        checksum=hexdigest,
-        size=size,
-        filename=filename,
-    )
+    url_info = checksums_lib.compute_url_info(
+        out_path, checksum_cls=self._checksumer_cls)
+    self._pbar_dl_size.update_total(url_info.size)
+    self._pbar_dl_size.update(url_info.size)
+    self._pbar_url.update(1)
+    return DownloadResult(path=utils.as_path(out_path), url_info=url_info)
 
-  def _sync_download(
-      self, url: str, destination_path: str, verify: bool = True
-      ) -> checksums_lib.UrlInfo:
+  def _sync_download(self,
+                     url: str,
+                     destination_path: str,
+                     verify: bool = True) -> DownloadResult:
     """Synchronous version of `download` method.
 
     To download through a proxy, the `HTTP_PROXY`, `HTTPS_PROXY`,
@@ -215,10 +236,13 @@ class _Downloader(object):
             self._pbar_dl_size.update(size_mb // unit_mb)
             size_mb %= unit_mb
     self._pbar_url.update(1)
-    return checksums_lib.UrlInfo(
-        checksum=checksum.hexdigest(),
-        size=size,
-        filename=fname,
+    return DownloadResult(
+        path=utils.as_path(path),
+        url_info=checksums_lib.UrlInfo(
+            checksum=checksum.hexdigest(),
+            size=utils.Size(size),
+            filename=fname,
+        ),
     )
 
 
