@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,18 +23,18 @@ import itertools
 import json
 import os
 import re
-from typing import Any
+from typing import Any, Optional
 
 from six.moves import urllib
 import tensorflow.compat.v2 as tf
 
+from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.download import checksums as checksums_lib
-from tensorflow_datasets.core.utils import py_utils
+from tensorflow_datasets.core.utils import type_utils
 
 # Should be `Union[int, float, bool, str, Dict[str, Json], List[Json]]`
 Json = Any
 
-
 _hex_codec = codecs.getdecoder('hex_codec')
 
 
@@ -63,9 +63,9 @@ _EXTRACTION_METHOD_TO_EXTS = [
     (ExtractMethod.BZIP2, ['.bz2']),
 ]
 
-_KNOWN_EXTENSIONS = [
-    ext_ for ext_ in itertools.chain(  # pylint: disable=g-complex-comprehension
-        *[extensions_ for _, extensions_ in _EXTRACTION_METHOD_TO_EXTS])]
+_KNOWN_EXTENSIONS = list(
+    itertools.chain(  # pylint: disable=g-complex-comprehension
+        *[extensions_ for _, extensions_ in _EXTRACTION_METHOD_TO_EXTS]))
 
 _NETLOC_COMMON_PREFIXES = [
     'www.',
@@ -195,26 +195,26 @@ def get_dl_dirname(url):
   return get_dl_fname(url, checksum)
 
 
-def _get_info_path(path):
+def _get_info_path(path: type_utils.PathLike) -> str:
   """Returns path (`str`) of INFO file associated with resource at path."""
-  return '%s.INFO' % path
+  return '%s.INFO' % os.fspath(path)
 
 
-def _read_info(info_path) -> Json:
+def _read_info(info_path: type_utils.PathLike) -> Json:
   """Returns info dict or None."""
-  if not tf.io.gfile.exists(info_path):
+  if not tf.io.gfile.exists(os.fspath(info_path)):
     return None
-  with tf.io.gfile.GFile(info_path) as info_f:
+  with tf.io.gfile.GFile(os.fspath(info_path)) as info_f:
     return json.load(info_f)
 
 
 # TODO(pierrot): one lock per info path instead of locking everything.
-synchronize_decorator = py_utils.build_synchronize_decorator()
+synchronize_decorator = utils.build_synchronize_decorator()
 
 
 def rename_info_file(
-    src_path: str,
-    dst_path: str,
+    src_path: type_utils.PathLike,
+    dst_path: type_utils.PathLike,
     overwrite: bool = False,
 ) -> None:
   tf.io.gfile.rename(
@@ -222,14 +222,14 @@ def rename_info_file(
 
 
 @synchronize_decorator
-def read_info_file(info_path: str) -> Json:
+def read_info_file(info_path: type_utils.PathLike) -> Json:
   return _read_info(_get_info_path(info_path))
 
 
 @synchronize_decorator
 def write_info_file(
-    resource: 'Resource',
-    path: str,
+    url: str,
+    path: type_utils.PathLike,
     dataset_name: str,
     original_fname: str,
     url_info: checksums_lib.UrlInfo,
@@ -241,7 +241,7 @@ def write_info_file(
   data (`dataset_name`) is only for human consumption.
 
   Args:
-    resource: resource for which to write the INFO file.
+    url: Url for which to write the INFO file.
     path: path of downloaded file.
     dataset_name: data used to dl the file.
     original_fname: name of file as downloaded.
@@ -250,7 +250,7 @@ def write_info_file(
   url_info_dict = url_info.asdict()
   info_path = _get_info_path(path)
   info = _read_info(info_path) or {}
-  urls = set(info.get('urls', []) + [resource.url])
+  urls = set(info.get('urls', []) + [url])
   dataset_names = info.get('dataset_names', [])
   if dataset_name:
     dataset_names.append(dataset_name)
@@ -261,20 +261,21 @@ def write_info_file(
   if info.get('url_info', url_info_dict) != url_info_dict:
     raise ValueError(
         'File info {} contains a different checksum that the downloaded one: '
-        'Stored: {}; Expected: {}'.format(
-            info_path, info['url_info'], url_info_dict))
+        'Stored: {}; Expected: {}'.format(info_path, info['url_info'],
+                                          url_info_dict))
   info = dict(
       urls=list(urls),
       dataset_names=list(set(dataset_names)),
       original_fname=original_fname,
       url_info=url_info_dict,
   )
-  with py_utils.atomic_write(info_path, 'w') as info_f:
+  with utils.atomic_write(info_path, 'w') as info_f:
     json.dump(info, info_f, sort_keys=True)
 
 
-def get_extract_method(path):
+def get_extract_method(path: type_utils.PathLike):
   """Returns `ExtractMethod` to use on resource at path. Cannot be None."""
+  path = os.fspath(path)
   info_path = _get_info_path(path)
   info = _read_info(info_path)
   fname = info.get('original_fname', path) if info else path
@@ -284,31 +285,33 @@ def get_extract_method(path):
 class Resource(object):
   """Represents a resource to download, extract, or both."""
 
-  def __init__(self,
-               *,
-               url=None,
-               extract_method=None,
-               path=None):
+  def __init__(
+      self,
+      *,
+      url: Optional[str] = None,
+      extract_method: Optional[ExtractMethod] = None,
+      path: Optional[type_utils.PathLike] = None,
+  ):
     """Resource constructor.
 
     Args:
       url: `str`, the URL at which to download the resource.
-      extract_method: `ExtractMethod` to be used to extract resource. If
-        not set, will be guessed from downloaded file name `original_fname`.
+      extract_method: `ExtractMethod` to be used to extract resource. If not
+        set, will be guessed from downloaded file name `original_fname`.
       path: `str`, path of resource on local disk. Can be None if resource has
         not be downloaded yet. In such case, `url` must be set.
     """
     self.url = url
-    self.path = path
+    self.path: utils.ReadWritePath = utils.as_path(path) if path else None
     self._extract_method = extract_method
 
   @classmethod
-  def exists_locally(cls, path):
+  def exists_locally(cls, path: type_utils.PathLike):
     """Returns whether the resource exists locally, at `resource.path`."""
     # If INFO file doesn't exist, consider resource does NOT exist, as it would
     # prevent guessing the `extract_method`.
-    return (tf.io.gfile.exists(path) and
-            tf.io.gfile.exists(_get_info_path(path)))
+    path = os.fspath(path)
+    return tf.io.gfile.exists(path) and tf.io.gfile.exists(_get_info_path(path))
 
   @property
   def extract_method(self):
