@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for tensorflow_datasets.core.example_serializer."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import numpy as np
 import tensorflow.compat.v2 as tf
 
@@ -47,11 +42,15 @@ class ExampleSerializerTest(testing.SubTestCase):
         'input': [[1, 2, 3], [], [4, 5]],
     }
     tensor_info = {
-        'input': feature_lib.TensorInfo(
-            shape=(None, None,),
-            dtype=tf.int64,
-            sequence_rank=2,
-        ),
+        'input':
+            feature_lib.TensorInfo(
+                shape=(
+                    None,
+                    None,
+                ),
+                dtype=tf.int64,
+                sequence_rank=2,
+            ),
     }
     ex_proto = example_serializer._dict_to_tf_example(example_data, tensor_info)
     feature = ex_proto.features.feature
@@ -69,19 +68,25 @@ class ExampleSerializerTest(testing.SubTestCase):
         'input': [],
     }
     tensor_info = {
-        'input': feature_lib.TensorInfo(
-            shape=(None, None,),
-            dtype=tf.int64,
-            sequence_rank=2,
-        ),
+        'input':
+            feature_lib.TensorInfo(
+                shape=(
+                    None,
+                    None,
+                ),
+                dtype=tf.int64,
+                sequence_rank=2,
+            ),
     }
     ex_proto = example_serializer._dict_to_tf_example(example_data, tensor_info)
     feature = ex_proto.features.feature
     self.assertEqual(
-        [], list(feature['input/ragged_flat_values'].int64_list.value),
+        [],
+        list(feature['input/ragged_flat_values'].int64_list.value),
     )
     self.assertEqual(
-        [], list(feature['input/ragged_row_lengths_0'].int64_list.value),
+        [],
+        list(feature['input/ragged_row_lengths_0'].int64_list.value),
     )
 
   def test_add_ragged_fields(self):
@@ -92,18 +97,22 @@ class ExampleSerializerTest(testing.SubTestCase):
         [4, 5],
     ]
     tensor_info = feature_lib.TensorInfo(
-        shape=(None, None,), dtype=tf.int64, sequence_rank=2)
+        shape=(
+            None,
+            None,
+        ), dtype=tf.int64, sequence_rank=2)
     out = example_serializer._add_ragged_fields(example_data, tensor_info)
-    self.assertRaggedFieldEqual(out, {
-        'ragged_flat_values': (
-            np.array([1, 2, 3, 4, 5]),
-            feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
-        ),
-        'ragged_row_lengths_0': (
-            [3, 0, 2],
-            feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
-        ),
-    })
+    self.assertRaggedFieldEqual(
+        out, {
+            'ragged_flat_values': (
+                np.array([1, 2, 3, 4, 5]),
+                feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
+            ),
+            'ragged_row_lengths_0': (
+                [3, 0, 2],
+                feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
+            ),
+        })
 
   def test_add_ragged_fields_np(self):
     # List of np.array.
@@ -113,18 +122,22 @@ class ExampleSerializerTest(testing.SubTestCase):
         np.array([4, 5], dtype=np.int64),
     ]
     tensor_info = feature_lib.TensorInfo(
-        shape=(None, None,), dtype=tf.int64, sequence_rank=2)
+        shape=(
+            None,
+            None,
+        ), dtype=tf.int64, sequence_rank=2)
     out = example_serializer._add_ragged_fields(example_data, tensor_info)
-    self.assertRaggedFieldEqual(out, {
-        'ragged_flat_values': (
-            np.array([1, 2, 3, 4, 5]),
-            feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
-        ),
-        'ragged_row_lengths_0': (
-            [3, 0, 2],
-            feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
-        ),
-    })
+    self.assertRaggedFieldEqual(
+        out, {
+            'ragged_flat_values': (
+                np.array([1, 2, 3, 4, 5]),
+                feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
+            ),
+            'ragged_row_lengths_0': (
+                [3, 0, 2],
+                feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
+            ),
+        })
 
   def test_add_ragged_fields_empty_np(self):
     # List of np.array.
@@ -133,56 +146,64 @@ class ExampleSerializerTest(testing.SubTestCase):
         np.array([], dtype=np.int64),
     ]
     tensor_info = feature_lib.TensorInfo(
-        shape=(None, None,), dtype=tf.int64, sequence_rank=2)
+        shape=(
+            None,
+            None,
+        ), dtype=tf.int64, sequence_rank=2)
     out = example_serializer._add_ragged_fields(example_data, tensor_info)
-    self.assertRaggedFieldEqual(out, {
-        'ragged_flat_values': (
-            np.zeros(shape=(0,), dtype=np.int64),
-            feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
-        ),
-        'ragged_row_lengths_0': (
-            [0, 0],
-            feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
-        ),
-    })
+    self.assertRaggedFieldEqual(
+        out, {
+            'ragged_flat_values': (
+                np.zeros(shape=(0,), dtype=np.int64),
+                feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
+            ),
+            'ragged_row_lengths_0': (
+                [0, 0],
+                feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
+            ),
+        })
 
   def test_add_ragged_fields_empty(self):
     # List of empty values
-    example_data = [
-        [],
-        [],
-        []
-    ]
+    example_data = [[], [], []]
     tensor_info = feature_lib.TensorInfo(
-        shape=(None, None,), dtype=tf.int64, sequence_rank=2)
+        shape=(
+            None,
+            None,
+        ), dtype=tf.int64, sequence_rank=2)
     out = example_serializer._add_ragged_fields(example_data, tensor_info)
-    self.assertRaggedFieldEqual(out, {
-        'ragged_flat_values': (
-            np.zeros(shape=(0,), dtype=np.int64),
-            feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
-        ),
-        'ragged_row_lengths_0': (
-            [0, 0, 0],
-            feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
-        ),
-    })
+    self.assertRaggedFieldEqual(
+        out, {
+            'ragged_flat_values': (
+                np.zeros(shape=(0,), dtype=np.int64),
+                feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
+            ),
+            'ragged_row_lengths_0': (
+                [0, 0, 0],
+                feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
+            ),
+        })
 
   def test_add_ragged_fields_all_empty(self):
     # Empty list
     example_data = []
     tensor_info = feature_lib.TensorInfo(
-        shape=(None, None,), dtype=tf.int64, sequence_rank=2)
+        shape=(
+            None,
+            None,
+        ), dtype=tf.int64, sequence_rank=2)
     out = example_serializer._add_ragged_fields(example_data, tensor_info)
-    self.assertRaggedFieldEqual(out, {
-        'ragged_flat_values': (
-            np.zeros(shape=(0,), dtype=np.int64),
-            feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
-        ),
-        'ragged_row_lengths_0': (
-            np.zeros(shape=(0,), dtype=np.int64),
-            feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
-        ),
-    })
+    self.assertRaggedFieldEqual(
+        out, {
+            'ragged_flat_values': (
+                np.zeros(shape=(0,), dtype=np.int64),
+                feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
+            ),
+            'ragged_row_lengths_0': (
+                np.zeros(shape=(0,), dtype=np.int64),
+                feature_lib.TensorInfo(shape=(None,), dtype=tf.int64),
+            ),
+        })
 
   def test_add_ragged_fields_single_level_sequence(self):
     # Single level sequence
@@ -192,7 +213,10 @@ class ExampleSerializerTest(testing.SubTestCase):
         [4, 5],
     ]
     tensor_info = feature_lib.TensorInfo(
-        shape=(None, 2,), dtype=tf.int64, sequence_rank=1)
+        shape=(
+            None,
+            2,
+        ), dtype=tf.int64, sequence_rank=1)
     out = example_serializer._add_ragged_fields(example_data, tensor_info)
     self.assertAllEqual(out[0], [
         [1, 2],
@@ -227,9 +251,8 @@ class ExampleSerializerTest(testing.SubTestCase):
             dtype=tf.int64,
         ),
     }
-    with self.assertRaisesRegex(
-        ValueError, 'Error while serializing feature `input`:'
-    ):
+    with self.assertRaisesRegex(ValueError,
+                                'Error while serializing feature `input`:'):
       example_serializer._dict_to_tf_example(example_data, tensor_info)
 
 
