@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,18 +17,21 @@
 
 import abc
 import collections
+import functools
+import html
+import importlib
 import json
 import os
-from typing import Dict, Type, TypeVar
+from typing import Dict, List, Type, TypeVar
 
 import numpy as np
 import six
 import tensorflow.compat.v2 as tf
 
-from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.utils import type_utils
 
 Json = type_utils.Json
+Shape = type_utils.Shape
 
 T = TypeVar('T', bound='FeatureConnector')
 
@@ -36,9 +39,16 @@ T = TypeVar('T', bound='FeatureConnector')
 class TensorInfo(object):
   """Structure containing info on the `tf.Tensor` shape/dtype."""
 
-  __slots__ = ['shape', 'dtype', 'default_value', 'sequence_rank']
+  __slots__ = [
+      'shape', 'dtype', 'default_value', 'sequence_rank', 'dataset_lvl'
+  ]
 
-  def __init__(self, shape, dtype, default_value=None, sequence_rank=None):
+  def __init__(self,
+               shape,
+               dtype,
+               default_value=None,
+               sequence_rank=None,
+               dataset_lvl=0):
     """Constructor.
 
     Args:
@@ -47,11 +57,13 @@ class TensorInfo(object):
       default_value: Used for retrocompatibility with previous files if a new
         field is added to provide a default value when reading the file.
       sequence_rank: `int`, Number of `tfds.features.Sequence` dimension.
+      dataset_lvl: `int`, if >0, nesting level of a `tfds.features.Dataset`.
     """
     self.shape = shape
     self.dtype = dtype
     self.default_value = default_value
     self.sequence_rank = sequence_rank or 0
+    self.dataset_lvl = dataset_lvl
 
   @classmethod
   def copy_from(cls, tensor_info):
@@ -61,15 +73,13 @@ class TensorInfo(object):
         dtype=tensor_info.dtype,
         default_value=tensor_info.default_value,
         sequence_rank=tensor_info.sequence_rank,
+        dataset_lvl=tensor_info.dataset_lvl,
     )
 
   def __eq__(self, other):
     """Equality."""
-    return (
-        self.shape == other.shape and
-        self.dtype == other.dtype and
-        self.default_value == other.default_value
-    )
+    return (self.shape == other.shape and self.dtype == other.dtype and
+            self.default_value == other.default_value)
 
   def __repr__(self):
     return '{}(shape={}, dtype={})'.format(
@@ -99,11 +109,21 @@ class FeatureConnector(object):
   """
 
   # Keep track of all sub-classes.
-  _registered_features: Dict[str, 'FeatureConnector'] = {}
+  _registered_features: Dict[str, Type['FeatureConnector']] = {}
+
+  # FeatureConnector use the module name to reconstruct/reload the features in
+  # `features = FeatureConnector.from_config('features.json')`
+  # For backward compatibility, after renaming/moving/ `my_feature.py` to a new
+  # location, it is possible to specify the previous `module.MyFeature` names.
+  ALIASES: List[str] = []
 
   def __init_subclass__(cls):
     """Registers subclasses features."""
     cls._registered_features[f'{cls.__module__}.{cls.__name__}'] = cls
+    # Also register the aliases. Note: We use __dict__ to make sure the alias
+    # is only registered for the class. Not it's child.
+    for module_alias in cls.__dict__.get('ALIASES', []):
+      cls._registered_features[module_alias] = cls
 
   @abc.abstractmethod
   def get_tensor_info(self):
@@ -163,18 +183,31 @@ class FeatureConnector(object):
     ```
 
     Args:
-      value: `dict(type=, content=)` containing the feature to restore.
-        Match dict returned by `to_json`.
+      value: `dict(type=, content=)` containing the feature to restore. Match
+        dict returned by `to_json`.
 
     Returns:
       The reconstructed FeatureConnector.
     """
-    subclass = cls._registered_features.get(value['type'])
+    feature_qualname = value['type']  # my_project.xyz.MyFeature
+    err_msg = f'Unrecognized FeatureConnector type: {feature_qualname}.\n'
+
+    # Dynamically import custom feature-connectors
+    if feature_qualname not in cls._registered_features:
+      # Split `my_project.xyz.MyFeature` -> (`my_project.xyz`, `MyFeature`)
+      module_name, _ = feature_qualname.rsplit('.', maxsplit=1)  # pytype: disable=attribute-error
+      try:
+        # Import to register the FeatureConnector
+        importlib.import_module(module_name)
+      except ImportError:
+        raise ValueError(
+            f'{err_msg}Could not import {module_name}. You might have to '
+            'install additional dependencies.')
+
+    subclass = cls._registered_features.get(feature_qualname)
     if subclass is None:
-      raise ValueError(
-          f'Unrecognized FeatureConnector type: {value["type"]}\n'
-          f'Supported: {list(cls._registered_features)}'
-      )
+      raise ValueError(f'{err_msg}Supported: {list(cls._registered_features)}')
+
     return subclass.from_json_content(value['content'])
 
   def to_json(self) -> Json:
@@ -212,7 +245,8 @@ class FeatureConnector(object):
                 }
             },
             "target": {
-                "type": "tensorflow_datasets.core.features.class_label_feature.ClassLabel",
+                "type":
+                "tensorflow_datasets.core.features.class_label_feature.ClassLabel",
                 "num_classes": 10
             }
         }
@@ -405,26 +439,45 @@ class FeatureConnector(object):
     overwrite this method to apply a custom batch decoding.
 
     Args:
-      tfexample_data: Same `tf.Tensor` inputs as `decode_example`, but with
-        and additional first dimension for the sequence length.
+      tfexample_data: Same `tf.Tensor` inputs as `decode_example`, but with and
+        additional first dimension for the sequence length.
 
     Returns:
       tensor_data: Tensor or dictionary of tensor, output of the tf.data.Dataset
         object
     """
+    ex = tfexample_data
+
     # Note: This all works fine in Eager mode (without tf.function) because
     # tf.data pipelines are always executed in Graph mode.
 
     # Apply the decoding to each of the individual distributed features.
-    return tf.map_fn(
+    decode_map_fn = functools.partial(
+        tf.map_fn,
         self.decode_example,
-        tfexample_data,
         fn_output_signature=self.dtype,
         parallel_iterations=10,
-        back_prop=False,
         name='sequence_decode',
     )
 
+    if (
+        # input/output could potentially be a `dict` for custom feature
+        # connectors. Empty length not supported for those for now.
+        isinstance(ex, dict) or isinstance(self.shape, dict) or
+        not _has_shape_ambiguity(in_shape=ex.shape, out_shape=self.shape)):
+      return decode_map_fn(ex)
+    else:
+      # `tf.map_fn` cannot resolve ambiguity when decoding an empty sequence
+      # with unknown output shape (e.g. decode images `tf.string`):
+      # `(0,)` -> `(0, None, None, 3)`.
+      # Instead, we arbitrarily set unknown shape to `0`:
+      # `(0,)` -> `(0, 0, 0, 3)`
+      return tf.cond(
+          tf.equal(tf.shape(ex)[0], 0),  # Empty sequence
+          lambda: _make_empty_seq_output(shape=self.shape, dtype=self.dtype),
+          lambda: decode_map_fn(ex),
+      )
+
   def decode_ragged_example(self, tfexample_data):
     """Decode nested features from a tf.RaggedTensor.
 
@@ -450,7 +503,20 @@ class FeatureConnector(object):
 
   def repr_html_batch(self, ex: np.ndarray) -> str:
     """Returns the HTML str representation of the object (Sequence)."""
-    return _repr_html(ex)
+    _MAX_SUB_ROWS = 7  # pylint: disable=invalid-name
+    if isinstance(ex, tf.RaggedTensor):  # e.g. `Sequence(Video())`
+      return _repr_html(ex)
+    # Truncate sequences which contains too many sub-examples
+    if len(ex) > _MAX_SUB_ROWS:
+      ex = ex[:_MAX_SUB_ROWS]
+      overflow = ['...']
+    else:
+      overflow = []
+    batch_ex = '<br/>'.join([self.repr_html(x) for x in ex] + overflow)
+    # TODO(tfds): How to limit the max-height to the neighboors cells ?
+    return (
+        f'<div style="overflow-y: scroll; max-height: 300px;" >{batch_ex}</div>'
+    )
 
   def repr_html_ragged(self, ex: np.ndarray) -> str:
     """Returns the HTML str representation of the object (Nested sequence)."""
@@ -493,7 +559,7 @@ class FeatureConnector(object):
 
     Args:
       x: A nested `dict` like structure matching the structure of the
-      `FeatureConnector`. Note that some elements may be missing.
+        `FeatureConnector`. Note that some elements may be missing.
 
     Returns:
       `list`: The flattened list of element of `x`. Order is guaranteed to be
@@ -528,7 +594,7 @@ class FeatureConnector(object):
     ])
     ```
 
-    Will produce the following flattened output:
+    Will produce the following nested output:
     ```
     {
         'a': None,
@@ -616,84 +682,42 @@ class FeatureConnector(object):
     pass
 
 
-class Tensor(FeatureConnector):
-  """`FeatureConnector` for generic data of arbitrary shape and type."""
-
-  def __init__(self, *, shape, dtype):
-    """Construct a Tensor feature."""
-    self._shape = tuple(shape)
-    self._dtype = dtype
-
-  def get_tensor_info(self):
-    """See base class for details."""
-    return TensorInfo(shape=self._shape, dtype=self._dtype)
-
-  def decode_batch_example(self, example_data):
-    """See base class for details."""
-    # Overwrite the `tf.map_fn`, decoding is a no-op
-    return self.decode_example(example_data)
-
-  def decode_ragged_example(self, example_data):
-    """See base class for details."""
-    # Overwrite the `tf.map_fn`, decoding is a no-op
-    return self.decode_example(example_data)
-
-  def encode_example(self, example_data):
-    """See base class for details."""
-    np_dtype = np.dtype(self.dtype.as_numpy_dtype)
-    if not isinstance(example_data, np.ndarray):
-      example_data = np.array(example_data, dtype=np_dtype)
-    # Ensure the shape and dtype match
-    if example_data.dtype != np_dtype:
-      raise ValueError('Dtype {} do not match {}'.format(
-          example_data.dtype, np_dtype))
-    utils.assert_shape_match(example_data.shape, self._shape)
-    return example_data
-
-  @classmethod
-  def from_json_content(cls, value: Json) -> 'Tensor':
-    shape = tuple(value['shape'])
-    dtype = tf.dtypes.as_dtype(value['dtype'])
-    return cls(shape=shape, dtype=dtype)
-
-  def to_json_content(self) -> Json:
-    return {
-        'shape': list(self._shape),
-        'dtype': self._dtype.name,
-    }
-
-
 def make_config_path(root_dir: str) -> str:
   """Returns the path to the features config."""
   return os.path.join(root_dir, 'features.json')
 
 
-def get_inner_feature_repr(feature):
-  """Utils which returns the object which should get printed in __repr__.
-
-  This is used in container features (Sequence, FeatureDict) to print scalar
-  Tensor in a less verbose way `Sequence(tf.int32)` rather than
-  `Sequence(Tensor(shape=(), dtype=tf.in32))`.
-
-  Args:
-    feature: The feature to dispaly
-
-  Returns:
-    Either the feature or it's inner value.
-  """
-  # We only print `tf.int32` rather than `Tensor(shape=(), dtype=tf.int32)`
-  # * For the base `Tensor` class (and not subclass).
-  # * When shape is scalar (explicit check to avoid trigger when `shape=None`).
-  if type(feature) == Tensor and feature.shape == ():  # pylint: disable=unidiomatic-typecheck,g-explicit-bool-comparison
-    return repr(feature.dtype)
-  else:
-    return repr(feature)
-
-
 def _repr_html(ex) -> str:
   """Default HTML repr."""
   if isinstance(ex, np.ndarray) and ex.size > 1:
     # Do not print individual values for array as it is slow
     # TODO(tfds): We could display a snippet, like the first/last tree items
     return f'{type(ex).__qualname__}(shape={ex.shape}, dtype={ex.dtype})'
-  return repr(ex)
+
+  # Escape symbols which might have special meaning in HTML like '<', '>'
+  return html.escape(repr(ex))
+
+
+def _has_shape_ambiguity(in_shape: Shape, out_shape: Shape) -> bool:
+  """Returns True if the shape can be an empty sequence with unknown shape."""
+  # Normalize shape if running with `tf.compat.v1.disable_v2_tensorshape`
+  if isinstance(in_shape, tf.TensorShape):
+    in_shape = in_shape.as_list()  # pytype: disable=attribute-error
+
+  return bool(
+      in_shape[0] is None  # Empty sequence
+      # Unknown output shape (note that sequence length isn't present,
+      # as `self.shape` is called from the inner feature).
+      and None in out_shape)
+
+
+def _make_empty_seq_output(
+    shape: Shape,
+    dtype: tf.dtypes.DType,
+) -> tf.Tensor:
+  """Return an empty (0, *shape) `tf.Tensor` with `0` instead of `None`."""
+  if not isinstance(shape, (tuple, list)) or None not in shape:
+    raise ValueError(f'Could not construct empty output for shape: {shape}')
+  return tf.constant([],
+                     shape=[0] + [0 if d is None else d for d in shape],
+                     dtype=dtype)
