@@ -13,14 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""FeatureDict: Main feature connector container.
-"""
+"""FeatureDict: Main feature connector container."""
 
 import six
 import tensorflow.compat.v2 as tf
 
 from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.features import feature as feature_lib
+from tensorflow_datasets.core.features import tensor_feature
 from tensorflow_datasets.core.features import top_level_feature
 from tensorflow_datasets.core.utils import type_utils
 
@@ -113,8 +113,8 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
     Args:
       feature_dict (dict): Dictionary containing the feature connectors of a
         example. The keys should correspond to the data dict as returned by
-        tf.data.Dataset(). Types (tf.int32,...) and dicts will automatically
-        be converted into FeatureConnector.
+        tf.data.Dataset(). Types (tf.int32,...) and dicts will automatically be
+        converted into FeatureConnector.
 
     Raises:
       ValueError: If one of the given features is not recognized
@@ -154,7 +154,7 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
     lines = ['{}({{'.format(type(self).__name__)]
     # Add indentation
     for key, feature in sorted(list(self._feature_dict.items())):
-      feature_repr = feature_lib.get_inner_feature_repr(feature)
+      feature_repr = tensor_feature.get_inner_feature_repr(feature)
       all_sub_lines = '\'{}\': {},'.format(key, feature_repr)
       lines.extend('    ' + l for l in all_sub_lines.split('\n'))
     lines.append('})')
@@ -177,8 +177,7 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
   @classmethod
   def from_json_content(cls, value: Json) -> 'FeaturesDict':
     return cls({
-        k: feature_lib.FeatureConnector.from_json(v)
-        for k, v in value.items()
+        k: feature_lib.FeatureConnector.from_json(v) for k, v in value.items()
     })
 
   def to_json_content(self) -> Json:
@@ -196,8 +195,7 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
         example[k] = feature.encode_example(example_value)
       except Exception as e:  # pylint: disable=broad-except
         utils.reraise(
-            e, prefix=f'In <{feature.__class__.__name__}> with name "{k}":\n'
-        )
+            e, prefix=f'In <{feature.__class__.__name__}> with name "{k}":\n')
     return example
 
   def _flatten(self, x):
@@ -218,8 +216,7 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
           'this means that the provided dict structure does not match the '
           '`FeatureDict`. Please check for typos in the key names. '
           'Available keys: {}. Unrecognized keys: {}'.format(
-              list(self.keys()), list(set(x.keys()) - set(self.keys())))
-      )
+              list(self.keys()), list(set(x.keys()) - set(self.keys()))))
     return out
 
   def _nest(self, list_x):
@@ -228,7 +225,7 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
     out = {}
     for k, f in sorted(self.items()):
       offset = len(f._flatten(None))  # pylint: disable=protected-access
-      out[k] = f._nest(list_x[curr_pos:curr_pos+offset])  # pylint: disable=protected-access
+      out[k] = f._nest(list_x[curr_pos:curr_pos + offset])  # pylint: disable=protected-access
       curr_pos += offset
     if curr_pos != len(list_x):
       raise ValueError(
@@ -260,7 +257,7 @@ def to_feature(value):
   if isinstance(value, feature_lib.FeatureConnector):
     return value
   elif utils.is_dtype(value):  # tf.int32, tf.string,...
-    return feature_lib.Tensor(shape=(), dtype=tf.as_dtype(value))
+    return tensor_feature.Tensor(shape=(), dtype=tf.as_dtype(value))
   elif isinstance(value, dict):
     return FeaturesDict(value)
   else:
