@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for tensorflow_datasets.core.features.sequence_feature."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import numpy as np
 import tensorflow.compat.v2 as tf
 from tensorflow_datasets import testing
@@ -53,9 +48,15 @@ class SequenceDictFeatureTest(testing.FeatureExpectationsTestCase):
             # Array of dict
             testing.FeatureExpectationItem(
                 value=[
-                    {'int': 1},
-                    {'int': 10},
-                    {'int': 100},
+                    {
+                        'int': 1
+                    },
+                    {
+                        'int': 10
+                    },
+                    {
+                        'int': 100
+                    },
                 ],
                 expected={'int': [1, 10, 100]},
             ),
@@ -66,14 +67,16 @@ class SequenceDictFeatureTest(testing.FeatureExpectationsTestCase):
                 raise_msg='Input sequence length do not match',
             ),
         ],
-    )
+        test_attributes=dict(_length=3))
 
   def test_label(self):
 
     self.assertFeature(
-        feature=feature_lib.Sequence({
-            'label': feature_lib.ClassLabel(names=['left', 'right']),
-        }, length=None),
+        feature=feature_lib.Sequence(
+            {
+                'label': feature_lib.ClassLabel(names=['left', 'right']),
+            },
+            length=None),
         shape={'label': (None,)},
         dtype={'label': tf.int64},
         serialized_info={
@@ -95,7 +98,7 @@ class SequenceDictFeatureTest(testing.FeatureExpectationsTestCase):
                 expected={'label': []},
             ),
         ],
-    )
+        test_attributes=dict(_length=None))
 
   def test_nested(self):
 
@@ -181,60 +184,113 @@ class SequenceDictFeatureTest(testing.FeatureExpectationsTestCase):
     # Different combinaison of list of dict/dict of list to encode the same
     # nested sequence
     ex1 = f.encode_example([
-        {'a': {'c': [1, 1, 1]}, 'b': 1},
-        {'a': {'c': []}, 'b': 2},
-        {'a': {'c': [3, 3]}, 'b': 3},
+        {
+            'a': {
+                'c': [1, 1, 1]
+            },
+            'b': 1
+        },
+        {
+            'a': {
+                'c': []
+            },
+            'b': 2
+        },
+        {
+            'a': {
+                'c': [3, 3]
+            },
+            'b': 3
+        },
     ])
 
     ex2 = f.encode_example([
-        {'a': [{'c': 1}, {'c': 1}, {'c': 1}], 'b': 1},
-        {'a': [], 'b': 2},
-        {'a': [{'c': 3}, {'c': 3}], 'b': 3},
+        {
+            'a': [{
+                'c': 1
+            }, {
+                'c': 1
+            }, {
+                'c': 1
+            }],
+            'b': 1
+        },
+        {
+            'a': [],
+            'b': 2
+        },
+        {
+            'a': [{
+                'c': 3
+            }, {
+                'c': 3
+            }],
+            'b': 3
+        },
     ])
 
     ex3 = f.encode_example({
         'a': [
-            [{'c': 1}, {'c': 1}, {'c': 1}],
+            [{
+                'c': 1
+            }, {
+                'c': 1
+            }, {
+                'c': 1
+            }],
             [],
-            [{'c': 3}, {'c': 3}],
+            [{
+                'c': 3
+            }, {
+                'c': 3
+            }],
         ],
         'b': [1, 2, 3],
     })
 
     ex4 = f.encode_example({
-        'a': {'c': [[1, 1, 1], [], [3, 3]]},
+        'a': {
+            'c': [[1, 1, 1], [], [3, 3]]
+        },
         'b': [1, 2, 3],
     })
 
     out = {
-        'a': {'c': tf.ragged.constant([
-            [1, 1, 1],
-            [],
-            [3, 3],
-        ])},
+        'a': {
+            'c': tf.ragged.constant([
+                [1, 1, 1],
+                [],
+                [3, 3],
+            ])
+        },
         'b': [1, 2, 3],
     }
 
     def to_ragged(ex):
       ex['a']['c'] = tf.ragged.constant(ex['a']['c'])
       return ex
+
     self.assertAllEqualNested(to_ragged(ex1), out)
     self.assertAllEqualNested(to_ragged(ex2), out)
     self.assertAllEqualNested(to_ragged(ex3), out)
     self.assertAllEqualNested(to_ragged(ex4), out)
 
     # Should raise error if two sequences do not have the same length.
-    with self.assertRaisesWithPredicateMatch(
-        ValueError, 'length of all elements'):
+    with self.assertRaisesWithPredicateMatch(ValueError,
+                                             'length of all elements'):
       f.encode_example({
-          'a': {'c': [[1, 1, 1], []]},
+          'a': {
+              'c': [[1, 1, 1], []]
+          },
           'b': [1, 2, 3],
       })
 
     # Empty sequence should create the correct number of dimension
     ex2 = f.encode_example([])
     self.assertAllEqualNested(ex2, {
-        'a': {'c': np.zeros((0, 0), np.int64)},
+        'a': {
+            'c': np.zeros((0, 0), np.int64)
+        },
         'b': np.zeros((0,), np.int64),
     })
 
@@ -272,9 +328,7 @@ class SequenceDictFeatureTest(testing.FeatureExpectationsTestCase):
     self.assertFeature(
         feature=feature_lib.Sequence(
             feature_lib.Sequence(
-                feature_lib.Tensor(shape=(2,), dtype=tf.int32),
-            ),
-        ),
+                feature_lib.Tensor(shape=(2,), dtype=tf.int32),),),
         shape=(None, None, 2),
         dtype=tf.int32,
         tests=[
@@ -288,7 +342,8 @@ class SequenceDictFeatureTest(testing.FeatureExpectationsTestCase):
                     [[0, 1], [2, 3]],
                     [],
                     [[4, 5]],
-                ], inner_shape=(2,)),
+                ],
+                                                inner_shape=(2,)),
             ),
             # Empty
             testing.FeatureExpectationItem(
@@ -337,10 +392,11 @@ class SequenceDictFeatureTest(testing.FeatureExpectationsTestCase):
   def test_2lvl_sequences_string(self):
 
     self.assertFeature(
-        feature=feature_lib.Sequence(
-            feature_lib.Sequence(tf.string),
+        feature=feature_lib.Sequence(feature_lib.Sequence(tf.string),),
+        shape=(
+            None,
+            None,
         ),
-        shape=(None, None,),
         dtype=tf.string,
         tests=[
             testing.FeatureExpectationItem(
@@ -384,8 +440,7 @@ class SequenceDictFeatureTest(testing.FeatureExpectationsTestCase):
             feature_lib.Sequence(
                 feature_lib.Sequence(tf.int32),
                 length=3,
-            ),
-        ),
+            ),),
         shape=(None, 3, None),
         dtype=tf.int32,
         tests=[
@@ -421,14 +476,17 @@ class SequenceDictFeatureTest(testing.FeatureExpectationsTestCase):
     imgs_stacked = np.stack(imgs)
 
     self.assertFeature(
-        feature=feature_lib.Sequence({
-            'image': feature_lib.Image(shape=(128, 100, 3)),
-        }, length=None),
+        feature=feature_lib.Sequence(
+            {
+                'image': feature_lib.Image(shape=(128, 100, 3)),
+            }, length=None),
         shape={'image': (None, 128, 100, 3)},
         dtype={'image': tf.uint8},
         tests=[
             testing.FeatureExpectationItem(
-                value=[{'image': img} for img in imgs],
+                value=[{
+                    'image': img
+                } for img in imgs],
                 expected={'image': imgs_stacked},
             ),
             testing.FeatureExpectationItem(
@@ -443,10 +501,9 @@ class SequenceDictFeatureTest(testing.FeatureExpectationsTestCase):
             testing.FeatureExpectationItem(
                 value={'image': []},
                 # The empty value still has the right shape
-                expected={'image': np.empty(
-                    shape=(0, 128, 100, 3),
-                    dtype=np.uint8
-                )},
+                expected={
+                    'image': np.empty(shape=(0, 128, 100, 3), dtype=np.uint8)
+                },
             ),
         ],
     )
@@ -486,8 +543,7 @@ class SequenceFeatureTest(testing.FeatureExpectationsTestCase):
 
     self.assertFeature(
         feature=feature_lib.Sequence(
-            feature_lib.ClassLabel(names=['left', 'right']),
-        ),
+            feature_lib.ClassLabel(names=['left', 'right']),),
         shape=(None,),
         dtype=tf.int64,
         tests=[
@@ -508,10 +564,77 @@ class SequenceFeatureTest(testing.FeatureExpectationsTestCase):
         ],
     )
 
+  def test_image_unknown_len(self):
+
+    imgs = [
+        np.random.randint(256, size=(28, 28, 3), dtype=np.uint8),
+        np.random.randint(256, size=(28, 28, 3), dtype=np.uint8),
+    ]
+    imgs_stacked = np.stack(imgs)
+
+    self.assertFeature(
+        feature=feature_lib.Sequence(feature_lib.Image(shape=(None, None, 3))),
+        dtype=tf.uint8,
+        shape=(None, None, None, 3),  # (length, h, w, c)
+        tests=[
+            testing.FeatureExpectationItem(
+                value=[],  # Empty input
+                expected=np.empty(shape=(0, 0, 0, 3), dtype=np.uint8),
+            ),
+            testing.FeatureExpectationItem(
+                value=imgs,
+                expected=imgs_stacked,
+            ),
+        ],
+    )
+
+  def test_image_nested_empty_len(self):
+    imgs = [
+        np.random.randint(256, size=(28, 28, 3), dtype=np.uint8),
+        np.random.randint(256, size=(28, 28, 3), dtype=np.uint8),
+    ]
+    imgs_stacked = np.stack(imgs)
+
+    self.assertFeature(
+        feature=feature_lib.Sequence({
+            'a': feature_lib.Image(shape=(None, None, 3)),
+            'b': tf.int32,
+        }),
+        shape={
+            'a': (None, None, None, 3),
+            'b': (None,),
+        },
+        dtype={
+            'a': tf.uint8,
+            'b': tf.int32,
+        },
+        tests=[
+            testing.FeatureExpectationItem(
+                value={
+                    'a': imgs,
+                    'b': [1, 2],
+                },
+                expected={
+                    'a': imgs_stacked,
+                    'b': [1, 2],
+                },
+            ),
+            testing.FeatureExpectationItem(
+                value={
+                    'a': [],
+                    'b': [],
+                },
+                expected={
+                    'a': np.empty(shape=(0, 0, 0, 3), dtype=np.uint8),
+                    'b': [],
+                },
+            ),
+        ],
+    )
+
   def test_getattr(self):
     feature = feature_lib.Sequence(
-        feature_lib.ClassLabel(names=['left', 'right']),
-    )
+        feature_lib.ClassLabel(names=['left', 'right']),)
     self.assertEqual(feature.names, ['left', 'right'])
 
     feature = feature_lib.Sequence({
