@@ -72,8 +72,7 @@ class TextFeatureTest(testing.FeatureExpectationsTestCase):
                 expected=[],
             ),
         ],
-        skip_feature_tests=True
-    )
+        skip_feature_tests=True)
 
   def test_text_conversion(self):
     text_f = features.Text(encoder=text_encoder.ByteTextEncoder())
