@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,10 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Custom Datasets APIs."""
+"""Utils to load data comming from third party sources directly with TFDS."""
 
 from tensorflow_datasets.core import registered
 
+from tensorflow_datasets.core.folder_dataset.compute_split_utils import compute_split_info
+from tensorflow_datasets.core.folder_dataset.write_metadata_utils import write_metadata
+
 # Custom datasets cannot be instanciated through `tfds.load`
 with registered.skip_registration():
   # pylint: disable=g-import-not-at-top
@@ -24,8 +27,9 @@ with registered.skip_registration():
   from tensorflow_datasets.core.folder_dataset.translate_folder import TranslateFolder
   # pylint: enable=g-import-not-at-top
 
-
 __all__ = [
+    "compute_split_info",
     "ImageFolder",
     "TranslateFolder",
+    "write_metadata",
 ]
