@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,10 +15,14 @@
 
 """Lazy imports for heavy dependencies."""
 
+import functools
 import importlib
+from typing import TypeVar
 
 from tensorflow_datasets.core.utils import py_utils as utils
 
+_Fn = TypeVar("_Fn")
+
 
 def _try_import(module_name):
   """Try importing a module, with an informative error message on failure."""
@@ -46,6 +50,11 @@ class LazyImporter(object):
   def apache_beam(cls):
     return _try_import("apache_beam")
 
+  @utils.classproperty
+  @classmethod
+  def bs4(cls):
+    return _try_import("bs4")
+
   @utils.classproperty
   @classmethod
   def crepe(cls):
@@ -54,7 +63,7 @@ class LazyImporter(object):
   @utils.classproperty
   @classmethod
   def cv2(cls):
-    return _try_import("cv2")  # pylint: disable=unreachable
+    return _try_import("cv2")
 
   @utils.classproperty
   @classmethod
@@ -76,6 +85,11 @@ class LazyImporter(object):
   def librosa(cls):
     return _try_import("librosa")
 
+  @utils.classproperty
+  @classmethod
+  def lxml(cls):
+    return _try_import("lxml")
+
   @utils.classproperty
   @classmethod
   def matplotlib(cls):
@@ -87,6 +101,11 @@ class LazyImporter(object):
   def mwparserfromhell(cls):
     return _try_import("mwparserfromhell")
 
+  @utils.classproperty
+  @classmethod
+  def networkx(cls):
+    return _try_import("networkx")
+
   @utils.classproperty
   @classmethod
   def nltk(cls):
@@ -105,11 +124,21 @@ class LazyImporter(object):
     _try_import("PIL.TiffImagePlugin")
     return _try_import("PIL.Image")
 
+  @utils.classproperty
+  @classmethod
+  def PIL_ImageDraw(cls):  # pylint: disable=invalid-name
+    return _try_import("PIL.ImageDraw")
+
   @utils.classproperty
   @classmethod
   def pretty_midi(cls):
     return _try_import("pretty_midi")
 
+  @utils.classproperty
+  @classmethod
+  def pycocotools(cls):
+    return _try_import("pycocotools.mask")
+
   @utils.classproperty
   @classmethod
   def pydub(cls):
@@ -154,6 +183,7 @@ class LazyImporter(object):
   def tldextract(cls):
     return _try_import("tldextract")
 
+
   @utils.classproperty
   @classmethod
   def os(cls):
@@ -168,3 +198,19 @@ class LazyImporter(object):
 
 
 lazy_imports = LazyImporter  # pylint: disable=invalid-name
+
+
+def beam_ptransform_fn(fn: _Fn) -> _Fn:
+  """Lazy version of `@beam.ptransform_fn`."""
+
+  lazy_decorated_fn = None
+
+  @functools.wraps(fn)
+  def decorated(*args, **kwargs):
+    nonlocal lazy_decorated_fn
+    # Actually decorate the function only the first time it is called
+    if lazy_decorated_fn is None:
+      lazy_decorated_fn = lazy_imports.apache_beam.ptransform_fn(fn)
+    return lazy_decorated_fn(*args, **kwargs)
+
+  return decorated
