@@ -22,6 +22,7 @@ import inspect
 from typing import ClassVar, Iterator, List, Type
 
 from tensorflow_datasets.core import naming
+from tensorflow_datasets.core import visibility
 from tensorflow_datasets.core.utils import py_utils
 
 # Internal registry containing <str registered_name, DatasetBuilder subclass>
@@ -37,7 +38,6 @@ _ABSTRACT_DATASET_REGISTRY = {}
 _MODULE_TO_DATASETS = collections.defaultdict(list)
 
 
-
 class DatasetNotFoundError(ValueError):
   """Exception raised when the dataset cannot be found."""
 
@@ -92,8 +92,7 @@ class RegisteredDataset(abc.ABC):
       raise ValueError(f'Dataset with name {cls.name} already registered.')
     elif cls.name in _ABSTRACT_DATASET_REGISTRY:
       raise ValueError(
-          f'Dataset with name {cls.name} already registered as abstract.'
-      )
+          f'Dataset with name {cls.name} already registered as abstract.')
 
     # Add the dataset to the registers
     if is_abstract:
@@ -102,9 +101,17 @@ class RegisteredDataset(abc.ABC):
       _DATASET_REGISTRY[cls.name] = cls
 
 
+def _is_builder_available(builder_cls: Type[RegisteredDataset]) -> bool:
+  """Returns `True` is the builder is available."""
+  return visibility.DatasetType.TFDS_PUBLIC.is_available()
+
+
 def list_imported_builders() -> List[str]:
   """Returns the string names of all `tfds.core.DatasetBuilder`s."""
-  all_builders = list(_DATASET_REGISTRY)
+  all_builders = [
+      builder_name for builder_name, builder_cls in _DATASET_REGISTRY.items()
+      if _is_builder_available(builder_cls)
+  ]
   return sorted(all_builders)
 
 
@@ -117,6 +124,13 @@ def imported_builder_cls(name: str) -> Type[RegisteredDataset]:
     # Alternativelly, could manually extract the list of non-implemented
     # abstract methods.
     raise AssertionError(f'Dataset {name} is an abstract class.')
+
   if name not in _DATASET_REGISTRY:
     raise DatasetNotFoundError(f'Dataset {name} not found.')
-  return _DATASET_REGISTRY[name]  # pytype: disable=bad-return-type
+
+  builder_cls = _DATASET_REGISTRY[name]
+  if not _is_builder_available(builder_cls):
+    available_types = visibility.get_availables()
+    msg = f'Dataset {name} is not available. Only: {available_types}'
+    raise PermissionError(msg)
+  return builder_cls  # pytype: disable=bad-return-type
