@@ -33,10 +33,18 @@ from tensorflow_datasets.core import tfrecords_writer
 from tensorflow_datasets.core.utils import read_config as read_config_lib
 from tensorflow_datasets.core.utils import shard_utils
 
-
 # Skip the cardinality test for backward compatibility with TF <= 2.1.
 _SKIP_CARDINALITY_TEST = not hasattr(tf.data.experimental, 'assert_cardinality')
 
+_SHUFFLE_FILES_ERROR_MESSAGE = ('Dataset is an ordered dataset '
+                                '(\'disable_shuffling=True\'), but examples '
+                                'will not be read in order because '
+                                '`shuffle_files=True`.')
+_CYCLE_LENGTH_ERROR_MESSAGE = ('Dataset is an ordered dataset '
+                               '(\'disable_shuffling=True\'), but examples will'
+                               ' not be read in order because '
+                               '`ReadConfig.interleave_cycle_length != 1`.')
+
 
 def _write_tfrecord_from_shard_spec(shard_spec, get):
   """Write tfrecord shard given shard_spec and buckets to read data from.
@@ -50,7 +58,7 @@ def _write_tfrecord_from_shard_spec(shard_spec, get):
   for instruction in shard_spec.file_instructions:
     iterator = get(int(instruction.filename))
     skip, take = instruction.skip, instruction.take
-    stop = skip+take if take > 0 else None
+    stop = skip + take if take > 0 else None
     iterators.append(itertools.islice(iterator, skip, stop))
   tfrecords_writer._write_examples(shard_spec.path, itertools.chain(*iterators))
 
@@ -158,19 +166,14 @@ class ReadInstructionTest(testing.TestCase):
 
   def setUp(self):
     super(ReadInstructionTest, self).setUp()
-    self.splits = {
-        'train': 200,
-        'test': 101,
-        'validation': 30,
-        'dev-train': 10
-    }
+    self.splits = {'train': 200, 'test': 101, 'validation': 30, 'dev-train': 10}
 
   def check_from_ri(self, ri, expected):
     res = ri.to_absolute(self.splits)
     expected_result = []
     for split_name, from_, to_ in expected:
-      expected_result.append(tfrecords_reader._AbsoluteInstruction(
-          split_name, from_, to_))
+      expected_result.append(
+          tfrecords_reader._AbsoluteInstruction(split_name, from_, to_))
     self.assertEqual(res, expected_result)
     return ri
 
@@ -188,7 +191,7 @@ class ReadInstructionTest(testing.TestCase):
     ri = self.check_from_spec('train', [('train', None, None)])
     self.assertEqual(
         str(ri),
-        ("ReadInstruction(["
+        ('ReadInstruction(['
          "_RelativeInstruction(splitname='train', from_=None, to=None, "
          "unit='abs', rounding='closest')])"))
     self.check_from_spec('test', [('test', None, None)])
@@ -218,18 +221,18 @@ class ReadInstructionTest(testing.TestCase):
     # No overlap:
     self.check_from_spec('test[100%:]', [('test', 101, None)])
     # Percent slicing, pct1_dropremainder rounding:
-    ri = tfrecords_reader.ReadInstruction('train', to=20, unit='%',
-                                          rounding='pct1_dropremainder')
+    ri = tfrecords_reader.ReadInstruction(
+        'train', to=20, unit='%', rounding='pct1_dropremainder')
     self.check_from_ri(ri, [('train', None, 40)])
     # test split has 101 examples.
-    ri = tfrecords_reader.ReadInstruction('test', to=100, unit='%',
-                                          rounding='pct1_dropremainder')
+    ri = tfrecords_reader.ReadInstruction(
+        'test', to=100, unit='%', rounding='pct1_dropremainder')
     self.check_from_ri(ri, [('test', None, 100)])
     # No overlap using 'pct1_dropremainder' rounding:
-    ri1 = tfrecords_reader.ReadInstruction('test', to=99, unit='%',
-                                           rounding='pct1_dropremainder')
-    ri2 = tfrecords_reader.ReadInstruction('test', from_=100, unit='%',
-                                           rounding='pct1_dropremainder')
+    ri1 = tfrecords_reader.ReadInstruction(
+        'test', to=99, unit='%', rounding='pct1_dropremainder')
+    ri2 = tfrecords_reader.ReadInstruction(
+        'test', from_=100, unit='%', rounding='pct1_dropremainder')
     self.check_from_ri(ri1, [('test', None, 99)])
     self.check_from_ri(ri2, [('test', 100, None)])
     # Empty:
@@ -246,7 +249,7 @@ class ReadInstructionTest(testing.TestCase):
     ri = ri1 + ri2 + ri3
     self.assertEqual(
         str(ri),
-        ("ReadInstruction(["
+        ('ReadInstruction(['
          "_RelativeInstruction(splitname='train', from_=10, to=20, unit='abs',"
          " rounding='closest'), "
          "_RelativeInstruction(splitname='test', from_=10, to=20, unit='abs',"
@@ -256,10 +259,10 @@ class ReadInstructionTest(testing.TestCase):
 
   def test_add_invalid(self):
     # Mixed rounding:
-    ri1 = tfrecords_reader.ReadInstruction('test', unit='%', to=10,
-                                           rounding='pct1_dropremainder')
-    ri2 = tfrecords_reader.ReadInstruction('test', unit='%', from_=90,
-                                           rounding='closest')
+    ri1 = tfrecords_reader.ReadInstruction(
+        'test', unit='%', to=10, rounding='pct1_dropremainder')
+    ri2 = tfrecords_reader.ReadInstruction(
+        'test', unit='%', from_=90, rounding='closest')
     with self.assertRaisesWithPredicateMatch(AssertionError,
                                              'different rounding'):
       unused_ = ri1 + ri2
@@ -277,12 +280,10 @@ class ReadInstructionTest(testing.TestCase):
     self.assertRaises('validation[:250%:2]',
                       'Unrecognized instruction format: validation[:250%:2]')
     # Unexisting split:
-    self.assertRaises('imaginary',
-                      'Unknown split "imaginary"',
-                      exc_cls=ValueError)
+    self.assertRaises(
+        'imaginary', 'Unknown split "imaginary"', exc_cls=ValueError)
     # Invalid boundaries abs:
-    self.assertRaises('validation[:31]',
-                      'incompatible with 30 examples')
+    self.assertRaises('validation[:31]', 'incompatible with 30 examples')
     # Invalid boundaries %:
     self.assertRaises('validation[:250%]',
                       'Percent slice boundaries must be > -100 and < 100')
@@ -291,8 +292,8 @@ class ReadInstructionTest(testing.TestCase):
     # pct1_dropremainder with < 100 examples
     with self.assertRaisesWithPredicateMatch(
         AssertionError, 'with less than 100 elements is forbidden'):
-      ri = tfrecords_reader.ReadInstruction('validation', to=99, unit='%',
-                                            rounding='pct1_dropremainder')
+      ri = tfrecords_reader.ReadInstruction(
+          'validation', to=99, unit='%', rounding='pct1_dropremainder')
       ri.to_absolute(self.splits)
 
 
@@ -300,9 +301,8 @@ class ReaderTest(testing.TestCase):
 
   def setUp(self):
     super(ReaderTest, self).setUp()
-    with mock.patch.object(
-        example_parser, 'ExampleParser', testing.DummyParser
-    ):
+    with mock.patch.object(example_parser, 'ExampleParser',
+                           testing.DummyParser):
       self.reader = tfrecords_reader.Reader(self.tmp_dir, 'some_spec')
       self.reader.read = functools.partial(
           self.reader.read,
@@ -314,14 +314,13 @@ class ReaderTest(testing.TestCase):
     path = os.path.join(self.tmp_dir, 'mnist-%s.tfrecord' % split_name)
     num_examples = len(records)
     with mock.patch.object(
-        tfrecords_writer, '_get_number_shards', return_value=shards_number
-    ):
-      shard_specs = tfrecords_writer._get_shard_specs(
-          num_examples, 0, [num_examples], path)
-    serialized_records = [six.b(rec) for rec in records]
+        tfrecords_writer, '_get_number_shards', return_value=shards_number):
+      shard_specs = tfrecords_writer._get_shard_specs(num_examples, 0,
+                                                      [num_examples], path)
+    serialized_records = [(key, six.b(rec)) for key, rec in enumerate(records)]
     for shard_spec in shard_specs:
-      _write_tfrecord_from_shard_spec(
-          shard_spec, lambda unused_i: iter(serialized_records))
+      _write_tfrecord_from_shard_spec(shard_spec,
+                                      lambda unused_i: iter(serialized_records))
     return splits.SplitInfo(
         name=split_name,
         shard_lengths=[int(s.examples_number) for s in shard_specs],
@@ -410,8 +409,9 @@ class ReaderTest(testing.TestCase):
         [b'k', b'l'],
     ]
     # The various orders in which the dataset can be read:
-    expected_permutations = [tuple(sum(shard, []))
-                             for shard in itertools.permutations(shards)]
+    expected_permutations = [
+        tuple(sum(shard, [])) for shard in itertools.permutations(shards)
+    ]
     ds = ds.batch(12).repeat(100)
     read_data = set(tuple(e) for e in tfds.as_numpy(ds))
     for batch in read_data:
@@ -422,9 +422,7 @@ class ReaderTest(testing.TestCase):
 
   def test_shuffle_deterministic(self):
     split_info = self._write_tfrecord('train', 5, 'abcdefghijkl')
-    read_config = read_config_lib.ReadConfig(
-        shuffle_seed=123,
-    )
+    read_config = read_config_lib.ReadConfig(shuffle_seed=123,)
     ds = self.reader.read(
         name='mnist',
         instructions='train',
@@ -442,8 +440,9 @@ class ReaderTest(testing.TestCase):
   def test_4fold(self):
     train_info = self._write_tfrecord('train', 5, 'abcdefghijkl')
     instructions = [
-        tfrecords_reader.ReadInstruction('train', from_=k, to=k+25, unit='%')
-        for k in range(0, 100, 25)]
+        tfrecords_reader.ReadInstruction('train', from_=k, to=k + 25, unit='%')
+        for k in range(0, 100, 25)
+    ]
     tests = self.reader.read(
         name='mnist',
         instructions=instructions,
@@ -451,8 +450,9 @@ class ReaderTest(testing.TestCase):
     )
     instructions = [
         (tfrecords_reader.ReadInstruction('train', to=k, unit='%') +
-         tfrecords_reader.ReadInstruction('train', from_=k+25, unit='%'))
-        for k in range(0, 100, 25)]
+         tfrecords_reader.ReadInstruction('train', from_=k + 25, unit='%'))
+        for k in range(0, 100, 25)
+    ]
     trains = self.reader.read(
         name='mnist',
         instructions=instructions,
@@ -460,15 +460,13 @@ class ReaderTest(testing.TestCase):
     )
     read_tests = [list(r) for r in tfds.as_numpy(tests)]
     read_trains = [list(r) for r in tfds.as_numpy(trains)]
-    self.assertEqual(read_tests, [[b'a', b'b', b'c'],
-                                  [b'd', b'e', b'f'],
-                                  [b'g', b'h', b'i'],
-                                  [b'j', b'k', b'l']])
-    self.assertEqual(read_trains, [
-        [b'd', b'e', b'f', b'g', b'h', b'i', b'j', b'k', b'l'],
-        [b'a', b'b', b'c', b'g', b'h', b'i', b'j', b'k', b'l'],
-        [b'a', b'b', b'c', b'd', b'e', b'f', b'j', b'k', b'l'],
-        [b'a', b'b', b'c', b'd', b'e', b'f', b'g', b'h', b'i']])
+    self.assertEqual(read_tests, [[b'a', b'b', b'c'], [b'd', b'e', b'f'],
+                                  [b'g', b'h', b'i'], [b'j', b'k', b'l']])
+    self.assertEqual(read_trains,
+                     [[b'd', b'e', b'f', b'g', b'h', b'i', b'j', b'k', b'l'],
+                      [b'a', b'b', b'c', b'g', b'h', b'i', b'j', b'k', b'l'],
+                      [b'a', b'b', b'c', b'd', b'e', b'f', b'j', b'k', b'l'],
+                      [b'a', b'b', b'c', b'd', b'e', b'f', b'g', b'h', b'i']])
 
   def test_read_files(self):
     self._write_tfrecord('train', 4, 'abcdefghijkl')
@@ -491,20 +489,21 @@ class ReaderTest(testing.TestCase):
     self.assertEqual(split_info.shard_lengths, [2, 3, 2, 3, 2])
 
     def read(num_workers, index):
-      return list(tfds.as_numpy(self.reader.read(
-          name='mnist',
-          instructions='train',
-          split_infos=[split_info],
-          read_config=read_config_lib.ReadConfig(
-              input_context=tf.distribute.InputContext(
-                  num_input_pipelines=num_workers,
-                  input_pipeline_id=index,
-              ),
-          ),
-          # Workers should read a deterministic subset of the examples, even
-          # if examples within one worker may be shuffled.
-          shuffle_files=True,
-      )))
+      return list(
+          tfds.as_numpy(
+              self.reader.read(
+                  name='mnist',
+                  instructions='train',
+                  split_infos=[split_info],
+                  read_config=read_config_lib.ReadConfig(
+                      input_context=tf.distribute.InputContext(
+                          num_input_pipelines=num_workers,
+                          input_pipeline_id=index,
+                      ),),
+                  # Workers should read a deterministic subset of the examples,
+                  # even if examples within one worker may be shuffled.
+                  shuffle_files=True,
+              )))
 
     def _b(bytes_str):
       if six.PY2:
@@ -524,5 +523,63 @@ class ReaderTest(testing.TestCase):
     with self.assertRaisesRegexp(ValueError, 'Cannot shard the pipeline'):
       read(num_workers=6, index=0)
 
+  def test_shuffle_files_should_be_disabled(self):
+    self._write_tfrecord('train', 4, 'abcdefghijkl')
+    fname_pattern = 'mnist-train.tfrecord-0000%d-of-00004'
+    with self.assertRaisesWithPredicateMatch(ValueError,
+                                             _SHUFFLE_FILES_ERROR_MESSAGE):
+      self.reader.read_files(
+          [
+              shard_utils.FileInstruction(
+                  filename=fname_pattern % 1, skip=0, take=-1, num_examples=3),
+          ],
+          read_config=read_config_lib.ReadConfig(),
+          shuffle_files=True,
+          disable_shuffling=True,
+      )
+
+  def test_cycle_length_must_be_one(self):
+    self._write_tfrecord('train', 4, 'abcdefghijkl')
+    fname_pattern = 'mnist-train.tfrecord-0000%d-of-00004'
+    instructions = [
+        shard_utils.FileInstruction(
+            filename=fname_pattern % 1, skip=0, take=-1, num_examples=3),
+    ]
+    # In ordered dataset interleave_cycle_length is set to 1 by default
+    self.reader.read_files(
+        instructions,
+        read_config=read_config_lib.ReadConfig(),
+        shuffle_files=False,
+        disable_shuffling=True,
+    )
+    with self.assertRaisesWithPredicateMatch(ValueError,
+                                             _CYCLE_LENGTH_ERROR_MESSAGE):
+      self.reader.read_files(
+          instructions,
+          read_config=read_config_lib.ReadConfig(interleave_cycle_length=16),
+          shuffle_files=False,
+          disable_shuffling=True,
+      )
+
+  def test_ordering_guard(self):
+    self._write_tfrecord('train', 4, 'abcdefghijkl')
+    fname_pattern = 'mnist-train.tfrecord-0000%d-of-00004'
+    instructions = [
+        shard_utils.FileInstruction(
+            filename=fname_pattern % 1, skip=0, take=-1, num_examples=3),
+    ]
+    reported_warnings = []
+    with mock.patch('absl.logging.warning', reported_warnings.append):
+      self.reader.read_files(
+          instructions,
+          read_config=read_config_lib.ReadConfig(
+              interleave_cycle_length=16, enable_ordering_guard=False),
+          shuffle_files=True,
+          disable_shuffling=True,
+      )
+      expected_warning = _SHUFFLE_FILES_ERROR_MESSAGE + '\n' + _CYCLE_LENGTH_ERROR_MESSAGE
+      self.assertIn(expected_warning, reported_warnings)
+
+
 if __name__ == '__main__':
   testing.test_main()
