@@ -43,12 +43,13 @@ class GcsUtilsTest(testing.TestCase):
       )
       with tempfile.TemporaryDirectory() as f:
         gcs_utils.download_gcs_dataset('mnist/2.0.0', f)
-        self.assertCountEqual(os.listdir(f), [
-            'mnist-test.tfrecord-00000-of-00001',
-            'mnist-train.tfrecord-00000-of-00001',
-            'dataset_info.json',
-            'image.image.json',
-        ])
+        self.assertCountEqual(
+            os.listdir(f), [
+                'mnist-test.tfrecord-00000-of-00001',
+                'mnist-train.tfrecord-00000-of-00001',
+                'dataset_info.json',
+                'image.image.json',
+            ])
 
   def test_mnist(self):
     with self.gcs_access():
