@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,21 +23,11 @@ from tensorflow_datasets import testing
 from tensorflow_datasets.core.utils import image_utils
 
 # pylint: disable=bad-whitespace
-SIX_PIXELS = [
-    [[  0, 255,   0],
-     [255,   0,   0],
-     [255,   0, 255]],
-    [[  0,   0, 255],
-     [255, 255,   0],
-     [126, 127, 128]]]
+SIX_PIXELS = [[[0, 255, 0], [255, 0, 0], [255, 0, 255]],
+              [[0, 0, 255], [255, 255, 0], [126, 127, 128]]]
 
-SIX_PIXELS_JPEG = [
-    [[158, 161,  92],
-     [ 76,  79,  10],
-     [180,  57, 181]],
-    [[ 33,  36,   0],
-     [229, 232, 163],
-     [201,  78, 202]]]
+SIX_PIXELS_JPEG = [[[158, 161, 92], [76, 79, 10], [180, 57, 181]],
+                   [[33, 36, 0], [229, 232, 163], [201, 78, 202]]]
 # pylint: enable=bad-whitespace
 
 
@@ -74,6 +64,26 @@ class ImageUtilsTest(testing.TestCase):
     new_np_image = image_utils.decode_image(new_image)
     np.testing.assert_allclose(original_np_image, new_np_image, rtol=10)
 
+  def test_apply_colormap(self):
+    assert image_utils.get_colormap().shape == (256, 3)
+
+    gray_img = np.array(
+        [
+            [[0], [2]],
+            [[1234], [2]],
+        ],
+        dtype=np.uint16,
+    )
+    assert gray_img.shape == (2, 2, 1)
+    colored_img = image_utils.apply_colormap(gray_img)
+    assert colored_img.shape == (2, 2, 3)
+    assert colored_img.dtype == np.uint8
+
+    np.testing.assert_array_equal(colored_img, [
+        [[0, 0, 0], [55, 126, 184]],
+        [[71, 84, 183], [55, 126, 184]],
+    ])
+
 
 if __name__ == '__main__':
   testing.test_main()
