@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,12 +16,14 @@
 """Tests for py_utils."""
 
 import collections
-import hashlib
-import os
+import pathlib
+
+import pytest
 
 import tensorflow as tf
 from tensorflow_datasets import testing
 from tensorflow_datasets.core import constants
+from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.utils import py_utils
 
 
@@ -32,6 +34,7 @@ class PyUtilsTest(testing.TestCase):
 
   def test_map_nested(self):
     """Test the mapping function."""
+
     def map_fn(x):
       return x * 10
 
@@ -87,6 +90,7 @@ class PyUtilsTest(testing.TestCase):
     self.assertEqual(result, (1, 2))
 
   def test_dict_only(self):
+
     def map_fn(x):
       return x[0] + x[1]
 
@@ -106,13 +110,14 @@ class PyUtilsTest(testing.TestCase):
     }
 
     result = py_utils.zip_nested(arg0, arg1, dict_only=True)
-    self.assertEqual(result, {
-        'a': ((1, 2), (10, 20)),
-        'b': {
-            'c': (2, 20),
-            'e': ([3, 4, 5], [30, 40, 50]),
-        },
-    })
+    self.assertEqual(
+        result, {
+            'a': ((1, 2), (10, 20)),
+            'b': {
+                'c': (2, 20),
+                'e': ([3, 4, 5], [30, 40, 50]),
+            },
+        })
 
     result = py_utils.map_nested(map_fn, result, dict_only=True)
     self.assertEqual(result, {
@@ -146,13 +151,15 @@ class PyUtilsTest(testing.TestCase):
     self.assertEqual(py_utils.pack_as_nest_dict(flat_d, nest_d), nest_d)
 
     with self.assertRaisesWithPredicateMatch(ValueError, 'Extra keys'):
-      py_utils.pack_as_nest_dict({
-          'a': 1,
-          'b/c': 2,
-          'b/e': 3,
-          'b/f/g': 4,
-          'b/h': 5,  # Extra key
-      }, nest_d)
+      py_utils.pack_as_nest_dict(
+          {
+              'a': 1,
+              'b/c': 2,
+              'b/e': 3,
+              'b/f/g': 4,
+              'b/h': 5,  # Extra key
+          },
+          nest_d)
 
     with self.assertRaisesWithPredicateMatch(KeyError, 'b/e'):
       py_utils.pack_as_nest_dict(
@@ -171,8 +178,8 @@ class PyUtilsTest(testing.TestCase):
           },
       )
 
-    with self.assertRaisesWithPredicateMatch(
-        ValueError, 'overwrite existing key:'):
+    with self.assertRaisesWithPredicateMatch(ValueError,
+                                             'overwrite existing key:'):
       py_utils.flatten_nest_dict({
           'a': {
               'b': 1,
@@ -214,17 +221,6 @@ class PyUtilsTest(testing.TestCase):
         raise tf.errors.FailedPreconditionError(None, None, 'message')
 
 
-class ReadChecksumDigestTest(testing.TestCase):
-
-  def test_digest(self):
-    digest, size = py_utils.read_checksum_digest(
-        os.path.join(self.test_data, '6pixels.png'), hashlib.sha256)
-    self.assertEqual(
-        digest,
-        '04f38ebed34d3b027d2683193766155912fba647158c583c3bdb4597ad8af34c')
-    self.assertEqual(102, size)
-
-
 class GetClassPathUrlTest(testing.TestCase):
 
   def test_get_class_path(self):
@@ -242,6 +238,19 @@ class GetClassPathUrlTest(testing.TestCase):
         (constants.SRC_BASE_URL + 'tensorflow_datasets/core/utils/py_utils.py'))
 
 
+def test_list_info_files(tmp_path: pathlib.Path):
+  tmp_path.joinpath('test.tfrecord').touch()
+  tmp_path.joinpath('test.riegeli').touch()
+  tmp_path.joinpath('info.json').touch()
+
+  # Have a info file in the sub-directory. Shouldn't be listed.
+  tmp_path.joinpath('diff').mkdir()
+  tmp_path.joinpath('diff/info.json').touch()
+  info_files = py_utils.list_info_files(tmp_path)
+
+  assert info_files == ['info.json']
+
+
 def _flatten_with_path(v):
   return list(py_utils.flatten_with_path(v))
 
@@ -253,12 +262,10 @@ def test_flatten_with_path():
   assert _flatten_with_path('value') == [((), 'value')]
   assert _flatten_with_path({'key': 'value'}) == [(('key',), 'value')]
   # Order doesn't matter
-  ordered_dict1 = collections.OrderedDict(
-      [('key1', 'value1'), ('key2', 'value2')]
-  )
-  ordered_dict2 = collections.OrderedDict(
-      [('key2', 'value2'), ('key1', 'value1')]
-  )
+  ordered_dict1 = collections.OrderedDict([('key1', 'value1'),
+                                           ('key2', 'value2')])
+  ordered_dict2 = collections.OrderedDict([('key2', 'value2'),
+                                           ('key1', 'value1')])
   expected_result = [(('key1',), 'value1'), (('key2',), 'value2')]
   assert _flatten_with_path(ordered_dict1) == expected_result
   assert _flatten_with_path(ordered_dict2) == expected_result
@@ -279,11 +286,40 @@ def test_flatten_with_path():
       (('key2',), 'value2'),
       (('nested', 'subkey', 0), 'subvalue0'),
       (('nested', 'subkey', 1), 'subvalue1'),
-      (('nested', 'subnested', 'subsubkey1',), 'subsubvalue1'),
-      (('nested', 'subnested', 'subsubkey2',), 'subsubvalue2'),
+      ((
+          'nested',
+          'subnested',
+          'subsubkey1',
+      ), 'subsubvalue1'),
+      ((
+          'nested',
+          'subnested',
+          'subsubkey2',
+      ), 'subsubvalue2'),
   ]
   # Order is consistent with tf.nest.flatten
-  assert (
-      [v for _, v in _flatten_with_path(complex_dict)]
-      == tf.nest.flatten(complex_dict)
-  )
+  assert ([v for _, v in _flatten_with_path(complex_dict)
+          ] == tf.nest.flatten(complex_dict))
+
+
+@pytest.mark.parametrize(
+    ['url', 'filename'],
+    [
+        (
+            'http://test.com/appspot.com/tsvsWithoutLabels%2FAX.tsv?'
+            'Id=firebase&Expires=2498860800',
+            'tsvsWithoutLabels_AX.tsv'  # `%2F` -> `_`
+        ),
+    ])
+def test_basename_from_url(url: str, filename: str):
+  assert utils.basename_from_url(url) == filename
+
+
+def test_incomplete_file(tmp_path: pathlib.Path):
+  tmp_path = utils.as_path(tmp_path)
+  filepath = tmp_path / 'test.txt'
+  with py_utils.incomplete_file(filepath) as tmp_filepath:
+    tmp_filepath.write_text('content')
+    assert not filepath.exists()
+  assert filepath.read_text() == 'content'
+  assert not tmp_filepath.exists()  # Tmp file is deleted
