@@ -43,17 +43,20 @@ TupleOrList = Union[Tuple[T, ...], List[T]]
 TreeDict = Union[T, Dict[str, 'TreeDict']]  # pytype: disable=not-supported-yet
 Tree = Union[T, TupleOrList['Tree'], Dict[str, 'Tree']]  # pytype: disable=not-supported-yet
 
-
 Tensor = Union[tf.Tensor, tf.SparseTensor, tf.RaggedTensor]
 
 Dim = Optional[int]
 Shape = TupleOrList[Dim]
 
-JsonValue = Union[
-    str, bool, int, float, None, List['JsonValue'], Dict[str, 'JsonValue'],  # pytype: disable=not-supported-yet
-]
+JsonValue = Union[str, bool, int, float, None, List['JsonValue'],
+                  Dict[str, 'JsonValue'],  # pytype: disable=not-supported-yet
+                 ]
 Json = Dict[str, JsonValue]
 
+# Types for the tfrecord example construction.
+
+Key = Union[int, str, bytes]
+KeySerializedExample = Tuple[Key, bytes]  # `(key, serialized_proto)`
 
 # pytype: disable=ignored-abstractmethod
 
@@ -71,30 +74,70 @@ class PurePath(Protocol):
 
   # pylint: disable=multiple-statements,line-too-long
 
-  def __new__(cls: Type[T], *args: PathLike) -> T: raise NotImplementedError
-  def __fspath__(self) -> str: raise NotImplementedError
-  def __hash__(self) -> int: raise NotImplementedError
-  def __lt__(self, other: 'PurePath') -> bool: raise NotImplementedError
-  def __le__(self, other: 'PurePath') -> bool: raise NotImplementedError
-  def __gt__(self, other: 'PurePath') -> bool: raise NotImplementedError
-  def __ge__(self, other: 'PurePath') -> bool: raise NotImplementedError
-  def __truediv__(self: T, key: PathLike) -> T: raise NotImplementedError
-  def __rtruediv__(self: T, key: PathLike) -> T: raise NotImplementedError
-  def __bytes__(self) -> bytes: raise NotImplementedError
-  def as_posix(self) -> str: raise NotImplementedError
-  def as_uri(self) -> str: raise NotImplementedError
-  def is_absolute(self) -> bool: raise NotImplementedError
-  def is_reserved(self) -> bool: raise NotImplementedError
-  def match(self, path_pattern: str) -> bool: raise NotImplementedError
-  def relative_to(self: T, *other: PathLike) -> T: raise NotImplementedError
-  def with_name(self: T, name: str) -> T: raise NotImplementedError
-  def with_suffix(self: T, suffix: str) -> T: raise NotImplementedError
-  def joinpath(self: T, *other: PathLike) -> T: raise NotImplementedError
+  def __new__(cls: Type[T], *args: PathLike) -> T:
+    raise NotImplementedError
+
+  def __fspath__(self) -> str:
+    raise NotImplementedError
+
+  def __hash__(self) -> int:
+    raise NotImplementedError
+
+  def __lt__(self, other: 'PurePath') -> bool:
+    raise NotImplementedError
+
+  def __le__(self, other: 'PurePath') -> bool:
+    raise NotImplementedError
+
+  def __gt__(self, other: 'PurePath') -> bool:
+    raise NotImplementedError
+
+  def __ge__(self, other: 'PurePath') -> bool:
+    raise NotImplementedError
+
+  def __truediv__(self: T, key: PathLike) -> T:
+    raise NotImplementedError
+
+  def __rtruediv__(self: T, key: PathLike) -> T:
+    raise NotImplementedError
+
+  def __bytes__(self) -> bytes:
+    raise NotImplementedError
+
+  def as_posix(self) -> str:
+    raise NotImplementedError
+
+  def as_uri(self) -> str:
+    raise NotImplementedError
+
+  def is_absolute(self) -> bool:
+    raise NotImplementedError
+
+  def is_reserved(self) -> bool:
+    raise NotImplementedError
+
+  def match(self, path_pattern: str) -> bool:
+    raise NotImplementedError
+
+  def relative_to(self: T, *other: PathLike) -> T:
+    raise NotImplementedError
+
+  def with_name(self: T, name: str) -> T:
+    raise NotImplementedError
+
+  def with_suffix(self: T, suffix: str) -> T:
+    raise NotImplementedError
+
+  def joinpath(self: T, *other: PathLike) -> T:
+    raise NotImplementedError
 
   @property
-  def parents(self: T) -> Sequence[T]: raise NotImplementedError
+  def parents(self: T) -> Sequence[T]:
+    raise NotImplementedError
+
   @property
-  def parent(self: T) -> T: raise NotImplementedError
+  def parent(self: T) -> T:
+    raise NotImplementedError
 
   # py3.9 backport of PurePath.is_relative_to.
   def is_relative_to(self, *other: PathLike) -> bool:
