@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,14 +15,18 @@
 
 """Visualizer utils."""
 
+from tensorflow_datasets.core.visualization.graph_visualizer import GraphVisualizer
+from tensorflow_datasets.core.visualization.graph_visualizer import GraphVisualizerMetadataDict
 from tensorflow_datasets.core.visualization.image_visualizer import ImageGridVisualizer
 from tensorflow_datasets.core.visualization.show_examples import show_examples
 from tensorflow_datasets.core.visualization.show_examples import show_statistics
 from tensorflow_datasets.core.visualization.visualizer import Visualizer
 
-
 __all__ = [
     "ImageGridVisualizer",
+    "GraphVisualizer",
+    "GraphVisualizerMetadataDict",
     "show_examples",
+    "show_statistics",
     "Visualizer",
 ]
