@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
-"""Show example util.
-"""
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+"""Show example util."""
 
 from typing import Any
 
@@ -28,20 +22,19 @@ from tensorflow_datasets.core import dataset_info
 from tensorflow_datasets.core import lazy_imports_lib
 from tensorflow_datasets.core import splits
 from tensorflow_datasets.core import utils
+from tensorflow_datasets.core.visualization import graph_visualizer
 from tensorflow_datasets.core.visualization import image_visualizer
-from tensorflow_metadata.proto.v0 import statistics_pb2
 
+from tensorflow_metadata.proto.v0 import statistics_pb2
 
 _ALL_VISUALIZERS = [
     image_visualizer.ImageGridVisualizer(),
+    graph_visualizer.GraphVisualizer(),
 ]
 
 
-def show_examples(
-    ds: tf.data.Dataset,
-    ds_info: dataset_info.DatasetInfo,
-    **options_kwargs: Any
-):
+def show_examples(ds: tf.data.Dataset, ds_info: dataset_info.DatasetInfo,
+                  **options_kwargs: Any):
   """Visualize images (and labels) from an image classification dataset.
 
   This function is for interactive use (Colab, Jupyter). It displays and return
@@ -55,14 +48,14 @@ def show_examples(
 
   Args:
     ds: `tf.data.Dataset`. The tf.data.Dataset object to visualize. Examples
-      should not be batched. Examples will be consumed in order until
-      (rows * cols) are read or the dataset is consumed.
+      should not be batched. Examples will be consumed in order until (rows *
+      cols) are read or the dataset is consumed.
     ds_info: The dataset info object to which extract the label and features
       info. Available either through `tfds.load('mnist', with_info=True)` or
       `tfds.builder('mnist').info`
     **options_kwargs: Additional display options, specific to the dataset type
-      to visualize. Are forwarded to `tfds.visualization.Visualizer.show`.
-      See the `tfds.visualization` for a list of available visualizers.
+      to visualize. Are forwarded to `tfds.visualization.Visualizer.show`. See
+      the `tfds.visualization` for a list of available visualizers.
 
   Returns:
     fig: The `matplotlib.Figure` object
@@ -74,12 +67,16 @@ def show_examples(
           'The old signature is deprecated and will be removed. '
           'Please change your call to `tfds.show_examples(ds, info)`')
     ds, ds_info = ds_info, ds
+
+  # Pack `as_supervised=True` datasets
+  ds = dataset_info.pack_as_supervised_ds(ds, ds_info)
+
   for visualizer in _ALL_VISUALIZERS:
     if visualizer.match(ds_info):
       return visualizer.show(ds, ds_info, **options_kwargs)
-    raise ValueError(
-        'Visualisation not supported for dataset `{}`'.format(ds_info.name)
-    )
+
+  raise ValueError('Visualisation not supported for dataset `{}`'.format(
+      ds_info.name))
 
 
 def show_statistics(
@@ -117,8 +114,8 @@ def show_statistics(
   Args:
     ds_info: The `tfds.core.DatasetInfo` object containing the statistics.
     split: Split for which generate the statistics.
-    disable_logging: `bool`, if True, disable the tfdv logs which can be
-      too verbose.
+    disable_logging: `bool`, if True, disable the tfdv logs which can be too
+      verbose.
 
   Returns:
     `None`
