@@ -17,25 +17,27 @@
 
 from typing import Any
 
-from tensorflow_datasets.d4rl import mujoco_dataset
+from tensorflow_datasets.d4rl import dataset_builder
 import tensorflow_datasets.public_api as tfds
 
 
-class D4rlMujocoHalfcheetah(mujoco_dataset.D4RLMujocoDatasetBuilder):
+class D4rlMujocoHalfcheetah(dataset_builder.D4RLDatasetBuilder):
   """DatasetBuilder for halfcheetah dataset."""
 
-  VERSION = tfds.core.Version('1.0.1')
+  VERSION = tfds.core.Version('1.1.0')
   RELEASE_NOTES = {
       '1.0.0':
           'Initial release.',
       '1.0.1':
           'Support for episode and step metadata, and unification of the' +
-          ' reward shape accross all the configs.'
+          ' reward shape across all the configs.',
+      '1.1.0':
+          'Added is_last.',
   }
 
-  BUILDER_CONFIGS = mujoco_dataset.BUILDER_CONFIGS
+  BUILDER_CONFIGS = dataset_builder.MUJOCO_BUILDER_CONFIGS
 
   def __init__(self, **kwargs: Any):
-    config = mujoco_dataset.DatasetConfig(
+    config = dataset_builder.DatasetConfig(
         name='halfcheetah', obs_len=17, action_len=6, qpos_len=9, qvel_len=9)
     super().__init__(ds_config=config, **kwargs)
