@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,17 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for binarized_mnist dataset module."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from tensorflow_datasets import testing
 from tensorflow_datasets.image import binarized_mnist
 
-
 # testing/binarized_mnist.py generates fake input data
 
 
@@ -40,5 +34,6 @@ class MNISTTest(testing.DatasetBuilderTestCase):
       "test_data": binarized_mnist._TEST_DATA_FILENAME,
   }
 
+
 if __name__ == "__main__":
   testing.test_main()
