@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -44,7 +44,7 @@ High-quality version of the CELEBA
 dataset, consisting of 30000 images in 1024 x 1024 resolution.
 
 Note: CelebAHQ dataset may contain potential bias. The fairness indicators
-[example](https://github.com/tensorflow/fairness-indicators/blob/master/fairness_indicators/documentation/examples/Fairness_Indicators_TFCO_CelebA_Case_Study.ipynb)
+[example](https://www.tensorflow.org/responsible_ai/fairness_indicators/tutorials/Fairness_Indicators_TFCO_CelebA_Case_Study)
 goes into detail about several considerations to keep in mind while using the
 CelebAHQ dataset.
 
@@ -105,15 +105,16 @@ class CelebAHq(tfds.core.GeneratorBasedBuilder):
     return tfds.core.DatasetInfo(
         builder=self,
         description=_DESCRIPTION,
-        features=tfds.features.FeaturesDict({
-            "image":
-                tfds.features.Image(
-                    shape=(self.builder_config.resolution,
-                           self.builder_config.resolution, 3),
-                    encoding_format="png"),
-            "image/filename":
-                tfds.features.Text(),
-        },),
+        features=tfds.features.FeaturesDict(
+            {
+                "image":
+                    tfds.features.Image(
+                        shape=(self.builder_config.resolution,
+                               self.builder_config.resolution, 3),
+                        encoding_format="png"),
+                "image/filename":
+                    tfds.features.Text(),
+            },),
         homepage="https://github.com/tkarras/progressive_growing_of_gans",
         citation=_CITATION,
     )
