@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """CLEVR dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import collections
 import json
 import os
@@ -27,14 +22,12 @@ import os
 import tensorflow.compat.v2 as tf
 import tensorflow_datasets.public_api as tfds
 
-
 _DESCRIPTION = """\
 CLEVR is a diagnostic dataset that tests a range of visual reasoning abilities.
 It contains minimal biases and has detailed annotations describing the kind of
 reasoning each question requires.
 """
 
-
 _CITATION = """\
 @inproceedings{johnson2017clevr,
   title={{CLEVR}: A diagnostic dataset for compositional language and elementary visual reasoning},
@@ -51,29 +44,41 @@ _DOWNLOAD_URL = "https://dl.fbaipublicfiles.com/clevr/CLEVR_v1.0.zip"
 class CLEVR(tfds.core.GeneratorBasedBuilder):
   """CLEVR dataset."""
 
-  VERSION = tfds.core.Version("3.1.0", "Add question/answer text.")
+  VERSION = tfds.core.Version("3.1.0")
   SUPPORTED_VERSIONS = [
       tfds.core.Version("3.0.0"),
   ]
+  RELEASE_NOTES = {
+      "3.1.0": "Add question/answer text.",
+  }
 
   def _info(self):
     features = {
-        "image": tfds.features.Image(),
-        "file_name": tfds.features.Text(),
-        "objects": tfds.features.Sequence({
-            "color": tfds.features.ClassLabel(names=["gray", "blue",
-                                                     "brown", "yellow",
-                                                     "red", "green",
-                                                     "purple", "cyan"]),
-            "material": tfds.features.ClassLabel(names=["rubber", "metal"]),
-            "shape": tfds.features.ClassLabel(names=["cube", "sphere",
-                                                     "cylinder"]),
-            "size": tfds.features.ClassLabel(names=["small", "large"]),
-            "rotation": tfds.features.Tensor(shape=(), dtype=tf.float32),
-            "3d_coords": tfds.features.Tensor(shape=(3,), dtype=tf.float32),
-            "pixel_coords": tfds.features.Tensor(shape=(3,),
-                                                 dtype=tf.float32),
-        })
+        "image":
+            tfds.features.Image(),
+        "file_name":
+            tfds.features.Text(),
+        "objects":
+            tfds.features.Sequence({
+                "color":
+                    tfds.features.ClassLabel(names=[
+                        "gray", "blue", "brown", "yellow", "red", "green",
+                        "purple", "cyan"
+                    ]),
+                "material":
+                    tfds.features.ClassLabel(names=["rubber", "metal"]),
+                "shape":
+                    tfds.features.ClassLabel(
+                        names=["cube", "sphere", "cylinder"]),
+                "size":
+                    tfds.features.ClassLabel(names=["small", "large"]),
+                "rotation":
+                    tfds.features.Tensor(shape=(), dtype=tf.float32),
+                "3d_coords":
+                    tfds.features.Tensor(shape=(3,), dtype=tf.float32),
+                "pixel_coords":
+                    tfds.features.Tensor(shape=(3,), dtype=tf.float32),
+            })
     }
     if self.version > "3.0.0":
       features["question_answer"] = tfds.features.Sequence({
@@ -103,24 +108,30 @@ class CLEVR(tfds.core.GeneratorBasedBuilder):
           "val": tfds.Split.VALIDATION,
           "test": tfds.Split.TEST,
       }
-      splits.append(tfds.core.SplitGenerator(
-          name=name_map[split_name],
-          gen_kwargs={
-              "images_dir_path": os.path.join(images_path_dir, split_name),
-              "question_file": os.path.join(
-                  questions_path_dir,
-                  "CLEVR_{}_questions.json".format(split_name)),
-              "scenes_description_file": os.path.join(
-                  scenes_path_dir, "CLEVR_{}_scenes.json".format(split_name)),
+      splits.append(
+          tfds.core.SplitGenerator(
+              name=name_map[split_name],
+              gen_kwargs={
+                  "images_dir_path":
+                      os.path.join(images_path_dir, split_name),
+                  "question_file":
+                      os.path.join(
+                          questions_path_dir,
+                          "CLEVR_{}_questions.json".format(split_name)),
+                  "scenes_description_file":
+                      os.path.join(scenes_path_dir,
+                                   "CLEVR_{}_scenes.json".format(split_name)),
               },
           ))
 
     return splits
 
-  def _generate_examples(
-      self, images_dir_path, question_file, scenes_description_file):
-    image_paths = sorted([os.path.join(images_dir_path, filename)
-                          for filename in tf.io.gfile.listdir(images_dir_path)])
+  def _generate_examples(self, images_dir_path, question_file,
+                         scenes_description_file):
+    image_paths = sorted([
+        os.path.join(images_dir_path, filename)
+        for filename in tf.io.gfile.listdir(images_dir_path)
+    ])
 
     with tf.io.gfile.GFile(question_file) as f:
       questions_json = json.load(f)
@@ -138,8 +149,10 @@ class CLEVR(tfds.core.GeneratorBasedBuilder):
       # if annotation file does not exist, we create empty annotations
       scenes_json = {"scenes": [{"objects": []}] * len(image_paths)}
 
-    attrs = ["color", "material", "shape", "size",
-             "rotation", "pixel_coords", "3d_coords"]
+    attrs = [
+        "color", "material", "shape", "size", "rotation", "pixel_coords",
+        "3d_coords"
+    ]
     for image_path, scene in zip(image_paths, scenes_json["scenes"]):
       objects = scene["objects"]
       fname = os.path.basename(image_path)
