@@ -21,7 +21,6 @@ import re
 import tensorflow.compat.v2 as tf
 import tensorflow_datasets.public_api as tfds
 
-
 _CITATION = """
 @inproceedings{pinggera2016lost,
   title={Lost and found: detecting small road hazards for self-driving vehicles},
@@ -134,9 +133,13 @@ class LostAndFound(tfds.core.GeneratorBasedBuilder):
         'image_right':
             tfds.features.Image(shape=(1024, 2048, 3), encoding_format='png'),
         'segmentation_label':
-            tfds.features.Image(shape=(1024, 2048, 1), encoding_format='png'),
+            tfds.features.Image(
+                shape=(1024, 2048, 1), encoding_format='png',
+                use_colormap=True),
         'instance_id':
-            tfds.features.Image(shape=(1024, 2048, 1), encoding_format='png'),
+            tfds.features.Image(
+                shape=(1024, 2048, 1), encoding_format='png',
+                use_colormap=True),
         'disparity_map':
             tfds.features.Image(shape=(1024, 2048, 1), encoding_format='png')
     }
