@@ -24,7 +24,8 @@ import tensorflow.compat.v2 as tf
 
 import tensorflow_datasets.public_api as tfds
 
-LSUN_URL = "http://dl.yf.io/lsun/scenes/%s_%s_lmdb.zip"
+LSUN_SCENE_URL = "http://dl.yf.io/lsun/scenes/%s_%s_lmdb.zip"
+LSUN_OBJECT_URL = "http://dl.yf.io/lsun/objects/%s.zip"
 
 _CITATION = """\
 @article{journals/corr/YuZSSX15,
@@ -44,9 +45,8 @@ _CITATION = """\
 }
 """
 
-
 # From http://dl.yf.io/lsun/categories.txt minus "test"
-_CATEGORIES = [
+_SCENES_CATEGORIES = [
     "classroom",
     "bedroom",
     "bridge",
@@ -59,11 +59,37 @@ _CATEGORIES = [
     "tower",
 ]
 
+# From http://dl.yf.io/lsun/objects/
+_OBJECTS_CATEGORIES = [
+    "airplane",
+    "bicycle",
+    "bird",
+    "boat",
+    "bottle",
+    "bus",
+    "car",
+    "cat",
+    "chair",
+    "cow",
+    "dining_table",
+    "dog",
+    "horse",
+    "motorbike",
+    "person",
+    "potted_plant",
+    "sheep",
+    "sofa",
+    "train",
+    "tv-monitor",
+]
+
 
 def _make_lmdb_dataset(path):
   return tfds.core.lazy_imports.tensorflow_io.IODataset.from_lmdb(path)
 
 
+
+
 class Lsun(tfds.core.GeneratorBasedBuilder):
   """Lsun dataset."""
 
@@ -71,11 +97,14 @@ class Lsun(tfds.core.GeneratorBasedBuilder):
       tfds.core.BuilderConfig(  # pylint: disable=g-complex-comprehension
           name=category,
           description="Images of category %s" % category,
-          version=tfds.core.Version("3.0.0"),
+          version=tfds.core.Version("3.1.0"),
           release_notes={
               "3.0.0": "New split API (https://tensorflow.org/datasets/splits)",
+              "3.1.0":
+                  "Add builder config for missing `person` object category, "
+                  "and add `id` to the feature dict",
           },
-      ) for category in _CATEGORIES
+      ) for category in (_SCENES_CATEGORIES + _OBJECTS_CATEGORIES)
   ]
 
   def _info(self):
@@ -84,6 +113,7 @@ class Lsun(tfds.core.GeneratorBasedBuilder):
         description=("Large scale images showing different objects "
                      "from given categories like bedroom, tower etc."),
         features=tfds.features.FeaturesDict({
+            "id": tfds.features.Text(),
             "image": tfds.features.Image(encoding_format="jpeg"),
         }),
         homepage="https://www.yf.io/p/lsun",
@@ -91,29 +121,47 @@ class Lsun(tfds.core.GeneratorBasedBuilder):
     )
 
   def _split_generators(self, dl_manager):
-    extracted_dirs = dl_manager.download_and_extract({
-        "train": LSUN_URL % (self.builder_config.name, "train"),
-        "val": LSUN_URL % (self.builder_config.name, "val")
-    })
-    return [
-        tfds.core.SplitGenerator(
-            name=tfds.Split.TRAIN,
-            gen_kwargs={
-                "extracted_dir": extracted_dirs["train"],
-                "file_path": "%s_%s_lmdb" % (self.builder_config.name, "train")
-            }),
-        tfds.core.SplitGenerator(
-            name=tfds.Split.VALIDATION,
-            gen_kwargs={
-                "extracted_dir": extracted_dirs["val"],
-                "file_path": "%s_%s_lmdb" % (self.builder_config.name, "val")
-            }),
-    ]
+    if self.builder_config.name in _SCENES_CATEGORIES:
+      extracted_dirs = dl_manager.download_and_extract({
+          "train": LSUN_SCENE_URL % (self.builder_config.name, "train"),
+          "val": LSUN_SCENE_URL % (self.builder_config.name, "val")
+      })
+      return [
+          tfds.core.SplitGenerator(
+              name=tfds.Split.TRAIN,
+              gen_kwargs={
+                  "extracted_dir":
+                      extracted_dirs["train"],
+                  "file_path":
+                      "%s_%s_lmdb" % (self.builder_config.name, "train")
+              }),
+          tfds.core.SplitGenerator(
+              name=tfds.Split.VALIDATION,
+              gen_kwargs={
+                  "extracted_dir": extracted_dirs["val"],
+                  "file_path": "%s_%s_lmdb" % (self.builder_config.name, "val")
+              }),
+      ]
+    else:
+      extracted_dirs = dl_manager.download_and_extract({
+          "train": LSUN_OBJECT_URL % self.builder_config.name,
+      })
+      return [
+          tfds.core.SplitGenerator(
+              name=tfds.Split.TRAIN,
+              gen_kwargs={
+                  "extracted_dir": extracted_dirs["train"],
+                  "file_path": self.builder_config.name
+              })
+      ]
 
   def _generate_examples(self, extracted_dir, file_path):
     with tf.Graph().as_default():
       path = os.path.join(extracted_dir, file_path, "data.mdb")
       dataset = _make_lmdb_dataset(path)
-      for i, (_, jpeg_image) in enumerate(tfds.as_numpy(dataset)):
-        record = {"image": io.BytesIO(jpeg_image)}
+      for i, (id_bytes, jpeg_image) in enumerate(tfds.as_numpy(dataset)):
+        record = {
+            "id": id_bytes.decode("utf-8"),
+            "image": io.BytesIO(jpeg_image),
+        }
         yield i, record
