@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for Bigearthnet data loading."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from tensorflow_datasets import testing
 from tensorflow_datasets.image_classification import bigearthnet
 
@@ -31,5 +26,6 @@ class BigearthnetTest(testing.DatasetBuilderTestCase):
   }
   DL_EXTRACT_RESULT = "BigEarthNet-v1.0.tar.gz"
 
+
 if __name__ == "__main__":
   testing.test_main()
