@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -37,21 +37,25 @@ This version contains image-level labels only. The original dataset also
 contains bounding boxes.
 """
 _LABELS_FNAME = "image_classification/caltech101_labels.txt"
-_URL = "http://www.vision.caltech.edu/Image_Datasets/Caltech101/"
-_IMAGES_FNAME = "101_ObjectCategories.tar.gz"
+# Original url should be
+# http://www.vision.caltech.edu/Image_Datasets/Caltech101/101_ObjectCategories.tar.gz
+# which redirect to drive. We could use the original URL once
+# `downloader.download` correctly handle drive URLs hidden behind a redirection.
+_URL = "https://drive.google.com/uc?export=download&id=137RyRjvTBkBiIfeYBNZBtViDHQ6_Ewsp"
 _TRAIN_POINTS_PER_CLASS = 30
 
 
 class Caltech101(tfds.core.GeneratorBasedBuilder):
   """Caltech-101."""
 
-  VERSION = tfds.core.Version("3.0.0")
+  VERSION = tfds.core.Version("3.0.1")
   RELEASE_NOTES = {
       "3.0.0": "New split API (https://tensorflow.org/datasets/splits)",
+      "3.0.1": "Website URL update",
   }
 
   def _info(self):
-    names_file = tfds.core.get_tfds_path(_LABELS_FNAME)
+    names_file = tfds.core.tfds_path(_LABELS_FNAME)
     return tfds.core.DatasetInfo(
         builder=self,
         description=_DESCRIPTION,
@@ -61,12 +65,11 @@ class Caltech101(tfds.core.GeneratorBasedBuilder):
             "image/file_name": tfds.features.Text(),  # E.g. 'image_0001.jpg'.
         }),
         supervised_keys=("image", "label"),
-        homepage=_URL,
-        citation=_CITATION
-        )
+        homepage="http://www.vision.caltech.edu/Image_Datasets/Caltech101/",
+        citation=_CITATION)
 
   def _split_generators(self, dl_manager):
-    path = dl_manager.download_and_extract(os.path.join(_URL, _IMAGES_FNAME))
+    path = dl_manager.download_and_extract(_URL)
     return [
         tfds.core.SplitGenerator(
             name=tfds.Split.TRAIN,
@@ -119,8 +122,8 @@ class Caltech101(tfds.core.GeneratorBasedBuilder):
           if _TRAIN_POINTS_PER_CLASS > len(fnames):
             raise ValueError("Fewer than {} ({}) points in class {}".format(
                 _TRAIN_POINTS_PER_CLASS, len(fnames), d))
-          train_fnames = np.random.choice(fnames, _TRAIN_POINTS_PER_CLASS,
-                                          replace=False)
+          train_fnames = np.random.choice(
+              fnames, _TRAIN_POINTS_PER_CLASS, replace=False)
           test_fnames = set(fnames).difference(train_fnames)
           fnames_to_emit = train_fnames if is_train_split else test_fnames
 
