@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -74,20 +74,15 @@ class Cassava(tfds.core.GeneratorBasedBuilder):
     return [
         tfds.core.SplitGenerator(
             name=tfds.Split.TRAIN,
-            gen_kwargs={
-                "datapath": train_path},
+            gen_kwargs={"datapath": train_path},
         ),
-
         tfds.core.SplitGenerator(
             name=tfds.Split.TEST,
-            gen_kwargs={
-                "datapath": test_path},
+            gen_kwargs={"datapath": test_path},
         ),
-
         tfds.core.SplitGenerator(
             name=tfds.Split.VALIDATION,
-            gen_kwargs={
-                "datapath": validation_path},
+            gen_kwargs={"datapath": validation_path},
         ),
     ]
 
@@ -102,4 +97,3 @@ class Cassava(tfds.core.GeneratorBasedBuilder):
             "label": label,
         }
         yield fname, record
-
