@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for corrupted Cifar10."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from tensorflow_datasets import testing
 from tensorflow_datasets.image_classification import cifar10_corrupted
 
@@ -27,7 +22,9 @@ from tensorflow_datasets.image_classification import cifar10_corrupted
 class Cifar10CorruptedTest(testing.DatasetBuilderTestCase):
 
   BUILDER_CONFIG_NAMES_TO_TEST = [
-      "elastic_1", "elastic_4", "elastic_5",
+      "elastic_1",
+      "elastic_4",
+      "elastic_5",
   ]
 
   DATASET_CLASS = cifar10_corrupted.Cifar10Corrupted
