@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -77,8 +77,6 @@ class CycleGAN(tfds.core.GeneratorBasedBuilder):
   BUILDER_CONFIGS = [
       CycleGANConfig(  # pylint: disable=g-complex-comprehension
           name=config_name,
-          description=("A dataset consisting of images from two classes A and "
-                       "B (For example: horses/zebras, apple/orange,...)"),
           version=tfds.core.Version("2.0.0"),
           release_notes={
               "2.0.0": "New split API (https://tensorflow.org/datasets/splits)",
@@ -90,14 +88,14 @@ class CycleGAN(tfds.core.GeneratorBasedBuilder):
   def _info(self):
     return tfds.core.DatasetInfo(
         builder=self,
-        description=self.builder_config.description,
+        description="A dataset consisting of images from two classes A and "
+        "B (For example: horses/zebras, apple/orange,...)",
         features=tfds.features.FeaturesDict({
             "image": tfds.features.Image(),
             "label": tfds.features.ClassLabel(names=["A", "B"]),
         }),
         supervised_keys=("image", "label"),
-        homepage=
-        "https://people.eecs.berkeley.edu/~taesung_park/CycleGAN/datasets/",
+        homepage="https://people.eecs.berkeley.edu/~taesung_park/CycleGAN/datasets/",
         citation=_CITATION,
     )
 
@@ -115,26 +113,22 @@ class CycleGAN(tfds.core.GeneratorBasedBuilder):
 
     return [
         tfds.core.SplitGenerator(
-            name="trainA",
-            gen_kwargs={
+            name="trainA", gen_kwargs={
                 "path": train_a_path,
                 "label": "A",
             }),
         tfds.core.SplitGenerator(
-            name="trainB",
-            gen_kwargs={
+            name="trainB", gen_kwargs={
                 "path": train_b_path,
                 "label": "B",
             }),
         tfds.core.SplitGenerator(
-            name="testA",
-            gen_kwargs={
+            name="testA", gen_kwargs={
                 "path": test_a_path,
                 "label": "A",
             }),
         tfds.core.SplitGenerator(
-            name="testB",
-            gen_kwargs={
+            name="testB", gen_kwargs={
                 "path": test_b_path,
                 "label": "B",
             }),
