@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -44,10 +44,13 @@ class Dmlab(tfds.core.GeneratorBasedBuilder):
         {close, far, very far} x {positive reward, negative reward}
         respectively."""),
         features=tfds.features.FeaturesDict({
-            "image": tfds.features.Image(shape=(360, 480, 3),
-                                         encoding_format="jpeg"),
-            "filename": tfds.features.Text(),
-            "label": tfds.features.ClassLabel(num_classes=6),
+            "image":
+                tfds.features.Image(
+                    shape=(360, 480, 3), encoding_format="jpeg"),
+            "filename":
+                tfds.features.Text(),
+            "label":
+                tfds.features.ClassLabel(num_classes=6),
         }),
         homepage="https://github.com/google-research/task_adaptation",
         citation=r"""@article{zhai2019visual,
@@ -64,8 +67,7 @@ class Dmlab(tfds.core.GeneratorBasedBuilder):
                               primaryClass={cs.CV},
                               url = {https://arxiv.org/abs/1910.04867}
                           }""",
-        supervised_keys=("image", "label")
-    )
+        supervised_keys=("image", "label"))
 
   def _split_generators(self, dl_manager):
     path = dl_manager.download_and_extract(_URL)
