@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Eurosat remote sensing benchmarking dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import io
 import os
 
@@ -74,8 +69,8 @@ class EurosatConfig(tfds.core.BuilderConfig):
     if selection not in _DATA_OPTIONS:
       raise ValueError('selection must be one of %s' % _DATA_OPTIONS)
 
-    super(EurosatConfig, self).__init__(version=tfds.core.Version('2.0.0'),
-                                        **kwargs)
+    super(EurosatConfig, self).__init__(
+        version=tfds.core.Version('2.0.0'), **kwargs)
     self.selection = selection
     self.download_url = download_url
     self.subdir = subdir
@@ -157,13 +152,12 @@ class Eurosat(tfds.core.GeneratorBasedBuilder):
             'label': label,
             'filename': os.path.basename(filename)
         }
-      yield filename, record
+      yield f'{label}_{os.path.basename(filename)}', record
 
 
 def _extract_channels(filename):
   with tf.io.gfile.GFile(filename, 'rb') as f:
-    arr = tfds.core.lazy_imports.skimage.external.tifffile.imread(
-        io.BytesIO(f.read()))
+    arr = tfds.core.lazy_imports.tifffile.imread(io.BytesIO(f.read()))
 
   arr = arr.astype('float32')
   return arr
