@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,11 +21,10 @@ from tensorflow_datasets.image_classification import flowers
 class TFFlowersTest(testing.DatasetBuilderTestCase):
   DATASET_CLASS = flowers.TFFlowers
 
-  SPLITS = {
-      'train': 5
-  }
+  SPLITS = {'train': 5}
 
   DL_DOWNLOAD_RESULT = 'flower_photos.tgz'
 
+
 if __name__ == '__main__':
   testing.test_main()
