@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,22 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for Geirhos conflict stimuli."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from tensorflow_datasets.image_classification import geirhos_conflict_stimuli
 import tensorflow_datasets.testing as tfds_test
 
 
 class GeirhosConflictStimuliTest(tfds_test.DatasetBuilderTestCase):
   DATASET_CLASS = geirhos_conflict_stimuli.GeirhosConflictStimuli
-  SPLITS = {
-      'test': 2
-  }
+  SPLITS = {'test': 2}
 
   DL_EXTRACT_RESULT = {
       'texture_vs_shape': 'texture_vs_shape',
