@@ -47,11 +47,14 @@ class ImagenetRTest(tfds.testing.DatasetBuilderTestCase):
     for features in dataset_utils.as_numpy(dataset['test']):
       label_frequncies.update([label_feature.int2str(features['label'])])
       filenames.append(features['file_name'])
-    self.assertEqual(dict(label_frequncies),
-                     {'n01443537': 2,
-                      'n01484850': 3,
-                      'n12267677': 5})
+    self.assertEqual(
+        dict(label_frequncies), {
+            'n01443537': 2,
+            'n01484850': 3,
+            'n12267677': 5
+        })
     self.assertIn(b'n01443537/1.jpeg', filenames)
 
+
 if __name__ == '__main__':
   tfds.testing.test_main()
