@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,16 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
+"""Tests for ImageNet-v2 image classification dataset."""
 from tensorflow_datasets.image_classification import imagenet_v2
 import tensorflow_datasets.public_api as tfds
 
 
 class ImagenetV2Test(tfds.testing.DatasetBuilderTestCase):
 
-  BUILDER_CONFIG_NAMES_TO_TEST = ['matched-frequency',
-                                  'threshold-0.7',
-                                  'topimages']
+  BUILDER_CONFIG_NAMES_TO_TEST = [
+      'matched-frequency', 'threshold-0.7', 'topimages'
+  ]
 
   DATASET_CLASS = imagenet_v2.ImagenetV2
   SPLITS = {
