@@ -62,8 +62,7 @@ class LFW(tfds.core.GeneratorBasedBuilder):
     # There is no train/test split predefined
     return [
         tfds.core.SplitGenerator(
-            name=tfds.Split.TRAIN,
-            gen_kwargs={
+            name=tfds.Split.TRAIN, gen_kwargs={
                 "data_path": path,
             }),
     ]
