@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -224,11 +224,7 @@ class EMNISTConfig(tfds.core.BuilderConfig):
       test_examples: number of test examples
       **kwargs: keyword arguments forwarded to super.
     """
-    super(EMNISTConfig, self).__init__(
-        version=tfds.core.Version(
-            "3.0.0",
-            "New split API (https://tensorflow.org/datasets/splits)"),
-        **kwargs)
+    super(EMNISTConfig, self).__init__(**kwargs)
     self.class_number = class_number
     self.train_examples = train_examples
     self.test_examples = test_examples
@@ -237,8 +233,10 @@ class EMNISTConfig(tfds.core.BuilderConfig):
 class EMNIST(MNIST):
   """Emnist dataset."""
   URL = "https://www.itl.nist.gov/iaui/vip/cs_links/EMNIST/gzip.zip"
-  VERSION = None  # Configs.
-
+  VERSION = tfds.core.Version("3.0.0")
+  RELEASE_NOTES = {
+      "3.0.0": "New split API (https://tensorflow.org/datasets/splits)",
+  }
   BUILDER_CONFIGS = [
       EMNISTConfig(
           name="byclass",
@@ -246,7 +244,6 @@ class EMNIST(MNIST):
           train_examples=697932,
           test_examples=116323,
           description="EMNIST ByClass",
-
       ),
       EMNISTConfig(
           name="bymerge",
@@ -327,9 +324,8 @@ class EMNIST(MNIST):
     }
 
     dir_name = os.path.join(dl_manager.download_and_extract(self.URL), "gzip")
-    extracted = dl_manager.extract({
-        k: os.path.join(dir_name, fname) for k, fname in filenames.items()
-    })
+    extracted = dl_manager.extract(
+        {k: os.path.join(dir_name, fname) for k, fname in filenames.items()})
 
     return [
         tfds.core.SplitGenerator(
