@@ -29,7 +29,7 @@ import numpy as np
 import tensorflow.compat.v2 as tf
 import tensorflow_datasets.public_api as tfds
 
-_DESCRIPTION = '''\
+_DESCRIPTION = """\
 Open Images is a dataset of ~9M images that have been annotated with image-level
  labels and object bounding boxes.
 
@@ -40,9 +40,9 @@ annotators to ensure accuracy and consistency. The images are very diverse and
 often contain complex scenes with several objects (8.4 per image on average).
 Moreover, the dataset is annotated with image-level labels spanning thousands of
 classes.
-'''
+"""
 
-_CITATION = '''\
+_CITATION = """\
 @article{OpenImages,
   author = {Alina Kuznetsova and
             Hassan Rom and
@@ -89,47 +89,64 @@ _CITATION = '''\
              https://storage.googleapis.com/openimages/web/index.html},
   year={2017}
 }
-'''
+"""
 
 # Reading from .tar.gz is slower than extracting the gz and then reading from
 # tar. We still read from the tar because it's faster to read fewer files on
 # many network based FS.
 # pylint: disable=line-too-long
 _URLS = {
-    'train_images': [tfds.download.Resource(  # pylint:disable=g-complex-comprehension
-        url='http://open-images-dataset.s3.amazonaws.com/tar/train_%s.tar.gz' % i_,
-        extract_method=tfds.download.ExtractMethod.GZIP)
-                     for i_ in '0123456789abcdef'],
-    'test_images': tfds.download.Resource(
-        url='http://open-images-dataset.s3.amazonaws.com/tar/test.tar.gz',
-        extract_method=tfds.download.ExtractMethod.GZIP),
-    'validation_images': tfds.download.Resource(
-        url='http://open-images-dataset.s3.amazonaws.com/tar/validation.tar.gz',
-        extract_method=tfds.download.ExtractMethod.GZIP),
-    'train_human_labels': 'https://storage.googleapis.com/openimages/2018_04/train/train-annotations-human-imagelabels.csv',
-    'train_machine_labels': 'https://storage.googleapis.com/openimages/2018_04/train/train-annotations-machine-imagelabels.csv',
-    'test_human_labels': 'https://storage.googleapis.com/openimages/2018_04/test/test-annotations-human-imagelabels.csv',
-    'test_machine_labels': 'https://storage.googleapis.com/openimages/2018_04/test/test-annotations-machine-imagelabels.csv',
-    'validation_human_labels': 'https://storage.googleapis.com/openimages/2018_04/validation/validation-annotations-human-imagelabels.csv',
-    'validation_machine_labels': 'https://storage.googleapis.com/openimages/2018_04/validation/validation-annotations-machine-imagelabels.csv',
-    'train-annotations-bbox': 'https://storage.googleapis.com/openimages/2018_04/train/train-annotations-bbox.csv',
-    'test-annotations-bbox': 'https://storage.googleapis.com/openimages/2018_04/test/test-annotations-bbox.csv',
-    'validation-annotations-bbox': 'https://storage.googleapis.com/openimages/2018_04/validation/validation-annotations-bbox.csv',
+    'train_images': [
+        tfds.download.Resource(  # pylint:disable=g-complex-comprehension
+            url='http://open-images-dataset.s3.amazonaws.com/tar/train_%s.tar.gz'
+            % i_,
+            extract_method=tfds.download.ExtractMethod.GZIP)
+        for i_ in '0123456789abcdef'
+    ],
+    'test_images':
+        tfds.download.Resource(
+            url='http://open-images-dataset.s3.amazonaws.com/tar/test.tar.gz',
+            extract_method=tfds.download.ExtractMethod.GZIP),
+    'validation_images':
+        tfds.download.Resource(
+            url='http://open-images-dataset.s3.amazonaws.com/tar/validation.tar.gz',
+            extract_method=tfds.download.ExtractMethod.GZIP),
+    'train_human_labels':
+        'https://storage.googleapis.com/openimages/2018_04/train/train-annotations-human-imagelabels.csv',
+    'train_machine_labels':
+        'https://storage.googleapis.com/openimages/2018_04/train/train-annotations-machine-imagelabels.csv',
+    'test_human_labels':
+        'https://storage.googleapis.com/openimages/2018_04/test/test-annotations-human-imagelabels.csv',
+    'test_machine_labels':
+        'https://storage.googleapis.com/openimages/2018_04/test/test-annotations-machine-imagelabels.csv',
+    'validation_human_labels':
+        'https://storage.googleapis.com/openimages/2018_04/validation/validation-annotations-human-imagelabels.csv',
+    'validation_machine_labels':
+        'https://storage.googleapis.com/openimages/2018_04/validation/validation-annotations-machine-imagelabels.csv',
+    'train-annotations-bbox':
+        'https://storage.googleapis.com/openimages/2018_04/train/train-annotations-bbox.csv',
+    'test-annotations-bbox':
+        'https://storage.googleapis.com/openimages/2018_04/test/test-annotations-bbox.csv',
+    'validation-annotations-bbox':
+        'https://storage.googleapis.com/openimages/2018_04/validation/validation-annotations-bbox.csv',
 }
 # pylint: enable=line-too-long
 
 _Object = collections.namedtuple('Object', ['label', 'confidence', 'source'])
 _Bbox = collections.namedtuple('Bbox', [
-    'label', 'source', 'bbox', 'is_occluded',
-    'is_truncated', 'is_group_of', 'is_depiction', 'is_inside'])
+    'label', 'source', 'bbox', 'is_occluded', 'is_truncated', 'is_group_of',
+    'is_depiction', 'is_inside'
+])
 
 IMAGE_LEVEL_SOURCES = [
-    'verification', 'crowdsource-verification',  # human labels
+    'verification',
+    'crowdsource-verification',  # human labels
     'machine',
 ]
 
 BBOX_SOURCES = [
-    'freeform', 'xclick',  # Manually drawn boxes.
+    'freeform',
+    'xclick',  # Manually drawn boxes.
     'activemil',  # Machine generated, human controlled.
 ]
 
@@ -175,46 +192,54 @@ class OpenImagesV4(tfds.core.GeneratorBasedBuilder):
   ]
 
   def _info(self):
-    source_class_label = tfds.features.ClassLabel(
-        names=IMAGE_LEVEL_SOURCES + BBOX_SOURCES)
+    source_class_label = tfds.features.ClassLabel(names=IMAGE_LEVEL_SOURCES +
+                                                  BBOX_SOURCES)
     all_class_label = tfds.features.ClassLabel(
-        names_file=tfds.core.tfds_path(os.path.join(
-            'object_detection', 'open_images_classes_all.txt')))
+        names_file=tfds.core.tfds_path(
+            os.path.join('object_detection', 'open_images_classes_all.txt')))
     trainable_class_label = tfds.features.ClassLabel(
-        names_file=tfds.core.tfds_path(os.path.join(
-            'object_detection', 'open_images_classes_trainable.txt')))
+        names_file=tfds.core.tfds_path(
+            os.path.join('object_detection',
+                         'open_images_classes_trainable.txt')))
     boxable_class_label = tfds.features.ClassLabel(
-        names_file=tfds.core.tfds_path(os.path.join(
-            'object_detection', 'open_images_classes_boxable.txt')))
+        names_file=tfds.core.tfds_path(
+            os.path.join('object_detection',
+                         'open_images_classes_boxable.txt')))
     return tfds.core.DatasetInfo(
         builder=self,
         description=_DESCRIPTION,
         features=tfds.features.FeaturesDict({
-            'image': tfds.features.Image(),
-            'image/filename': tfds.features.Text(),  # eg '226f0a1873b9bf8e.jpg'
-            'objects': tfds.features.Sequence({
-                'label': all_class_label,
-                # Original data is 0, .1, ..., 1. We use 0, 1, 2, ..., 10.
-                'confidence': tf.int32,
-                'source': source_class_label,
-            }),
-            'objects_trainable': tfds.features.Sequence({
-                'label': trainable_class_label,
-                # Original data is 0, .1, ..., 1. We use 0, 1, 2, ..., 10.
-                'confidence': tf.int32,
-                'source': source_class_label,
-            }),
-            'bobjects': tfds.features.Sequence({
-                'label': boxable_class_label,
-                'source': source_class_label,
-                'bbox': tfds.features.BBoxFeature(),
-                # Following values can be: 1 (true), 0 (false) and -1 (unknown).
-                'is_occluded': tf.int8,
-                'is_truncated': tf.int8,
-                'is_group_of': tf.int8,
-                'is_depiction': tf.int8,
-                'is_inside': tf.int8,
-            }),
+            'image':
+                tfds.features.Image(),
+            'image/filename':
+                tfds.features.Text(),  # eg '226f0a1873b9bf8e.jpg'
+            'objects':
+                tfds.features.Sequence({
+                    'label': all_class_label,
+                    # Original data is 0, .1, ..., 1. We use 0, 1, 2, ..., 10.
+                    'confidence': tf.int32,
+                    'source': source_class_label,
+                }),
+            'objects_trainable':
+                tfds.features.Sequence({
+                    'label': trainable_class_label,
+                    # Original data is 0, .1, ..., 1. We use 0, 1, 2, ..., 10.
+                    'confidence': tf.int32,
+                    'source': source_class_label,
+                }),
+            'bobjects':
+                tfds.features.Sequence({
+                    'label': boxable_class_label,
+                    'source': source_class_label,
+                    'bbox': tfds.features.BBoxFeature(),
+                    # Following values can be:
+                    # 1 (true), 0 (false) and -1 (unknown).
+                    'is_occluded': tf.int8,
+                    'is_truncated': tf.int8,
+                    'is_group_of': tf.int8,
+                    'is_depiction': tf.int8,
+                    'is_inside': tf.int8,
+                }),
         }),
         homepage='https://storage.googleapis.com/openimages/web/index.html',
         citation=_CITATION,
@@ -223,44 +248,54 @@ class OpenImagesV4(tfds.core.GeneratorBasedBuilder):
   def _split_generators(self, dl_manager):
     """Returns SplitGenerators."""
     paths = dl_manager.download_and_extract(_URLS)
+
     # Load labels from CSVs:
     def load(names):
       csv_positions = [0] * len(names)
       return functools.partial(_load_objects, [paths[name] for name in names],
                                csv_positions)
+
     train_objects = load(['train_human_labels', 'train_machine_labels'])
     test_objects = load(['test_human_labels', 'test_machine_labels'])
-    validation_objects = load(['validation_human_labels',
-                               'validation_machine_labels'])
+    validation_objects = load(
+        ['validation_human_labels', 'validation_machine_labels'])
+
     def load_boxes(name):
       csv_positions = [0]
       return functools.partial(_load_bboxes, paths[name], csv_positions)
+
     train_bbox = load_boxes('train-annotations-bbox')
     test_bbox = load_boxes('test-annotations-bbox')
     validation_bbox = load_boxes('validation-annotations-bbox')
     return [
         tfds.core.SplitGenerator(
             name=tfds.Split.TRAIN,
-            gen_kwargs=dict(archive_paths=paths['train_images'],
-                            objects_getter=train_objects,
-                            bboxes_getter=train_bbox,
-                            prefixes='0123456789abcdef'),
+            gen_kwargs=dict(
+                archive_paths=paths['train_images'],
+                objects_getter=train_objects,
+                bboxes_getter=train_bbox,
+                prefixes='0123456789abcdef'),
         ),
         tfds.core.SplitGenerator(
             name=tfds.Split.TEST,
-            gen_kwargs=dict(archive_paths=[paths['test_images']],
-                            objects_getter=test_objects,
-                            bboxes_getter=test_bbox),
+            gen_kwargs=dict(
+                archive_paths=[paths['test_images']],
+                objects_getter=test_objects,
+                bboxes_getter=test_bbox),
         ),
         tfds.core.SplitGenerator(
             name=tfds.Split.VALIDATION,
-            gen_kwargs=dict(archive_paths=[paths['validation_images']],
-                            objects_getter=validation_objects,
-                            bboxes_getter=validation_bbox),
+            gen_kwargs=dict(
+                archive_paths=[paths['validation_images']],
+                objects_getter=validation_objects,
+                bboxes_getter=validation_bbox),
         ),
     ]
 
-  def _generate_examples(self, archive_paths, objects_getter, bboxes_getter,
+  def _generate_examples(self,
+                         archive_paths,
+                         objects_getter,
+                         bboxes_getter,
                          prefixes=None):
     """Yields examples."""
     trainable_classes = set(
@@ -281,12 +316,17 @@ class OpenImagesV4(tfds.core.GeneratorBasedBuilder):
             obj for obj in image_objects if obj['label'] in trainable_classes
         ]
         record = {
-            'image': _resize_image_if_necessary(
-                fobj, target_pixels=self.builder_config.target_pixels),
-            'image/filename': fname,
-            'objects': image_objects,
-            'objects_trainable': image_objects_trainable,
-            'bobjects': image_bboxes,
+            'image':
+                _resize_image_if_necessary(
+                    fobj, target_pixels=self.builder_config.target_pixels),
+            'image/filename':
+                fname,
+            'objects':
+                image_objects,
+            'objects_trainable':
+                image_objects_trainable,
+            'bobjects':
+                image_bboxes,
         }
         yield fname, record
 
@@ -321,8 +361,8 @@ def _resize_image_if_necessary(image_fobj, target_pixels=None):
 
 def _load_objects(csv_paths, csv_positions, prefix):
   """Returns objects listed within given CSV files."""
-  logging.info('Loading CSVs %s from positions %s with prefix %s',
-               csv_paths, csv_positions, prefix)
+  logging.info('Loading CSVs %s from positions %s with prefix %s', csv_paths,
+               csv_positions, prefix)
   objects = collections.defaultdict(list)
   for i, labels_path in enumerate(csv_paths):
     with tf.io.gfile.GFile(labels_path) as csv_f:
@@ -343,8 +383,8 @@ def _load_objects(csv_paths, csv_positions, prefix):
 
 def _load_bboxes(csv_path, csv_positions, prefix):
   """Returns bounded boxes listed within given CSV file."""
-  logging.info('Loading CSVs %s from positions %s with prefix %s',
-               csv_path, csv_positions, prefix)
+  logging.info('Loading CSVs %s from positions %s with prefix %s', csv_path,
+               csv_positions, prefix)
   boxes = collections.defaultdict(list)
   with tf.io.gfile.GFile(csv_path) as csv_f:
     if csv_positions[0] > 0:
@@ -352,18 +392,31 @@ def _load_bboxes(csv_path, csv_positions, prefix):
     else:
       csv_f.readline()  # Drop headers
     reader = csv.reader(csv_f)
-    for (image_id, source, label, confidence, xmin, xmax, ymin, ymax,
-         is_occluded, is_truncated, is_group_of, is_depiction, is_inside,
-        ) in reader:
+    for (
+        image_id,
+        source,
+        label,
+        confidence,
+        xmin,
+        xmax,
+        ymin,
+        ymax,
+        is_occluded,
+        is_truncated,
+        is_group_of,
+        is_depiction,
+        is_inside,
+    ) in reader:
       if prefix and image_id[0] != prefix:
         break
       csv_positions[0] = csv_f.tell()
       image_id = int(image_id, 16)
       del confidence  # always 1 in bounding boxes.
       current_row = _Bbox(
-          label, source, tfds.features.BBox(
+          label, source,
+          tfds.features.BBox(
               float(ymin), float(xmin), float(ymax), float(xmax)),
-          int(is_occluded), int(is_truncated),
-          int(is_group_of), int(is_depiction), int(is_inside))
+          int(is_occluded), int(is_truncated), int(is_group_of),
+          int(is_depiction), int(is_inside))
       boxes[image_id].append(current_row)
   return dict(boxes)
