@@ -35,10 +35,8 @@ evaluating multilingual question answering performance. The dataset consists \
 of 7 languages: Arabic, German, Spanish, English, Hindi, Vietnamese, Chinese.
 """
 
-
 LANGUAGES = ["ar", "de", "en", "es", "hi", "vi", "zh"]
 
-
 _DOWNLOAD_URL = "https://dl.fbaipublicfiles.com/MLQA/MLQA_V1.zip"
 
 
@@ -95,8 +93,7 @@ class Mlqa(tfds.core.GeneratorBasedBuilder):
     return [
         tfds.core.SplitGenerator(  # pylint:disable=g-complex-comprehension
             name=split,
-            gen_kwargs={"filepath": path})
-        for split, path in filepaths.items()
+            gen_kwargs={"filepath": path}) for split, path in filepaths.items()
     ]
 
   def _generate_examples(self, filepath):
