@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,11 +20,12 @@ Displayed in https://www.tensorflow.org/datasets/catalog/.
 """
 
 import abc
+import html
 import textwrap
-from typing import List, Union
+from typing import List, Optional, Union
 
 import tensorflow_datasets as tfds
-
+from tensorflow_datasets.scripts.documentation import doc_utils
 
 Key = Union[int, str]
 
@@ -101,9 +102,11 @@ class Section(abc.ABC):
     if not isinstance(content, IntentedBlock):
       content = content.strip()  # Note: `strip()` cast `Block` -> `str`
     if is_block:
-      return f'{header}:\n\n{content}\n\n'
+      content = f'{header}:\n\n{content}\n\n'
     else:
-      return f'{header}: {content}\n\n'
+      content = f'{header}: {content}\n\n'
+    return content
+
 
 # --------------------------- Builder sections ---------------------------
 
@@ -114,10 +117,10 @@ class HomepageSection(Section):
 
   NAME = 'Homepage'
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     return builder.info.homepage
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
     homepage = builder.info.homepage
     return f'[{homepage}]({homepage})'
 
@@ -126,10 +129,10 @@ class DatasetDescriptionSection(Section):
 
   NAME = 'Description'
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     return builder.info.description
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
     return Block(builder.info.description)
 
 
@@ -137,11 +140,11 @@ class ConfigDescriptionSection(Section):
 
   NAME = 'Config description'
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     return builder.builder_config.description
 
-  def content(self, builder):
-    if not builder.builder_config:
+  def content(self, builder: tfds.core.DatasetBuilder):
+    if not builder.builder_config or not builder.builder_config.description:
       return _SKIP_SECTION
     return builder.builder_config.description
 
@@ -153,7 +156,11 @@ class SourceCodeSection(Section):
   def get_key(self, _):
     return True  # Always common to all configs
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
+    # TODO(tfds): Display the source code
+    if isinstance(builder, tfds.core.read_only_builder.ReadOnlyBuilder):
+      return ('Missing '
+              '([#2813](https://github.com/tensorflow/datasets/issues/2813))')
     class_path = tfds.core.utils.get_class_path(builder).split('.')
     del class_path[-2]
     class_path = '.'.join(class_path)
@@ -165,28 +172,35 @@ class VersionSection(Section):
 
   NAME = 'Versions'
 
-  def __init__(self, nightly_doc_util):
+  def __init__(self, nightly_doc_util: Optional[doc_utils.NightlyDocUtil]):
     self._nightly_doc_util = nightly_doc_util
 
-  def _list_versions(self, builder):
+  def _list_versions(self, builder: tfds.core.DatasetBuilder):
     """List versions."""
-    for v in builder.versions:  # List all available versions (in default order)
+    curr_versions = set(builder.versions)  # Registered version
+    # Merge all versions
+    all_versions = [*builder.versions, *builder.release_notes]
+    # Normalize and remove duplicates
+    all_versions = set(tfds.core.Version(v) for v in all_versions)
+    for v in sorted(all_versions):  # List all available versions
       if v == builder.version:  # Highlight the default version
         version_name = '**`{}`** (default)'.format(str(v))
       else:
         version_name = '`{}`'.format(str(v))
-      if self._nightly_doc_util.is_version_nightly(builder, str(v)):
+      if (v in curr_versions  # Filter versions only present in RELEASE_NOTES
+          and self._nightly_doc_util and
+          self._nightly_doc_util.is_version_nightly(builder, str(v))):
         nightly_str = ' ' + self._nightly_doc_util.icon
       else:
         nightly_str = ''
-      yield '    * {}{}: {}'.format(
-          version_name, nightly_str, v.description or 'No release notes.'
-      )
+      description = builder.release_notes.get(str(v), 'No release notes.')
+      yield f'    * {version_name}{nightly_str}: {description}'
 
-  def get_key(self, builder):
-    return tuple((str(v), v.description) for v in builder.versions)
+  def get_key(self, builder: tfds.core.DatasetBuilder):
+    release_key = tuple((k, v) for k, v in builder.release_notes.items())
+    return (tuple(builder.versions), release_key)
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
     return IntentedBlock('\n'.join(self._list_versions(builder)))
 
 
@@ -194,44 +208,42 @@ class DownloadSizeSection(Section):
 
   NAME = 'Download size'
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     return builder.info.download_size
 
-  def content(self, builder):
-    return f'`{tfds.units.size_str(builder.info.download_size)}`'
+  def content(self, builder: tfds.core.DatasetBuilder):
+    return f'`{builder.info.download_size}`'
 
 
 class DatasetSizeSection(Section):
 
   NAME = 'Dataset size'
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     return builder.info.dataset_size
 
-  def content(self, builder):
-    return f'`{tfds.units.size_str(builder.info.dataset_size)}`'
+  def content(self, builder: tfds.core.DatasetBuilder):
+    return f'`{builder.info.dataset_size}`'
 
 
 class ManualDatasetSection(Section):
 
   NAME = 'Manual download instructions'
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     return builder.MANUAL_DOWNLOAD_INSTRUCTIONS
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
     manual_instructions = builder.MANUAL_DOWNLOAD_INSTRUCTIONS
     if not manual_instructions:
       return _SKIP_SECTION
     manual_instructions = tfds.core.utils.dedent(manual_instructions)
-    return textwrap.dedent(
-        f"""
+    return textwrap.dedent(f"""
         This dataset requires you to
         download the source data manually into `download_config.manual_dir`
         (defaults to `~/tensorflow_datasets/downloads/manual/`):<br/>
         {tfds.core.utils.indent(manual_instructions, '        ')}
-        """
-    )
+        """)
 
 
 class AutocacheSection(Section):
@@ -239,10 +251,9 @@ class AutocacheSection(Section):
   NAME = 'Auto-cached'
   EXTRA_DOC = (
       ' ([documentation]'
-      '(https://www.tensorflow.org/datasets/performances#auto-caching))'
-  )
+      '(https://www.tensorflow.org/datasets/performances#auto-caching))')
 
-  def _build_autocached_info(self, builder):
+  def _build_autocached_info(self, builder: tfds.core.DatasetBuilder):
     """Returns the auto-cache information string."""
     always_cached = {}
     never_cached = {}
@@ -250,9 +261,13 @@ class AutocacheSection(Section):
     for split_name in sorted(builder.info.splits.keys()):
       split_name = str(split_name)
       cache_shuffled = builder._should_cache_ds(  # pylint: disable=protected-access
-          split_name, shuffle_files=True, read_config=tfds.ReadConfig())
+          split_name,
+          shuffle_files=True,
+          read_config=tfds.ReadConfig())
       cache_unshuffled = builder._should_cache_ds(  # pylint: disable=protected-access
-          split_name, shuffle_files=False, read_config=tfds.ReadConfig())
+          split_name,
+          shuffle_files=False,
+          read_config=tfds.ReadConfig())
 
       if all((cache_shuffled, cache_unshuffled)):
         always_cached[split_name] = None
@@ -283,10 +298,10 @@ class AutocacheSection(Section):
       autocached_info = ', '.join(autocached_info_parts)
     return autocached_info
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     return self._build_autocached_info(builder)
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
     return self._build_autocached_info(builder)
 
 
@@ -299,42 +314,36 @@ class SplitInfoSection(Section):
       return '{:,}'.format(split_info.num_examples)
     return 'Not computed'
 
-  def get_key(self, builder):
-    return tuple(
-        (str(s.name), int(s.num_examples)) for s in builder.info.splits.values()
-    )
+  def get_key(self, builder: tfds.core.DatasetBuilder):
+    return tuple((str(s.name), int(s.num_examples))
+                 for s in builder.info.splits.values())
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
     splits_str = ('\n').join([
         f'`\'{split_name}\'` | {self._get_num_examples(split_info)}'
         for split_name, split_info in sorted(builder.info.splits.items())
     ])
     return Block(
-        textwrap.dedent(
-            f"""
+        textwrap.dedent(f"""
             Split  | Examples
             :----- | -------:
             {tfds.core.utils.indent(splits_str, '            ')}
-            """
-        )
-    )
+            """))
 
 
 class FeatureInfoSection(Section):
 
   NAME = 'Features'
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     return repr(builder.info.features)
 
-  def content(self, builder):
-    code = textwrap.dedent(
-        """
+  def content(self, builder: tfds.core.DatasetBuilder):
+    code = textwrap.dedent("""
         ```python
         {}
         ```
-        """
-    ).format(builder.info.features)
+        """).format(builder.info.features)
     return Block(code)
 
 
@@ -343,13 +352,12 @@ class SupervisedKeySection(Section):
   NAME = 'Supervised keys'
   EXTRA_DOC = (
       ' (See [`as_supervised` doc]'
-      '(https://www.tensorflow.org/datasets/api_docs/python/tfds/load#args))'
-  )
+      '(https://www.tensorflow.org/datasets/api_docs/python/tfds/load#args))')
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     return builder.info.supervised_keys
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
     return f'`{str(builder.info.supervised_keys)}`'
 
 
@@ -357,21 +365,44 @@ class DatasetCitationSection(Section):
 
   NAME = 'Citation'
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     return builder.info.citation
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
     if not builder.info.citation:
       return ''
     return Block(
-        textwrap.dedent(
-            f"""
+        textwrap.dedent(f"""
             ```
             {tfds.core.utils.indent(builder.info.citation, '            ')}
             ```
-            """
-        )
-    )
+            """))
+
+
+class KnowYourDataSection(Section):
+
+  NAME = 'Visualization'
+
+  def __init__(self):
+    super().__init__()
+    self._catalog_urls = {}
+
+  def get_key(self, builder: tfds.core.DatasetBuilder):
+    return None  # Single url for all configs
+
+  def content(self, builder: tfds.core.DatasetBuilder):
+    url = self._catalog_urls.get(builder.name)
+    if url:
+      return f"""
+        <a class="button button-with-icon" href="{url}">
+          Explore in Know Your Data
+          <span class="material-icons icon-after" aria-hidden="true">
+            north_east
+          </span>
+        </a>
+      """
+    else:
+      return _SKIP_SECTION
 
 
 class DatasetVisualizationSection(Section):
@@ -384,12 +415,12 @@ class DatasetVisualizationSection(Section):
   def __init__(self, visualization_util):
     self._visualization_util = visualization_util
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     if self._visualization_util.has_visualization(builder):
       return builder.info.full_name
     return None  # Fuse the sections together if no configs are available
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
     if not self._visualization_util.has_visualization(builder):
       return 'Not supported.'
     return Block(self._visualization_util.get_html_tag(builder))
@@ -401,18 +432,24 @@ class DatasetDataframeSection(Section):
   EXTRA_DOC = (
       ' ([tfds.as_dataframe](https://www.tensorflow.org/datasets/api_docs/python/tfds/as_dataframe))'
   )
+  # Artificially limit the amount of dataframe blocks to optimize page loading.
+  _MAX_DATAFRAME_BLOCKS = 100
 
   def __init__(self, dataframe_util):
     self._dataframe_util = dataframe_util
+    self._blocks_generated = 0
 
-  def get_key(self, builder):
+  def get_key(self, builder: tfds.core.DatasetBuilder):
     if self._dataframe_util.has_visualization(builder):
       return builder.info.full_name
     return None  # Fuse the sections together if no configs are available
 
-  def content(self, builder):
+  def content(self, builder: tfds.core.DatasetBuilder):
+    if self._blocks_generated >= self._MAX_DATAFRAME_BLOCKS:
+      return f'Only shown for the first {self._MAX_DATAFRAME_BLOCKS} configs.'
     if not self._dataframe_util.has_visualization(builder):
       return 'Missing.'
+    self._blocks_generated += 1
     return Block(self._dataframe_util.get_html_tag(builder))
 
 
@@ -434,7 +471,8 @@ def _display_builder(
 
 
 def _display_all_builders(
-    nightly_doc_util,
+    namespace: Optional[str],
+    nightly_doc_util: Optional[doc_utils.NightlyDocUtil],
     builders: List[tfds.core.DatasetBuilder],
     all_sections: List[Section],
 ) -> str:
@@ -453,11 +491,16 @@ def _display_all_builders(
   unique_builder_str = []
   for i, builder in enumerate(builders):
     header_suffix = ' (default config)' if i == 0 else ''
-    nightly_str = (' ' + nightly_doc_util.icon) \
-        if nightly_doc_util.is_config_nightly(builder) else ''
-    unique_builder_str.append(
-        f'## {builder.name}/{builder.builder_config.name}'
-        f'{header_suffix}{nightly_str}\n')
+    if nightly_doc_util and nightly_doc_util.is_config_nightly(builder):
+      nightly_str = ' ' + nightly_doc_util.icon
+    else:
+      nightly_str = ''
+    ds_name = tfds.core.utils.DatasetName(
+        namespace=namespace,
+        name=builder.name,
+    )
+    unique_builder_str.append(f'## {ds_name}/{builder.builder_config.name}'
+                              f'{header_suffix}{nightly_str}\n')
     unique_builder_str.append(_display_builder(builder, unique_sections))
   unique_builder_str = '\n'.join(unique_builder_str)
 
@@ -467,18 +510,28 @@ def _display_all_builders(
 # --------------------------- Main page ---------------------------
 
 
-def _display_dataset_heading(builder):
-  return f'# `{builder.name}`'
+def _display_dataset_heading(
+    namespace: Optional[str],
+    builder: tfds.core.DatasetBuilder,
+) -> str:
+  ds_name = tfds.core.utils.DatasetName(namespace=namespace, name=builder.name)
+  return f"""
+      # `{ds_name}`
+
+      """
 
 
-def _display_nightly_str(nightly_doc_util, builder):
+def _display_nightly_str(
+    nightly_doc_util: Optional[doc_utils.NightlyDocUtil],
+    builder: tfds.core.DatasetBuilder,
+) -> str:
   """Header nightly note section."""
-  if nightly_doc_util.is_builder_nightly(builder):
+  if nightly_doc_util and nightly_doc_util.is_builder_nightly(builder):
     return f"""\
       Note: This dataset was added recently and is only available in our
       `tfds-nightly` package  {nightly_doc_util.icon}.
       """
-  elif nightly_doc_util.has_nightly(builder):
+  elif nightly_doc_util and nightly_doc_util.has_nightly(builder):
     return f"""\
       Note: This dataset has been updated since the last stable release.
       The new versions and config marked with {nightly_doc_util.icon}
@@ -488,7 +541,7 @@ def _display_nightly_str(nightly_doc_util, builder):
     return ''
 
 
-def _display_manual_instructions(builder):
+def _display_manual_instructions(builder: tfds.core.DatasetBuilder):
   """Header manual note section."""
   if builder.MANUAL_DOWNLOAD_INSTRUCTIONS:
     return 'Warning: Manual download required. See instructions below.'
@@ -497,7 +550,8 @@ def _display_manual_instructions(builder):
 
 def _display_builder_configs(
     builder: tfds.core.DatasetBuilder,
-    nightly_doc_util,
+    namespace: Optional[str],
+    nightly_doc_util: Optional[doc_utils.NightlyDocUtil],
     config_builders: List[tfds.core.DatasetBuilder],
     all_sections: List[Section],
 ) -> str:
@@ -506,19 +560,90 @@ def _display_builder_configs(
   if not builder.builder_config:
     return _display_builder(builder, all_sections)
   # Second case: Builder configs
-  return _display_all_builders(nightly_doc_util, config_builders, all_sections)
+  return _display_all_builders(
+      nightly_doc_util=nightly_doc_util,
+      namespace=namespace,
+      builders=config_builders,
+      all_sections=all_sections,
+  )
+
+
+def _escape(val: str) -> str:
+  val = html.escape(val, quote=True)
+  val = val.replace('\n', '&#10;')
+  val = val.strip()
+  return val
+
+
+def _display_schema_org(
+    builder: tfds.core.DatasetBuilder,
+    visu_doc_util: Optional[doc_utils.VisualizationDocUtil],
+) -> str:
+  r"""Builds schema.org microdata for DatasetSearch from DatasetBuilder.
+
+  Specs: https://developers.google.com/search/docs/data-types/dataset#dataset
+  Testing tool: https://search.google.com/structured-data/testing-tool
+  For Google Dataset Search: https://toolbox.google.com/datasetsearch
+
+  Microdata format was chosen over JSON-LD due to the fact that Markdown
+  rendering engines remove all \<script\> tags.
+
+  Args:
+    builder: Dataset to document
+    visu_doc_util: Visualization util
+
+  Returns:
+    schema_org: The schema.org
+  """
+  description = f"""
+
+  To use this dataset:
+
+  ```python
+  import tensorflow_datasets as tfds
+
+  ds = tfds.load('{builder.info.name}', split='train')
+  for ex in ds.take(4):
+    print(ex)
+  ```
+
+  See [the guide](https://www.tensorflow.org/datasets/overview) for more
+  informations on [tensorflow_datasets](https://www.tensorflow.org/datasets).
+
+  """
+  description = builder.info.description + textwrap.dedent(description)
+  if visu_doc_util and visu_doc_util.has_visualization(builder):
+    description += visu_doc_util.get_html_tag(builder) + '\n\n'
+
+  text = f"""\
+  <div itemscope itemtype="http://schema.org/Dataset">
+    <div itemscope itemprop="includedInDataCatalog" itemtype="http://schema.org/DataCatalog">
+      <meta itemprop="name" content="TensorFlow Datasets" />
+    </div>
+    <meta itemprop="name" content="{builder.info.name}" />
+    <meta itemprop="description" content="{_escape(description)}" />
+    <meta itemprop="url" content="https://www.tensorflow.org/datasets/catalog/{builder.info.name}" />
+    <meta itemprop="sameAs" content="{_escape(builder.info.homepage)}" />
+    <meta itemprop="citation" content="{_escape(builder.info.citation)}" />
+  </div>
+  """
+  text = textwrap.dedent(text)
+  return text
 
 
 def get_markdown_string(
+    *,
     builder: tfds.core.DatasetBuilder,
     config_builders: List[tfds.core.DatasetBuilder],
-    visu_doc_util,
-    df_doc_util,
-    nightly_doc_util,
+    namespace: Optional[str],
+    visu_doc_util: Optional[doc_utils.VisualizationDocUtil],
+    df_doc_util: Optional[doc_utils.DataframeDocUtil],
+    nightly_doc_util: Optional[doc_utils.NightlyDocUtil],
 ) -> str:
   """Build the dataset markdown."""
 
   all_sections = [
+      KnowYourDataSection(),
       DatasetDescriptionSection(),
       ConfigDescriptionSection(),
       HomepageSection(),
@@ -531,18 +656,24 @@ def get_markdown_string(
       SplitInfoSection(),
       FeatureInfoSection(),
       SupervisedKeySection(),
-      DatasetCitationSection(),
-      DatasetVisualizationSection(visu_doc_util),
-      DatasetDataframeSection(df_doc_util),
   ]
+  if visu_doc_util:
+    all_sections.append(DatasetVisualizationSection(visu_doc_util))
+  if df_doc_util:
+    all_sections.append(DatasetDataframeSection(df_doc_util))
+  all_sections.append(DatasetCitationSection())
 
   doc_str = [
-      _display_dataset_heading(builder),
+      _display_schema_org(builder, visu_doc_util),
+      _display_dataset_heading(namespace, builder),
       _display_nightly_str(nightly_doc_util, builder),
       _display_manual_instructions(builder),
       _display_builder_configs(
-          builder, nightly_doc_util, config_builders, all_sections
+          builder=builder,
+          namespace=namespace,
+          nightly_doc_util=nightly_doc_util,
+          config_builders=config_builders,
+          all_sections=all_sections,
       ),
   ]
-
   return '\n\n'.join([tfds.core.utils.dedent(s) for s in doc_str if s])
