@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -34,11 +34,9 @@ FLAGS = flags.FLAGS
 flags.DEFINE_string(
     'datasets', None,
     'Comma separated list of datasets to generates. None for all datasets.')
-flags.DEFINE_string(
-    'dst_dir', tfds.core.gcs_path('visualization/fig'),
-    'Destination dir to save the images.')
-flags.DEFINE_boolean(
-    'overwrite', False, 'If True, overwrite the existing visualizations.')
+flags.DEFINE_string('dst_dir', None, 'Destination dir to save the images.')
+flags.DEFINE_boolean('overwrite', False,
+                     'If True, overwrite the existing visualizations.')
 
 
 def _save_fig(dst_path: str, figure: matplotlib.figure.Figure) -> None:
@@ -56,7 +54,7 @@ def main(_):
   datasets = FLAGS.datasets.split(',') if FLAGS.datasets else None
   generate_and_save_figure_fn = functools.partial(
       script_utils.generate_and_save_artifact,
-      dst_dir=FLAGS.dst_dir,
+      dst_dir=FLAGS.dst_dir or tfds.core.gcs_path('visualization/fig'),
       overwrite=FLAGS.overwrite,
       file_extension='.png',
       get_artifact_fn=tfds.show_examples,
@@ -69,5 +67,4 @@ def main(_):
 
 
 if __name__ == '__main__':
-  flags.mark_flags_as_required(['dst_dir'])
   script_utils.multi_process_run(main)
