@@ -24,12 +24,9 @@ from absl import logging
 
 from tensorflow_datasets.scripts.cli import main as main_cli
 
-module_import = flags.DEFINE_string(
-    'module_import', None, '`--imports` flag'
-)
-builder_config_id = flags.DEFINE_integer(
-    'builder_config_id', None, '`--config_idx` flag'
-)
+module_import = flags.DEFINE_string('module_import', None, '`--imports` flag')
+builder_config_id = flags.DEFINE_integer('builder_config_id', None,
+                                         '`--config_idx` flag')
 
 
 def _parse_flags(argv: List[str]) -> argparse.Namespace:
@@ -43,8 +40,7 @@ _display_warning = True
 def main(args: argparse.Namespace) -> None:
   if _display_warning:
     logging.warning(
-        '***`tfds build` should be used instead of `download_and_prepare`.***'
-    )
+        '***`tfds build` should be used instead of `download_and_prepare`.***')
   if module_import.value:
     args.imports = module_import.value
   if builder_config_id.value is not None:
