@@ -74,8 +74,7 @@ class Iris(tfds.core.GeneratorBasedBuilder):
     # Specify the splits
     return [
         tfds.core.SplitGenerator(
-            name=tfds.Split.TRAIN,
-            gen_kwargs={"records": records}),
+            name=tfds.Split.TRAIN, gen_kwargs={"records": records}),
     ]
 
   def _generate_examples(self, records):
