@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,12 +28,11 @@ class MovieLensUtilsTest(tfds.testing.TestCase):
     """Test for parse_current_movies_data."""
     latest_small_path = os.path.join(
         tfds.testing.fake_examples_dir(),
-        'movie_lens',
+        'movielens',
         'ml-latest-small',
     )
     movies_generator = movielens_parsing.parse_current_movies_data(
-        latest_small_path
-    )
+        latest_small_path)
     expected_result = [
         (0, {
             'movie_id': '1',
@@ -83,7 +82,7 @@ class MovieLensUtilsTest(tfds.testing.TestCase):
     """Test for parse_current_ratings_data."""
     fake_dir_path = os.path.join(
         tfds.testing.fake_examples_dir(),
-        'movie_lens',
+        'movielens',
         'ml-latest-small',
     )
     movies_generator = movielens_parsing.parse_current_ratings_data(
@@ -161,7 +160,7 @@ class MovieLensUtilsTest(tfds.testing.TestCase):
     """Test for parse_100k_movies_data."""
     fake_dir_path = os.path.join(
         tfds.testing.fake_examples_dir(),
-        'movie_lens',
+        'movielens',
         'ml-100k',
     )
     movies_generator = movielens_parsing.parse_100k_movies_data(fake_dir_path)
@@ -214,7 +213,7 @@ class MovieLensUtilsTest(tfds.testing.TestCase):
     """Test for parse_100k_ratings_data."""
     fake_dir_path = os.path.join(
         tfds.testing.fake_examples_dir(),
-        'movie_lens',
+        'movielens',
         'ml-100k',
     )
     movies_generator = movielens_parsing.parse_100k_ratings_data(fake_dir_path)
@@ -339,7 +338,7 @@ class MovieLensUtilsTest(tfds.testing.TestCase):
     """Test for parse_1m_movies_data."""
     fake_dir_path = os.path.join(
         tfds.testing.fake_examples_dir(),
-        'movie_lens',
+        'movielens',
         'ml-1m',
     )
     movies_generator = movielens_parsing.parse_1m_movies_data(fake_dir_path)
@@ -392,7 +391,7 @@ class MovieLensUtilsTest(tfds.testing.TestCase):
     """Test for parse_1m_ratings_data."""
     fake_dir_path = os.path.join(
         tfds.testing.fake_examples_dir(),
-        'movie_lens',
+        'movielens',
         'ml-1m',
     )
     movies_generator = movielens_parsing.parse_1m_ratings_data(fake_dir_path)
