@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,12 +15,18 @@
 
 """Base DatasetBuilderTestCase to test a DatasetBuilder base class."""
 
+import collections
+import contextlib
+import difflib
 import hashlib
 import itertools
 import numbers
 import os
+import textwrap
+from typing import Iterator, List, Optional, Union
+from unittest import mock
 
-from absl.testing import absltest
+from absl import logging
 from absl.testing import parameterized
 import numpy as np
 import tensorflow.compat.v2 as tf
@@ -31,6 +37,7 @@ from tensorflow_datasets.core import dataset_utils
 from tensorflow_datasets.core import download
 from tensorflow_datasets.core import load
 from tensorflow_datasets.core import utils
+from tensorflow_datasets.core import visibility
 from tensorflow_datasets.core.download import checksums
 from tensorflow_datasets.testing import feature_test_case
 from tensorflow_datasets.testing import test_utils
@@ -65,7 +72,6 @@ FORBIDDEN_OS_PATH_FUNCTIONS = (
     "isfile",
 )
 
-
 _ORGINAL_NP_LOAD = np.load
 
 
@@ -78,9 +84,8 @@ def _np_load(file_, mmap_mode=None, allow_pickle=False, **kwargs):
   return _ORGINAL_NP_LOAD(file_, mmap_mode, allow_pickle, **kwargs)
 
 
-class DatasetBuilderTestCase(
-    parameterized.TestCase, feature_test_case.SubTestCase
-):
+class DatasetBuilderTestCase(parameterized.TestCase,
+                             feature_test_case.SubTestCase):
   """Inherit this class to test your DatasetBuilder class.
 
   You must set the following class attributes:
@@ -91,9 +96,9 @@ class DatasetBuilderTestCase(
 
     * VERSION: `str`. The version used to run the test. eg: '1.2.*'.
       Defaults to None (canonical version).
-    * BUILDER_CONFIG_NAMES_TO_TEST: `list[str]`, the list of builder configs
-      that should be tested. If None, all the BUILDER_CONFIGS from the class
-      will be tested.
+    * BUILDER_CONFIG_NAMES_TO_TEST: `list[str | tfds.core.BuilderConfig]`,
+      the list of builder configs that should be tested. If None, all the
+      BUILDER_CONFIGS from the class will be tested.
     * DL_EXTRACT_RESULT: `dict[str]`, the returned result of mocked
       `download_and_extract` method. The values should be the path of files
       present in the `fake_examples` directory, relative to that directory.
@@ -104,8 +109,7 @@ class DatasetBuilderTestCase(
       If not specified: will use DL_EXTRACT_RESULT (this is due to backwards
       compatibility and will be removed in the future).
     * EXAMPLE_DIR: `str`, the base directory in in which fake examples are
-      contained. Optional; defaults to
-      tensorflow_datasets/testing/test_data/fake_examples/<dataset name>.
+      contained. Optional; defaults to `<dataset dir>/dummy_data/`.
     * OVERLAPPING_SPLITS: `list[str]`, splits containing examples from other
       splits (e.g. a "example" split containing pictures from other splits).
     * MOCK_OUT_FORBIDDEN_OS_FUNCTIONS: `bool`, defaults to True. Set to False to
@@ -113,6 +117,7 @@ class DatasetBuilderTestCase(
       recommended `tf.io.gfile` API.
     * SKIP_CHECKSUMS: Checks that the urls called by `dl_manager.download`
       are registered.
+    * SKIP_TF1_GRAPH_MODE: Runs in eager mode only.
 
   This test case will check for the following:
 
@@ -131,49 +136,41 @@ class DatasetBuilderTestCase(
 
   DATASET_CLASS = None
   VERSION = None
-  BUILDER_CONFIG_NAMES_TO_TEST = None
+  BUILDER_CONFIG_NAMES_TO_TEST: Optional[List[Union[
+      str, dataset_builder.BuilderConfig]]] = None
   DL_EXTRACT_RESULT = None
   DL_DOWNLOAD_RESULT = None
   EXAMPLE_DIR = None
   OVERLAPPING_SPLITS = []
   MOCK_OUT_FORBIDDEN_OS_FUNCTIONS = True
   SKIP_CHECKSUMS = False
+  SKIP_TF1_GRAPH_MODE = False
 
   @classmethod
   def setUpClass(cls):
     tf.enable_v2_behavior()
-    super(DatasetBuilderTestCase, cls).setUpClass()
+    super().setUpClass()
     name = cls.__name__
     # Check class has the right attributes
     if cls.DATASET_CLASS is None or not callable(cls.DATASET_CLASS):
       raise AssertionError(
           "Assign your DatasetBuilder class to %s.DATASET_CLASS." % name)
 
+    cls._available_cm = visibility.set_availables_tmp([
+        visibility.DatasetType.TFDS_PUBLIC,
+    ])
+    cls._available_cm.__enter__()
+
+  @classmethod
+  def tearDownClass(cls):
+    super().tearDownClass()
+    cls._available_cm.__exit__(None, None, None)
+
   def setUp(self):
     super(DatasetBuilderTestCase, self).setUp()
     self.patchers = []
     self.builder = self._make_builder()
 
-    example_dir = self.DATASET_CLASS.code_path.parent / "dummy_data"
-    if self.EXAMPLE_DIR is not None:
-      self.example_dir = self.EXAMPLE_DIR
-    elif example_dir.exists():
-      self.example_dir = str(example_dir)
-    else:
-      self.example_dir = os.path.join(
-          test_utils.fake_examples_dir(), self.builder.name)
-
-    if not tf.io.gfile.exists(self.example_dir):
-      err_msg = (
-          "Dummy data not found in {}."
-          ""
-      ).format(self.example_dir)
-
-    if not tf.io.gfile.exists(self.example_dir):
-      # TODO(epot): Better documentation once datasets are migrated to the
-      # folder model.
-      err_msg = "fake_examples dir %s not found." % self.example_dir
-      raise ValueError(err_msg)
     if self.MOCK_OUT_FORBIDDEN_OS_FUNCTIONS:
       self._mock_out_forbidden_os_functions()
 
@@ -191,34 +188,57 @@ class DatasetBuilderTestCase(
     for patcher in self.patchers:
       patcher.stop()
 
+  @utils.classproperty
+  @classmethod
+  @utils.memoize()
+  def dummy_data(cls) -> utils.ReadOnlyPath:  # pylint: disable=no-self-argument
+    """Path to the `dummy_data/` directory."""
+    if cls is DatasetBuilderTestCase:  # Required for build_api_docs
+      return None  # pytype: disable=bad-return-type
+
+    dummy_data_expected = cls.DATASET_CLASS.code_path.parent / "dummy_data"
+    fake_example_dir = utils.as_path(test_utils.fake_examples_dir())
+    if cls.EXAMPLE_DIR is not None:
+      dummy_data_found = utils.as_path(cls.EXAMPLE_DIR)
+      dummy_data_expected = dummy_data_found  # Dir to display in the error
+    elif dummy_data_expected.exists():
+      dummy_data_found = dummy_data_expected
+    else:
+      dummy_data_found = fake_example_dir / cls.DATASET_CLASS.name
+
+    if not dummy_data_found.exists():
+      err_msg = f"Dummy data not found in: {dummy_data_expected}"
+      raise ValueError(err_msg)
+    return dummy_data_found
+
   def _mock_out_forbidden_os_functions(self):
     """Raises error if forbidden os functions are called instead of gfile."""
     err = AssertionError("Do not use `os`, but `tf.io.gfile` module instead. "
                          "This makes code compatible with more filesystems.")
     sep = os.path.sep
-    mock_os_path = absltest.mock.Mock(os.path, wraps=os.path)
+    mock_os_path = mock.Mock(os.path, wraps=os.path)
     mock_os_path.sep = sep
     for fop in FORBIDDEN_OS_PATH_FUNCTIONS:
       getattr(mock_os_path, fop).side_effect = err
-    mock_os = absltest.mock.Mock(os, path=mock_os_path, fspath=os.fspath)
+    mock_os = mock.Mock(os, path=mock_os_path, fspath=os.fspath)
     for fop in FORBIDDEN_OS_FUNCTIONS:
       if os.name == "nt" and not hasattr(os, fop):
         continue  # Not all `os` functions are available on Windows (ex: chmod).
       getattr(mock_os, fop).side_effect = err
-    os_patcher = absltest.mock.patch(
+    os_patcher = mock.patch(
         self.DATASET_CLASS.__module__ + ".os", mock_os, create=True)
     os_patcher.start()
     self.patchers.append(os_patcher)
 
     mock_builtins = __builtins__.copy()  # pytype: disable=module-attr
-    mock_builtins["open"] = absltest.mock.Mock(side_effect=err)
-    open_patcher = absltest.mock.patch(
-        self.DATASET_CLASS.__module__ + ".__builtins__", mock_builtins)
+    mock_builtins["open"] = mock.Mock(side_effect=err)
+    open_patcher = mock.patch(self.DATASET_CLASS.__module__ + ".__builtins__",
+                              mock_builtins)
     open_patcher.start()
     self.patchers.append(open_patcher)
 
     # It's hard to mock open within numpy, so mock np.load.
-    np_load_patcher = absltest.mock.patch("numpy.load", _np_load)
+    np_load_patcher = mock.patch("numpy.load", _np_load)
     np_load_patcher.start()
     self.patchers.append(np_load_patcher)
 
@@ -230,11 +250,8 @@ class DatasetBuilderTestCase(
     # all needed methods were implemented.
 
   def test_registered(self):
-    is_registered = self.builder.name in load.list_builders()
-    self.assertTrue(
-        is_registered,
-        f"Dataset {self.builder.name} was not registered.",
-    )
+    self.assertIn(self.builder.name,
+                  load.list_builders(with_community_datasets=False,))
 
   def test_info(self):
     info = self.builder.info
@@ -255,9 +272,9 @@ class DatasetBuilderTestCase(
     tf.nest.map_structure(self._add_url, url)
     del url
     if self.DL_EXTRACT_RESULT is None:
-      return self.example_dir
+      return self.dummy_data
     return tf.nest.map_structure(
-        lambda fname: os.path.join(self.example_dir, fname),
+        lambda fname: self.dummy_data / fname,
         self.DL_EXTRACT_RESULT,
     )
 
@@ -265,10 +282,10 @@ class DatasetBuilderTestCase(
     tf.nest.map_structure(self._add_url, url)
     if self.DL_DOWNLOAD_RESULT is None:
       # This is only to be backwards compatible with old approach.
-      # In the future it will be replaced with using self.example_dir.
+      # In the future it will be replaced with using self.dummy_data.
       return self._get_dl_extract_result(url)
     return tf.nest.map_structure(
-        lambda fname: os.path.join(self.example_dir, fname),
+        lambda fname: self.dummy_data / fname,
         self.DL_DOWNLOAD_RESULT,
     )
 
@@ -283,24 +300,32 @@ class DatasetBuilderTestCase(
 
   @test_utils.run_in_graph_and_eager_modes()
   def test_download_and_prepare_as_dataset(self):
-    # If configs specified, ensure they are all valid
+    if not tf.executing_eagerly() and self.SKIP_TF1_GRAPH_MODE:
+      logging.warning("Skipping tests in non-eager mode")
+      return
+
+    # Extract configs to test
+    configs_to_test: List[Union[str, dataset_builder.BuilderConfig]] = []
     if self.BUILDER_CONFIG_NAMES_TO_TEST:
       for config in self.BUILDER_CONFIG_NAMES_TO_TEST:  # pylint: disable=not-an-iterable
-        assert config in self.builder.builder_configs, (
-            "Config %s specified in test does not exist. Available:\n%s" % (
-                config, list(self.builder.builder_configs)))
+        if isinstance(config, dataset_builder.BuilderConfig):
+          configs_to_test.append(config)
+        elif config in self.builder.builder_configs:
+          # Append the `name` rather than the config due to
+          # https://github.com/tensorflow/datasets/issues/2348
+          configs_to_test.append(config)
+        else:
+          raise ValueError(f"Invalid config {config} specified in test."
+                           f"Available: {list(self.builder.builder_configs)}")
+    else:
+      configs_to_test.extend(cfg.name for cfg in self.builder.BUILDER_CONFIGS)
 
-    configs = self.builder.BUILDER_CONFIGS
-    print("Total configs: %d" % len(configs))
-    if configs:
-      for config in configs:
-        # Skip the configs that are not in the list.
-        if (self.BUILDER_CONFIG_NAMES_TO_TEST is not None and
-            (config.name not in self.BUILDER_CONFIG_NAMES_TO_TEST)):  # pylint: disable=unsupported-membership-test
-          print("Skipping config %s" % config.name)
-          continue
-        with self._subTest(config.name):
-          print("Testing config %s" % config.name)
+    print(f"Total configs: {len(configs_to_test)}")
+    if configs_to_test:
+      for config in configs_to_test:
+        config_name = config if isinstance(config, str) else config.name
+        with self._subTest(config_name):
+          print(f"Testing config {config_name}")
           builder = self._make_builder(config=config)
           self._download_and_prepare_as_dataset(builder)
     else:
@@ -316,12 +341,11 @@ class DatasetBuilderTestCase(
       return
 
     err_msg = (
-        "Did you forget to record checksums with `--register_checksums` ? "
-        "See instructions at: "
-        "hhttps://www.tensorflow.org/datasets/add_dataset#run_the_generation_code"
-        "If want to opt-out of checksums validation, please add "
-        "`SKIP_CHECKSUMS = True` to the `DatasetBuilderTestCase`.\n"
-    )
+        "Did you forget to record checksums with `--register_checksums` ? See "
+        "instructions at: "
+        "hhttps://www.tensorflow.org/datasets/add_dataset#run_the_generation_codeIf"
+        " want to opt-out of checksums validation, please add `SKIP_CHECKSUMS "
+        "= True` to the `DatasetBuilderTestCase`.\n")
     url_infos = self.DATASET_CLASS.url_infos
     filepath = self.DATASET_CLASS._checksums_path  # pylint: disable=protected-access
     # Legacy checksums: Search in `checksums/` dir
@@ -340,41 +364,35 @@ class DatasetBuilderTestCase(
     missing_urls = self._download_urls - set(url_infos.keys())
     self.assertEmpty(
         missing_urls,
-        f"Some urls checksums are missing at: {filepath}\n{err_msg}"
-    )
+        f"Some urls checksums are missing at: {filepath}\n{err_msg}")
 
   def _download_and_prepare_as_dataset(self, builder):
     # Provide the manual dir only if builder has MANUAL_DOWNLOAD_INSTRUCTIONS
     # set.
 
-    missing_dir_mock = absltest.mock.PropertyMock(
+    missing_dir_mock = mock.PropertyMock(
         side_effect=Exception("Missing MANUAL_DOWNLOAD_INSTRUCTIONS"))
 
     manual_dir = (
-        self.example_dir
+        self.dummy_data
         if builder.MANUAL_DOWNLOAD_INSTRUCTIONS else missing_dir_mock)
-    with absltest.mock.patch.multiple(
+    with mock.patch.multiple(
         "tensorflow_datasets.core.download.DownloadManager",
         download_and_extract=self._get_dl_extract_result,
         download=self._get_dl_download_result,
         download_checksums=self._download_checksums,
         manual_dir=manual_dir,
+        download_dir=self.dummy_data,
     ):
-      if isinstance(builder, dataset_builder.BeamBasedBuilder):
-        # For Beam datasets, set-up the runner config
-        import apache_beam as beam   # pylint: disable=import-outside-toplevel,g-import-not-at-top
-        beam_runner = None
-        beam_options = beam.options.pipeline_options.PipelineOptions()
-      else:
-        beam_runner = None
-        beam_options = None
+      # For Beam datasets, set-up the runner config
+      beam_runner = None
 
       download_config = download.DownloadConfig(
           compute_stats=download.ComputeStatsMode.SKIP,
           beam_runner=beam_runner,
-          beam_options=beam_options,
       )
-      builder.download_and_prepare(download_config=download_config)
+      with self._test_key_not_local_path(builder):
+        builder.download_and_prepare(download_config=download_config)
 
     with self._subTest("as_dataset"):
       self._assertAsDataset(builder)
@@ -392,17 +410,59 @@ class DatasetBuilderTestCase(
       with self._subTest("as_dataset"):
         self._assertAsDataset(builder_reloaded)
 
+    with self._subTest("config_description"):
+      self._test_description_builder_config(builder)
+
+  @contextlib.contextmanager
+  def _test_key_not_local_path(self, builder) -> Iterator[None]:
+    if not isinstance(builder, dataset_builder.GeneratorBasedBuilder):
+      yield  # Do not test non-generator builder
+      return
+
+    original_generate_examples = builder._generate_examples  # pylint: disable=protected-access
+
+    def _iter_examples(generator):
+      for key, ex in generator:
+        self._assert_key_valid(key)
+        yield key, ex
+
+    def new_generate_examples(*args, **kwargs):
+      examples = original_generate_examples(*args, **kwargs)
+      try:
+        import apache_beam as beam  # pylint: disable=g-import-not-at-top
+      except ImportError:
+        beam = None
+      if beam and isinstance(examples, (beam.PCollection, beam.PTransform)):
+        return examples  # Beam keys not supported for now
+      elif isinstance(examples, collections.abc.Iterable):
+        return _iter_examples(examples)
+      else:  # Unexpected
+        return examples
+
+    with mock.patch.object(builder, "_generate_examples",
+                           new_generate_examples):
+      yield
+
+  def _assert_key_valid(self, key):
+    if isinstance(key, str) and os.fspath(self.dummy_data) in key:
+      err_msg = ("Key yield in '_generate_examples' method "
+                 f"contain user directory path: {key}.\n"
+                 "This makes the dataset example order non-deterministic. "
+                 "Please use `filepath.name`, or `os.path.basename` instead.")
+      raise ValueError(err_msg)
+
   def _assertAsDataset(self, builder):
     split_to_checksums = {}  # {"split": set(examples_checksums)}
     for split_name, expected_examples_number in self.SPLITS.items():
       ds = builder.as_dataset(split=split_name)
+      spec = tf.data.DatasetSpec.from_value(ds)
       compare_shapes_and_types(
           builder.info.features.get_tensor_info(),
-          tf.compat.v1.data.get_output_types(ds),
-          tf.compat.v1.data.get_output_shapes(ds),
+          # We use _element_spec because element_spec was added in TF2.5+.
+          element_spec=spec._element_spec,  # pylint: disable=protected-access
       )
-      examples = list(dataset_utils.as_numpy(
-          builder.as_dataset(split=split_name)))
+      examples = list(
+          dataset_utils.as_numpy(builder.as_dataset(split=split_name)))
       split_to_checksums[split_name] = set(checksum(rec) for rec in examples)
       self.assertLen(examples, expected_examples_number)
     for (split1, hashes1), (split2, hashes2) in itertools.combinations(
@@ -427,6 +487,29 @@ class DatasetBuilderTestCase(
         sum(self.SPLITS.values()),
     )
 
+  def _test_description_builder_config(self, builder):
+    # Do not test on external datasets for backward compatibility
+    # TODO(tfds): Update once datasets are migrated
+    if "tensorflow_datasets" not in self.DATASET_CLASS.__module__:
+      return
+
+    # If configs specified, ensure they are all valid
+    if builder.builder_config and builder.builder_config.description:
+      err_msg = textwrap.dedent("""\
+          The BuilderConfig description should be a one-line description of
+          the config.
+          It shouldn't be the same as `builder.info.description` to avoid
+          redundancy. Both `config.description` and `builder.info.description`
+          will be displayed in the catalog.
+          """)
+      ratio = difflib.SequenceMatcher(
+          None,
+          builder.builder_config.description,
+          builder.info.description,
+      ).ratio()
+      if ratio > 0.9:
+        raise AssertionError(err_msg)
+
 
 def checksum(example):
   """Computes the md5 for a given example."""
@@ -450,7 +533,7 @@ def checksum(example):
     elif isinstance(element,
                     (tf.RaggedTensor, tf.compat.v1.ragged.RaggedTensorValue)):
       flat_str.append(str(element.to_list()))
-    elif isinstance(element, np.ndarray):
+    elif isinstance(element, (np.ndarray, np.generic)):
       # tf.Tensor() returns np.array of dtype object, which don't work
       # with x.to_bytes(). So instead convert numpy into list.
       if element.dtype.type is np.object_:
@@ -458,14 +541,16 @@ def checksum(example):
         flat_str.append(str(list(element.ravel())))
       else:
         flat_str.append(element.tobytes())
+    elif isinstance(element, dataset_utils._IterableDataset):  # pylint: disable=protected-access
+      for nested_e in element:
+        _bytes_flatten(flat_str, nested_e)
     else:
       flat_str.append(bytes(element))
     return flat_str
 
   flat_str = _bytes_flatten([], example)
   flat_bytes = [
-      s.encode("utf-8") if not isinstance(s, bytes) else s
-      for s in flat_str
+      s.encode("utf-8") if not isinstance(s, bytes) else s for s in flat_str
   ]
   flat_bytes = b"".join(flat_bytes)
 
@@ -474,19 +559,20 @@ def checksum(example):
   return hash_.hexdigest()
 
 
-def compare_shapes_and_types(tensor_info, output_types, output_shapes):
+def compare_shapes_and_types(tensor_info, element_spec):
   """Compare shapes and types between TensorInfo and Dataset types/shapes."""
-  for feature_name, feature_info in tensor_info.items():
-    if isinstance(feature_info, dict):
-      compare_shapes_and_types(feature_info, output_types[feature_name],
-                               output_shapes[feature_name])
+  for feature_name, (feature_info,
+                     spec) in utils.zip_dict(tensor_info, element_spec):
+    if isinstance(spec, tf.data.DatasetSpec):
+      # We use _element_spec because element_spec was added in TF2.5+.
+      compare_shapes_and_types(feature_info, spec._element_spec)  # pylint: disable=protected-access
+    elif isinstance(feature_info, dict):
+      compare_shapes_and_types(feature_info, spec)
     else:
-      expected_type = feature_info.dtype
-      output_type = output_types[feature_name]
-      if expected_type != output_type:
-        raise TypeError("Feature %s has type %s but expected %s" %
-                        (feature_name, output_type, expected_type))
-
-      expected_shape = feature_info.shape
-      output_shape = output_shapes[feature_name]
-      utils.assert_shape_match(expected_shape, output_shape)
+      # Some earlier versions of TF don't expose dtype and shape for the
+      # RaggedTensorSpec, so we use the protected versions.
+      if feature_info.dtype != spec._dtype:  # pylint: disable=protected-access
+        raise TypeError(
+            f"Feature {feature_name} has type {feature_info} but expected {spec}"
+        )
+      utils.assert_shape_match(feature_info.shape, spec._shape)  # pylint: disable=protected-access
