@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,7 +29,7 @@ import tensorflow.compat.v2 as tf
 from tensorflow_datasets.core import dataset_builder
 from tensorflow_datasets.core import dataset_info
 from tensorflow_datasets.core import features
-from tensorflow_datasets.core import splits
+from tensorflow_datasets.core import lazy_imports_lib
 from tensorflow_datasets.core import utils
 
 
@@ -108,24 +108,30 @@ class MockFs(object):
       yield self
 
   def add_file(self, path, content=None) -> None:
+    path = os.fspath(path)
     content = 'Content of {}'.format(path) if content is None else content
     self.files[path] = content
 
   def _list_directory(self, path):
+    path = os.fspath(path)
     path = path.rstrip(os.path.sep) + os.path.sep  # Make sure path is a `dir/`
     return list({
         # Extract `path/<dirname>/...` -> `<dirname>`
         os.path.relpath(p, path).split(os.path.sep)[0]
-        for p in self.files if p.startswith(path)
+        for p in self.files
+        if p.startswith(path)
     })
 
   @contextlib.contextmanager
   def _open(self, path, mode='r'):
     """Patch `tf.io.gfile.GFile`."""
+    path = os.fspath(path)
     if mode.startswith('w'):
       self.add_file(path, '')
     is_binary = 'b' in mode
 
+    if path not in self.files:
+      raise FileNotFoundError(f'File {path} does not exists.')
     content = self.files[path]
     if is_binary:
       fobj = io.BytesIO(content.encode('utf-8'))
@@ -139,6 +145,8 @@ class MockFs(object):
     self.files[path] = new_content.decode('utf-8') if is_binary else new_content  # pytype: disable=attribute-error
 
   def _rename(self, from_, to, overwrite=False):
+    from_ = os.fspath(from_)
+    to = os.fspath(to)
     if not overwrite and to in self.files:
       raise FileExistsError('Cannot overwrite: {} -> {}'.format(from_, to))  # pytype: disable=name-error
     if from_ not in self.files:
@@ -147,6 +155,7 @@ class MockFs(object):
 
   def _exists(self, path: str) -> bool:
     """Returns True, if any file/directory exists."""
+    path = os.fspath(path)
     path = path.rstrip(os.path.sep)  # Normalize path
     # Check full path existence
     if path in self.files:
@@ -203,14 +212,11 @@ def mock_tf(symbol_name: str, *args: Any, **kwargs: Any) -> Iterator[None]:
       getattr(module, symbol_name)  # Trigger the lazy-loading of the TF API.
       # Patch the module/object
       stack.enter_context(
-          mock.patch.object(module, symbol_name, *args, **kwargs)
-      )
+          mock.patch.object(module, symbol_name, *args, **kwargs))
     yield
 
 
-def run_in_graph_and_eager_modes(func=None,
-                                 config=None,
-                                 use_gpu=True):
+def run_in_graph_and_eager_modes(func=None, config=None, use_gpu=True):
   """Execute the decorated test in both graph mode and eager mode.
 
   This function returns a decorator intended to be applied to test methods in
@@ -305,14 +311,10 @@ class DummyDatasetSharedGenerator(dataset_builder.GeneratorBasedBuilder):
     # Split the 30 examples from the generator into 2 train shards and 1 test
     # shard.
     del dl_manager
-    return [
-        splits.SplitGenerator(
-            name=splits.Split.TRAIN,
-            gen_kwargs={'range_': range(20)}),
-        splits.SplitGenerator(
-            name=splits.Split.TEST,
-            gen_kwargs={'range_': range(20, 30)}),
-    ]
+    return {
+        'train': self._generate_examples(range_=range(20)),
+        'test': self._generate_examples(range_=range(20, 30)),
+    }
 
   def _generate_examples(self, range_):
     for i in range_:
@@ -335,14 +337,10 @@ class DummyMnist(dataset_builder.GeneratorBasedBuilder):
     )
 
   def _split_generators(self, dl_manager):
-    return [
-        splits.SplitGenerator(
-            name=splits.Split.TRAIN,
-            gen_kwargs=dict()),
-        splits.SplitGenerator(
-            name=splits.Split.TEST,
-            gen_kwargs=dict()),
-    ]
+    return {
+        'train': self._generate_examples(),
+        'test': self._generate_examples(),
+    }
 
   def _generate_examples(self):
     for i in range(20):
@@ -352,6 +350,43 @@ class DummyMnist(dataset_builder.GeneratorBasedBuilder):
       }
 
 
+class DummyDataset(
+    dataset_builder.GeneratorBasedBuilder,
+    skip_registration=True,
+):
+  """Minimal DatasetBuilder."""
+
+  VERSION = utils.Version('1.0.0')
+
+  def _info(self):
+    return dataset_info.DatasetInfo(
+        builder=self,
+        features=features.FeaturesDict({
+            'id': tf.int64,
+        }),
+        supervised_keys=('id', 'id'),
+        description='Minimal DatasetBuilder.',
+    )
+
+  def _split_generators(self, dl_manager):
+    del dl_manager
+    return {
+        'train': self._generate_examples(),
+    }
+
+  def _generate_examples(self):
+    for i in range(3):
+      yield i, {'id': i}
+
+
+class DummyBeamDataset(DummyDataset, skip_registration=True):
+  """Minimal beam DatasetBuilder."""
+
+  def _generate_examples(self):
+    beam = lazy_imports_lib.lazy_imports.apache_beam
+    return beam.Create(list(range(3))) | beam.Map(lambda i: (i, {'id': i}))
+
+
 def test_main():
   """Entrypoint for tests."""
   tf.enable_v2_behavior()
@@ -405,3 +440,30 @@ class DummyParser(object):
 
   def parse_example(self, ex):
     return ex
+
+
+def assert_features_equal(features0, features1) -> None:
+  """Asserts that the 2 nested FeatureConnector structure match."""
+  _assert_features_equal(
+      features.features_dict.to_feature(features0),
+      features.features_dict.to_feature(features1),
+  )
+
+
+def _assert_features_equal(features0, features1) -> None:
+  tf.nest.map_structure(_assert_feature_equal, features0, features1)
+
+
+def _assert_feature_equal(feature0, feature1):
+  """Assert that 2 features are equals."""
+  assert type(feature0) == type(feature1)  # pylint: disable=unidiomatic-typecheck
+  assert repr(feature0) == repr(feature1)
+  assert feature0.shape == feature1.shape
+  assert feature0.dtype == feature1.dtype
+  if isinstance(feature0, features.FeaturesDict):
+    _assert_features_equal(dict(feature0), dict(feature1))
+  if isinstance(feature0, features.Sequence):
+    assert feature0._length == feature1._length  # pylint: disable=protected-access
+    _assert_features_equal(feature0.feature, feature1.feature)
+  if isinstance(feature0, features.ClassLabel):
+    assert feature0.names == feature1.names
