@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ import collections
 import functools
 import json
 import os
+import uuid
 
 from absl import logging
 import tensorflow.compat.v2 as tf
@@ -81,13 +82,21 @@ _BADWORDS_LANGS = [
     "pt", "ru", "sv", "th", "tlh", "tr", "zh"
 ]
 
-
 DEFAULT_CC_VERSION = "2019-18"
 
 OPENWEBTEXT_CC_VERSIONS = (  # August 2018 - July 2019
     "2019-18",  # Original default for single-crawl dataset (April 2019).
-    "2019-30", "2019-26", "2019-22", "2019-13", "2019-09", "2019-04", "2018-51",
-    "2018-47", "2018-43", "2018-39", "2018-34")
+    "2019-30",
+    "2019-26",
+    "2019-22",
+    "2019-13",
+    "2019-09",
+    "2019-04",
+    "2018-51",
+    "2018-47",
+    "2018-43",
+    "2018-39",
+    "2018-34")
 
 ALL_CC_VERSIONS = (  # as of September 23, 2020
     "2013-20", "2013-48", "2014-10", "2014-15", "2014-23", "2014-35", "2014-41",
@@ -100,9 +109,7 @@ ALL_CC_VERSIONS = (  # as of September 23, 2020
     "2018-39", "2018-43", "2018-47", "2018-51", "2019-04", "2019-09", "2019-13",
     "2019-18", "2019-22", "2019-26", "2019-30", "2019-35", "2019-39", "2019-43",
     "2019-47", "2019-51", "2020-05", "2020-10", "2020-16", "2020-24", "2020-29",
-    "2020-34"
-)
-
+    "2020-34")
 
 _KNOWN_CORRUPT_WET_FILES = (  # as of September 23, 2020
     # files that raise EOFError
@@ -134,15 +141,15 @@ _KNOWN_CORRUPT_WET_FILES = (  # as of September 23, 2020
 # "multilingual" config below.
 MC4_LANGUAGES = [
     "af", "am", "ar", "az", "be", "bg", "bg-Latn", "bn", "ca", "ceb", "co",
-    "cs", "cy", "da", "de", "el", "el-Latn", "en", "eo", "es", "et", "eu",
-    "fa", "fi", "fil", "fr", "fy", "ga", "gd", "gl", "gu", "ha", "haw", "hi",
+    "cs", "cy", "da", "de", "el", "el-Latn", "en", "eo", "es", "et", "eu", "fa",
+    "fi", "fil", "fr", "fy", "ga", "gd", "gl", "gu", "ha", "haw", "hi",
     "hi-Latn", "hmn", "ht", "hu", "hy", "id", "ig", "is", "it", "iw", "ja",
-    "ja-Latn", "jv", "ka", "kk", "km", "kn", "ko", "ku", "ky", "la", "lb",
-    "lo", "lt", "lv", "mg", "mi", "mk", "ml", "mn", "mr", "ms", "mt", "my",
-    "ne", "nl", "no", "ny", "pa", "pl", "ps", "pt", "ro", "ru", "ru-Latn",
-    "sd", "si", "sk", "sl", "sm", "sn", "so", "sq", "sr", "st", "su", "sv",
-    "sw", "ta", "te", "tg", "th", "tr", "uk", "ur", "uz", "vi", "xh", "yi",
-    "yo", "zh", "zh-Latn", "zu"
+    "ja-Latn", "jv", "ka", "kk", "km", "kn", "ko", "ku", "ky", "la", "lb", "lo",
+    "lt", "lv", "mg", "mi", "mk", "ml", "mn", "mr", "ms", "mt", "my", "ne",
+    "nl", "no", "ny", "pa", "pl", "ps", "pt", "ro", "ru", "ru-Latn", "sd", "si",
+    "sk", "sl", "sm", "sn", "so", "sq", "sr", "st", "su", "sv", "sw", "ta",
+    "te", "tg", "th", "tr", "uk", "ur", "uz", "vi", "xh", "yi", "yo", "zh",
+    "zh-Latn", "zu"
 ]
 
 
@@ -169,7 +176,7 @@ class C4Config(tfds.core.BuilderConfig):
         use as the raw source text. Set to None to use default.
       clean: bool, whether to heuristically filter out lines and pages
         considered low quality. Note: only expected to work reliably for English
-        pages.
+          pages.
       badwords_filter: bool, whether to filter out pages with badwords.
       paragraph_filter: bool, whether to filter out pages with too few or too
         short paragraphs.
@@ -206,7 +213,6 @@ class C4(tfds.core.BeamBasedBuilder):
   You are using a C4 config that requires some files to be manually downloaded.
   For `c4/webtextlike`, download {_OPENWEBTEXT_URLS_ZIP} from
   {_OPENWEBTEXT_URLS_URL}.
-  For `c4/multilingual` and `en/noclean` download the Common Crawl WET files.
   """
 
   BUILDER_CONFIGS = [
@@ -223,8 +229,7 @@ class C4(tfds.core.BeamBasedBuilder):
           clean=False,
           dedupe=False,
           badwords_filter=False,
-          description=
-          "Disables all cleaning (deduplication, removal based on bad words, "
+          description="Disables all cleaning (deduplication, removal based on bad words, "
           "etc.)"),
       C4Config(
           "realnewslike",
@@ -233,8 +238,7 @@ class C4(tfds.core.BeamBasedBuilder):
           clean=True,
           dedupe=True,
           badwords_filter=True,
-          description=
-          "Filters from the default config to only include content from the "
+          description="Filters from the default config to only include content from the "
           "domains used in the 'RealNews' dataset (Zellers et al., 2019)."),
       C4Config(
           "webtextlike",
@@ -244,8 +248,7 @@ class C4(tfds.core.BeamBasedBuilder):
           clean=True,
           dedupe=True,
           badwords_filter=True,
-          description=
-          "Filters from the default config to only include content from the "
+          description="Filters from the default config to only include content from the "
           "URLs in OpenWebText (https://github.com/jcpeterson/openwebtext)."),
       C4Config(
           "multilingual",
@@ -255,8 +258,7 @@ class C4(tfds.core.BeamBasedBuilder):
           paragraph_filter=True,
           dedupe=True,
           badwords_filter=True,
-          description=
-          "Multilingual C4 (mC4) has 101 languages and is generated from 71 "
+          description="Multilingual C4 (mC4) has 101 languages and is generated from 71 "
           "Common Crawl dumps."),
   ]
 
@@ -273,8 +275,7 @@ class C4(tfds.core.BeamBasedBuilder):
         description=_DESCRIPTION,
         features=tfds.features.FeaturesDict(features),
         citation=_CITATION,
-        homepage=
-        "https://github.com/google-research/text-to-text-transfer-transformer#datasets",
+        homepage="https://github.com/google-research/text-to-text-transfer-transformer#datasets",
     )
 
   def _split_generators(self, dl_manager, pipeline):
@@ -283,22 +284,16 @@ class C4(tfds.core.BeamBasedBuilder):
     # We will automatically download the first default CC version, but others
     # need to be manually downloaded.
     cc_versions = set(self.builder_config.cc_versions)
-    default_version = set([DEFAULT_CC_VERSION])
-    auto_cc_versions = cc_versions & default_version
-    manual_cc_versions = cc_versions - default_version
-
     files_to_download = {}
     files_to_download["wet_path_urls"] = [
         _WET_PATH_URL.format(cc_version=cc_version)
-        for cc_version in auto_cc_versions]
-    files_to_download["manual_wet_paths"] = {
-        cc_version: _WET_PATH_URL.format(cc_version=cc_version)
-        for cc_version in manual_cc_versions
-    }
+        for cc_version in cc_versions
+    ]
     if self.builder_config.badwords_filter:
       files_to_download["badwords"] = {
           lang: _BADWORDS_URL.format(lang=lang)
-          for lang in _BADWORDS_LANGS if lang != "en"
+          for lang in _BADWORDS_LANGS
+          if lang != "en"
       }
       # Use older "en" file for reproducibility of the original C4.
       files_to_download["badwords"]["en"] = _EN_BADWORDS_URL
@@ -316,38 +311,10 @@ class C4(tfds.core.BeamBasedBuilder):
                 _OPENWEBTEXT_URLS_ZIP))
       file_paths["openwebtext_urls_zip"] = dl_manager.extract(owt_path)
 
-    wet_urls = []
-    for wet_path_url in file_paths["wet_path_urls"]:
-      with tf.io.gfile.GFile(wet_path_url) as f:
-        wet_urls.extend(["%s/%s" % (_DOWNLOAD_HOST, l.strip()) for l in f])
-    if dl_manager.register_checksums:
-      # Download locally to register checksums.
-      file_paths.update(dl_manager.download({"wet_files": wet_urls}))
-    else:
-      # Download on the beam workers.
-      file_paths["wet_urls"] = wet_urls
-      file_paths["wet_files"] = []
+    file_paths = tf.nest.map_structure(os.fspath, file_paths)
 
-    for cc_version, wet_path_url in file_paths["manual_wet_paths"].items():
-      crawl_dir = os.path.join(
-          dl_manager.manual_dir, "crawl-data", f"CC-MAIN-{cc_version}")
-      if not tf.io.gfile.exists(crawl_dir):
-        raise AssertionError(
-            "For the non-default Common Crawl version {0}, you must manually "
-            "download the WET files to the directory {1}.".format(
-                cc_version, crawl_dir))
-      with tf.io.gfile.GFile(wet_path_url) as f:
-        wet_files = [
-            os.path.join(dl_manager.manual_dir, line.strip())
-            for line in f if line.strip() not in _KNOWN_CORRUPT_WET_FILES
-        ]
-      logging.info(
-          "Adding %d WET files for manually downloaded version %s.",
-          len(wet_files), cc_version)
-      file_paths["wet_files"].extend(wet_files)
-
-    page_content_pcollection = self._get_page_content(
-        pipeline, file_paths, dl_manager, self.builder_config.languages)
+    page_content_pcollection = self._get_page_content(pipeline, file_paths,
+                                                      dl_manager)
 
     def _lang_filter(url_and_page, lang):
       _, page = url_and_page
@@ -369,9 +336,7 @@ class C4(tfds.core.BeamBasedBuilder):
                   split="train",
                   page_content=page_content_pcollection,
                   split_filter_fn=c4_utils.get_hashed_url_filter_fn(
-                      predicate_fn=train_predicate_fn
-                  )
-              ),
+                      predicate_fn=train_predicate_fn)),
           ),
           tfds.core.SplitGenerator(
               name=tfds.Split.VALIDATION,
@@ -379,9 +344,7 @@ class C4(tfds.core.BeamBasedBuilder):
                   split="validation",
                   page_content=page_content_pcollection,
                   split_filter_fn=c4_utils.get_hashed_url_filter_fn(
-                      predicate_fn=validation_predicate_fn
-                  )
-              ),
+                      predicate_fn=validation_predicate_fn)),
           ),
       ]
 
@@ -394,40 +357,57 @@ class C4(tfds.core.BeamBasedBuilder):
                   split=lang,
                   page_content=page_content_pcollection,
                   split_filter_fn=functools.partial(
-                      _filter, lang=lang,
-                      predicate_fn=train_predicate_fn
-                  ),
-              )
-          ),
+                      _filter, lang=lang, predicate_fn=train_predicate_fn),
+              )),
           tfds.core.SplitGenerator(
               name=f"{lang}-validation",
               gen_kwargs=dict(
                   split=f"{lang}-validation",
                   page_content=page_content_pcollection,
                   split_filter_fn=functools.partial(
-                      _filter, lang=lang,
-                      predicate_fn=validation_predicate_fn
-                  ),
-              )
-          )
+                      _filter, lang=lang, predicate_fn=validation_predicate_fn),
+              ))
       ])
     return splits
 
-  def _get_page_content(self, pipeline, file_paths, dl_manager, language):
+  def _get_page_content(self, pipeline, file_paths, dl_manager):
     """Build PCollection of un-split page content."""
     beam = tfds.core.lazy_imports.apache_beam
 
+    def download_wet_file(path, dl_dir):
+      url = f"{_DOWNLOAD_HOST}/{path}"
+      out_path = f"{dl_dir}/{path}"
+
+      if tf.io.gfile.exists(out_path):
+        c4_utils.get_counter_inc_fn("download_wet_url")("exists")
+        return out_path
+
+      tmp_dir = f"{out_path}.incomplete{uuid.uuid4().hex}"
+      try:
+        tf.io.gfile.makedirs(tmp_dir)
+        downloader = tfds.download.downloader.get_downloader()
+        with downloader.tqdm():
+          dl_path = downloader.download(url, tmp_dir).get().path
+        tf.io.gfile.rename(os.fspath(dl_path), out_path, overwrite=True)
+      finally:
+        if tf.io.gfile.exists(tmp_dir):
+          tf.io.gfile.rmtree(tmp_dir)
+
+        c4_utils.get_counter_inc_fn("download_wet_url")("downloaded")
+      return out_path
+
     wet_file_paths = (
-        pipeline |
-        "create_wet_files" >> beam.Create(file_paths["wet_files"]))
-    if "wet_urls" in file_paths:
-      def download_url(url, downloader):
-        return downloader.download({url: url})[url]
-      dl_wet_file_paths = (
-          pipeline
-          | "create_wet_urls" >> beam.Create(file_paths["wet_urls"])
-          | beam.Map(download_url, downloader=dl_manager))
-      wet_file_paths = (wet_file_paths, dl_wet_file_paths) | beam.Flatten()
+        pipeline
+        | "create_wet_path_urls" >> beam.Create(file_paths["wet_path_urls"])
+        | beam.io.ReadAllFromText(
+            compression_type=beam.io.filesystem.CompressionTypes.UNCOMPRESSED)
+        # Increase parallelism.
+        | beam.Reshuffle()
+        | "filter_corrupt_wet_files" >>
+        beam.Filter(lambda p: p not in _KNOWN_CORRUPT_WET_FILES)
+        | beam.Map(
+            download_wet_file,
+            dl_dir=os.path.join(dl_manager.download_dir, "c4_wet_files")))
 
     # Parse WET files and filter by length.
     # Output: url, text
@@ -458,19 +438,17 @@ class C4(tfds.core.BeamBasedBuilder):
     if self.builder_config.webtextlike:
       webtextlike_urls = (
           pipeline
-          | "read_webtextlike_urls" >>
-          beam.io.ReadFromText(
+          | "read_webtextlike_urls" >> beam.io.ReadFromText(
               os.path.join(file_paths["openwebtext_urls_zip"],
                            _OPENWEBTEXT_URLS_FILE_PATTERN))
           | "add_dummy_page" >> beam.Map(lambda x: (x, ""))
           | "normal_webtext_url" >> beam.Map(c4_utils.normalize_url))
-      page_content = (
-          {
-              "text": page_content,
-              "webtextlike_urls": webtextlike_urls
-          }
-          | "group_webtextlike_urls" >> beam.CoGroupByKey()
-          | beam.FlatMap(c4_utils.filter_by_webtextlike))
+      page_content = ({
+          "text": page_content,
+          "webtextlike_urls": webtextlike_urls
+      }
+                      | "group_webtextlike_urls" >> beam.CoGroupByKey()
+                      | beam.FlatMap(c4_utils.filter_by_webtextlike))
 
     if self.builder_config.paragraph_filter:
       page_content |= beam.Filter(c4_utils.paragraph_filter)
@@ -522,6 +500,7 @@ class C4(tfds.core.BeamBasedBuilder):
           "content-length": features["content-length"],
           "timestamp": features["timestamp"]
       }
+
     return (page_content
             | beam.Filter(split_filter_fn)
             | beam.Map(_emit_examples))
