@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -105,10 +105,7 @@ class CFQConfig(tfds.core.BuilderConfig):
       directory = 'splits'
       split_name = name
     super(CFQConfig, self).__init__(
-        name=name,
-        version=tfds.core.Version('1.2.0'),
-        description=_DESCRIPTION,
-        **kwargs)
+        name=name, version=tfds.core.Version('1.2.0'), **kwargs)
     self.split_file = os.path.join(directory, split_name + '.json')
 
 
