@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Test for PG-19 dataset module."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 
 import tensorflow_datasets.public_api as tfds
@@ -41,10 +36,11 @@ class Pg19Test(tfds.testing.DatasetBuilderTestCase):
 
   DATASET_CLASS = pg19.Pg19
   SPLITS = {
-      "train": 3,   # Number of fake train example
-      "test": 1,      # Number of fake test example
+      "train": 3,  # Number of fake train example
+      "test": 1,  # Number of fake test example
       "validation": 1  # Number of fake validation example
   }
 
+
 if __name__ == "__main__":
   tfds.testing.test_main()
