@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,6 +22,10 @@ from tensorflow_datasets.text.quac import quac
 class QuacTest(tfds.testing.DatasetBuilderTestCase):
   """Tests for quac dataset."""
   DATASET_CLASS = quac.Quac
+  DL_EXTRACT_RESULT = {
+      "train": "train_v0.2.json",
+      "val": "val_v0.2.json",
+  }
   SPLITS = {
       "train": 8,  # Number of fake train example
       "validation": 8,  # Number of fake validation example
