@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,10 +15,6 @@
 
 """reddit_disentanglement dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import tensorflow_datasets.public_api as tfds
 from tensorflow_datasets.text import reddit_disentanglement
 
@@ -34,4 +30,3 @@ class RedditDisentanglementTest(tfds.testing.DatasetBuilderTestCase):
 
 if __name__ == "__main__":
   tfds.testing.test_main()
-
