@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,18 +27,13 @@ class SalientSpanWikipediaSentencesTest(testing.DatasetBuilderTestCase):
       'test_examples.tfrecord.gz')
 
   BUILDER_CONFIG_NAMES_TO_TEST = ['sentences']
-  SPLITS = {
-      'train': 4
-  }
+  SPLITS = {'train': 4}
 
 
 class SalientSpanWikipediaDocumentsTest(SalientSpanWikipediaSentencesTest):
   BUILDER_CONFIG_NAMES_TO_TEST = ['documents']
-  SPLITS = {
-      'train': 2
-  }
+  SPLITS = {'train': 2}
 
 
 if __name__ == '__main__':
   testing.test_main()
-
