@@ -92,16 +92,14 @@ class YelpPolarityReviews(tfds.core.GeneratorBasedBuilder):
 
   def _split_generators(self, dl_manager):
     arch_path = dl_manager.download_and_extract(_DOWNLOAD_URL)
-    train_file = os.path.join(
-        arch_path, "yelp_review_polarity_csv", "train.csv")
+    train_file = os.path.join(arch_path, "yelp_review_polarity_csv",
+                              "train.csv")
     test_file = os.path.join(arch_path, "yelp_review_polarity_csv", "test.csv")
     return [
         tfds.core.SplitGenerator(
-            name=tfds.Split.TRAIN,
-            gen_kwargs={"filepath": train_file}),
+            name=tfds.Split.TRAIN, gen_kwargs={"filepath": train_file}),
         tfds.core.SplitGenerator(
-            name=tfds.Split.TEST,
-            gen_kwargs={"filepath": test_file}),
+            name=tfds.Split.TEST, gen_kwargs={"filepath": test_file}),
     ]
 
   def _generate_examples(self, filepath):
