@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -47,47 +47,32 @@ TranslateData = collections.namedtuple("TranslateData",
 class FloresConfig(tfds.core.BuilderConfig):
   """BuilderConfig for FLoRes."""
 
-  def __init__(self,
-               *,
-               text_encoder_config=None,
-               language_pair=(None, None),
-               **kwargs):
+  def __init__(self, *, language_pair=(None, None), **kwargs):
     """BuilderConfig for FLoRes.
 
     Args:
-      text_encoder_config: `tfds.deprecated.text.TextEncoderConfig`,
-        configuration for the `tfds.deprecated.text.TextEncoder` used for the
-        features feature.
       language_pair: pair of languages that will be used for translation. Should
         contain 2-letter coded strings. First will be used at source and second
         as target in supervised mode. For example: ("se", "en").
       **kwargs: keyword arguments forwarded to super.
     """
-    encoder_name = (
-        text_encoder_config.name if text_encoder_config else "plain_text")
-    name = "%s%s_%s" % (language_pair[0], language_pair[1], encoder_name)
+    name = f"{language_pair[0]}{language_pair[1]}"
 
     description = (
-        "Translation dataset from %s to %s, uses encoder %s.") % (
-            language_pair[0], language_pair[1], encoder_name)
+        f"Translation dataset from {language_pair[0]} to {language_pair[1]}.")
     super(FloresConfig, self).__init__(
         name=name,
         description=description,
-        version=tfds.core.Version(
-            "1.1.0",
-            "New split API (https://tensorflow.org/datasets/splits)"),
+        version=tfds.core.Version("1.2.0"),
         **kwargs)
-    self.text_encoder_config = (
-        text_encoder_config or tfds.deprecated.text.TextEncoderConfig())
 
     # Validate language pair.
     assert "en" in language_pair, (
-        "Config language pair must contain `en`, got: %s",
-        language_pair)
+        "Config language pair must contain `en`, got: %s", language_pair)
     source, target = language_pair
     non_en = source if target == "en" else target
-    assert non_en in ["ne", "si"], (
-        "Invalid non-en language in pair: %s", non_en)
+    assert non_en in ["ne",
+                      "si"], ("Invalid non-en language in pair: %s", non_en)
 
     self.language_pair = language_pair
 
@@ -96,12 +81,8 @@ class Flores(tfds.core.GeneratorBasedBuilder):
   """FLoRes machine translation dataset."""
 
   BUILDER_CONFIGS = [
-      FloresConfig(
-          language_pair=("ne", "en"),
-      ),
-      FloresConfig(
-          language_pair=("si", "en"),
-      ),
+      FloresConfig(language_pair=("ne", "en"),),
+      FloresConfig(language_pair=("si", "en"),),
   ]
 
   def _info(self):
@@ -110,17 +91,12 @@ class Flores(tfds.core.GeneratorBasedBuilder):
         builder=self,
         description=_DESCRIPTION,
         features=tfds.features.Translation(
-            languages=self.builder_config.language_pair,
-            encoder_config=self.builder_config.text_encoder_config),
+            languages=self.builder_config.language_pair),
         supervised_keys=(source, target),
         homepage="https://github.com/facebookresearch/flores/",
         citation=_CITATION,
     )
 
-  def _vocab_text_gen(self, files, language):
-    for _, ex in self._generate_examples(**files):
-      yield ex[language]
-
   def _split_generators(self, dl_manager):
     dl_dir = dl_manager.download_and_extract(_DATA_URL)
 
@@ -133,24 +109,19 @@ class Flores(tfds.core.GeneratorBasedBuilder):
     files = {}
     for split in ("dev", "devtest"):
       files[split] = {
-          "source_file": path_tmpl.format(
-              dl_dir=dl_dir, split=split, non_en=non_en, lang=source),
-          "target_file": path_tmpl.format(
-              dl_dir=dl_dir, split=split, non_en=non_en, lang=target),
+          "source_file":
+              path_tmpl.format(
+                  dl_dir=dl_dir, split=split, non_en=non_en, lang=source),
+          "target_file":
+              path_tmpl.format(
+                  dl_dir=dl_dir, split=split, non_en=non_en, lang=target),
       }
 
-    # Generate vocabulary from dev data if text encoder configured.
-    for language in self.builder_config.language_pair:
-      self.info.features[source].maybe_build_from_corpus(
-          self._vocab_text_gen(files["dev"], language))
-
     return [
         tfds.core.SplitGenerator(
-            name=tfds.Split.VALIDATION,
-            gen_kwargs=files["dev"]),
+            name=tfds.Split.VALIDATION, gen_kwargs=files["dev"]),
         tfds.core.SplitGenerator(
-            name=tfds.Split.TEST,
-            gen_kwargs=files["devtest"]),
+            name=tfds.Split.TEST, gen_kwargs=files["devtest"]),
     ]
 
   def _generate_examples(self, source_file, target_file):
@@ -161,13 +132,11 @@ class Flores(tfds.core.GeneratorBasedBuilder):
       target_sentences = f.read().split("\n")
 
     assert len(target_sentences) == len(
-        source_sentences), "Sizes do not match: %d vs %d for %s vs %s." % (
-            len(source_sentences), len(target_sentences), source_file,
-            target_file)
+        source_sentences), "Sizes do not match: %d vs %d for %s vs %s." % (len(
+            source_sentences), len(target_sentences), source_file, target_file)
 
     source, target = self.builder_config.language_pair
-    for idx, (l1, l2) in enumerate(
-        zip(source_sentences, target_sentences)):
+    for idx, (l1, l2) in enumerate(zip(source_sentences, target_sentences)):
       result = {source: l1, target: l2}
       # Make sure that both translations are non-empty.
       if all(result.values()):
