@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """WMT14: Translate dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import tensorflow_datasets.public_api as tfds
 from tensorflow_datasets.translate import wmt
 
@@ -38,9 +33,7 @@ _CITATION = """
 }
 """
 
-_LANGUAGE_PAIRS = [
-    (lang, "en") for lang in ["cs", "de", "fr", "hi", "ru"]
-]
+_LANGUAGE_PAIRS = [(lang, "en") for lang in ["cs", "de", "fr", "hi", "ru"]]
 
 
 class Wmt14Translate(wmt.WmtTranslate):
@@ -62,14 +55,10 @@ class Wmt14Translate(wmt.WmtTranslate):
   def _subsets(self):
     return {
         tfds.Split.TRAIN: [
-            "europarl_v7", "commoncrawl", "multiun",
-            "newscommentary_v9", "gigafren", "czeng_10", "yandexcorpus",
-            "wikiheadlines_hi", "wikiheadlines_ru", "hindencorp_01"
+            "europarl_v7", "commoncrawl", "multiun", "newscommentary_v9",
+            "gigafren", "czeng_10", "yandexcorpus", "wikiheadlines_hi",
+            "wikiheadlines_ru", "hindencorp_01"
         ],
-        tfds.Split.VALIDATION: [
-            "newsdev2014", "newstest2013"
-        ],
-        tfds.Split.TEST: [
-            "newstest2014"
-        ]
+        tfds.Split.VALIDATION: ["newsdev2014", "newstest2013"],
+        tfds.Split.TEST: ["newstest2014"]
     }
