@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """WMT16: Translate dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import tensorflow_datasets.public_api as tfds
 from tensorflow_datasets.translate import wmt
 
@@ -64,10 +59,6 @@ class Wmt16Translate(wmt.WmtTranslate):
             "newscommentary_v11", "czeng_16pre", "yandexcorpus",
             "wikiheadlines_fi", "wikiheadlines_ru", "setimes_2"
         ],
-        tfds.Split.VALIDATION: [
-            "newsdev2016", "newstest2015"
-        ],
-        tfds.Split.TEST: [
-            "newstest2016", "newstestB2016"
-        ]
+        tfds.Split.VALIDATION: ["newsdev2016", "newstest2015"],
+        tfds.Split.TEST: ["newstest2016", "newstestB2016"]
     }
