@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """WMT18: Translate dataset."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import tensorflow_datasets.public_api as tfds
 from tensorflow_datasets.translate import wmt
 
@@ -67,12 +62,9 @@ class Wmt18Translate(wmt.WmtTranslate):
         tfds.Split.TRAIN: [
             "europarl_v7", "europarl_v8_18", "paracrawl_v1", "commoncrawl",
             "newscommentary_v13", "czeng_17", "yandexcorpus",
-            "wikiheadlines_fi", "wikiheadlines_ru", "setimes_2",
-            "uncorpus_v1", "rapid_2016"] + wmt.CWMT_SUBSET_NAMES,
-        tfds.Split.VALIDATION: [
-            "newsdev2018", "newstest2017", "newstestB2017"
-        ],
-        tfds.Split.TEST: [
-            "newstest2018"
-        ]
+            "wikiheadlines_fi", "wikiheadlines_ru", "setimes_2", "uncorpus_v1",
+            "rapid_2016"
+        ] + wmt.CWMT_SUBSET_NAMES,
+        tfds.Split.VALIDATION: ["newsdev2018", "newstest2017", "newstestB2017"],
+        tfds.Split.TEST: ["newstest2018"]
     }
