@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """The WMT EnDe Translate dataset used by the Tensor2Tensor library."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import tensorflow_datasets.public_api as tfds
 from tensorflow_datasets.translate import wmt
 
@@ -55,12 +50,7 @@ class WmtT2tTranslate(wmt.WmtTranslate):
   @property
   def _subsets(self):
     return {
-        tfds.Split.TRAIN: [
-            "europarl_v7", "commoncrawl", "newscommentary_v13"],
-        tfds.Split.VALIDATION: [
-            "newstest2013"
-        ],
-        tfds.Split.TEST: [
-            "newstest2014"
-        ]
+        tfds.Split.TRAIN: ["europarl_v7", "commoncrawl", "newscommentary_v13"],
+        tfds.Split.VALIDATION: ["newstest2013"],
+        tfds.Split.TEST: ["newstest2014"]
     }
