@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """Tests for moving_sequence."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import tensorflow.compat.v2 as tf
 
 from tensorflow_datasets import testing
@@ -36,7 +31,7 @@ class MovingSequenceTest(tf.test.TestCase):
     sequence_length = 8
 
     vh = 1 / (sequence_length)
-    vw = 1 / (2*(sequence_length))
+    vw = 1 / (2 * (sequence_length))
     image = tf.ones((28, 28, 1), dtype=tf.uint8)
 
     velocity = tf.constant([vh, vw], dtype=tf.float32)
@@ -44,22 +39,24 @@ class MovingSequenceTest(tf.test.TestCase):
     start_position = tf.constant([0, 0], dtype=tf.float32)
 
     sequence = ms.image_as_moving_sequence(
-        image, start_position=start_position, velocity=velocity,
-        output_size=out_size, sequence_length=sequence_length)
+        image,
+        start_position=start_position,
+        velocity=velocity,
+        output_size=out_size,
+        sequence_length=sequence_length)
     sequence = tf.cast(sequence.image_sequence, tf.float32)
 
     self.assertAllEqual(*self.evaluate([
         tf.reduce_sum(sequence, axis=(1, 2, 3)),
-        tf.fill((sequence_length,),
-                tf.reduce_sum(tf.cast(image, tf.float32)))
+        tf.fill((sequence_length,), tf.reduce_sum(tf.cast(image, tf.float32)))
     ]))
 
     for i, full_image in enumerate(tf.unstack(sequence, axis=0)):
       j = i // 2
-      subimage = full_image[i:i+h, j:j+w]
+      subimage = full_image[i:i + h, j:j + w]
       n_true = tf.reduce_sum(subimage)
       # allow for pixel rounding errors in each dimension
-      self.assertGreaterEqual(self.evaluate(n_true), (h-1)*(w-1))
+      self.assertGreaterEqual(self.evaluate(n_true), (h - 1) * (w - 1))
 
 
 if __name__ == '__main__':
