@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2021 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python3
 """RoboNet dataset.
 
 RoboNet: Large-Scale Multi-Robot Learning
@@ -24,10 +23,6 @@ Karl Schmeckpeper, Siddharth Singh, Sergey Levine, Chelsea Finn
 https://www.robonet.wiki/
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import textwrap
 
@@ -36,7 +31,6 @@ import tensorflow.compat.v2 as tf
 
 import tensorflow_datasets.public_api as tfds
 
-
 DATA_URL_SAMPLE = ('https://drive.google.com/uc?export=download&'
                    'id=1YX2TgT8IKSn9V4wGCwdzbRnS53yicV2P')
 DATA_URL = ('https://drive.google.com/uc?export=download&'
@@ -60,8 +54,12 @@ _CITATION = """\
 class RobonetConfig(tfds.core.BuilderConfig):
   """"Configuration for RoboNet video rescaling."""
 
-  @tfds.core.disallow_positional_args
-  def __init__(self, sample_dataset=False, width=None, height=None, **kwargs):
+  def __init__(self,
+               *,
+               sample_dataset=False,
+               width=None,
+               height=None,
+               **kwargs):
     """The parameters specifying how the dataset will be processed.
 
     The dataset comes with three separate splits. You can specify which split
@@ -75,7 +73,7 @@ class RobonetConfig(tfds.core.BuilderConfig):
       **kwargs: Passed on to the constructor of `BuilderConfig`.
     """
     super(RobonetConfig, self).__init__(
-        version=tfds.core.Version('4.0.0'), **kwargs)
+        version=tfds.core.Version('4.0.1'), **kwargs)
     if (width is None) ^ (height is None):
       raise ValueError('Either both dimensions should be set, or none of them')
     self.sample_dataset = sample_dataset
@@ -121,27 +119,31 @@ class Robonet(tfds.core.BeamBasedBuilder):
     if self.builder_config.width is not None:
       if self.builder_config.height is None:
         raise ValueError('Provide either both height and width or none.')
-      ffmpeg_extra_args = (
-          '-vf', 'scale={}x{}'.format(self.builder_config.height,
-                                      self.builder_config.width))
+      ffmpeg_extra_args = ('-vf',
+                           'scale={}x{}'.format(self.builder_config.height,
+                                                self.builder_config.width))
     else:
       ffmpeg_extra_args = []
 
-    video_shape = (
-        None, self.builder_config.height, self.builder_config.width, 3)
+    video_shape = (None, self.builder_config.height, self.builder_config.width,
+                   3)
 
     features = tfds.features.FeaturesDict({
         # Video frames: uint8 [None, Time, Width, Height, Channels]
-        'video': tfds.features.Video(
-            video_shape,
-            ffmpeg_extra_args=ffmpeg_extra_args,
-            encoding_format='png'),
+        'video':
+            tfds.features.Video(
+                video_shape,
+                ffmpeg_extra_args=ffmpeg_extra_args,
+                encoding_format='png'),
         # Robot actions: float32, [None, ACTIONS_DIM]
-        'actions': tfds.features.Tensor(
-            shape=(None, ACTIONS_DIM), dtype=tf.float32),
+        'actions':
+            tfds.features.Tensor(shape=(None, ACTIONS_DIM), dtype=tf.float32),
         # Robot states: float32, [None, STATE_DIM]
-        'states': tfds.features.Tensor(
-            shape=(None, STATES_DIM), dtype=tf.float32)
+        'states':
+            tfds.features.Tensor(shape=(None, STATES_DIM), dtype=tf.float32),
+        # Filename: Text
+        'filename':
+            tfds.features.Text()
     })
 
     return tfds.core.DatasetInfo(
@@ -182,22 +184,20 @@ class Robonet(tfds.core.BeamBasedBuilder):
       with h5py.File(filename) as hf:
         video_bytes = hf['env']['cam0_video']['frames'][:].tostring()
         states = hf['env']['state'][:].astype(np.float32)
-        states = np.pad(
-            states, ((0, 0), (0, STATES_DIM-states.shape[1])), 'constant')
+        states = np.pad(states, ((0, 0), (0, STATES_DIM - states.shape[1])),
+                        'constant')
         actions = hf['policy']['actions'][:].astype(np.float32)
-        actions = np.pad(
-            actions, ((0, 0), (0, ACTIONS_DIM-actions.shape[1])), 'constant')
+        actions = np.pad(actions, ((0, 0), (0, ACTIONS_DIM - actions.shape[1])),
+                         'constant')
 
+      basename = os.path.basename(filename)
       features = {
           'video': video_bytes,
           'actions': actions,
           'states': states,
+          'filename': basename,
       }
-      return os.path.basename(filename), features
+      return basename, features
 
     filenames = tf.io.gfile.glob(os.path.join(filedir, '*.hdf5'))
-    return (
-        pipeline
-        | beam.Create(filenames)
-        | beam.Map(_process_example)
-    )
+    return pipeline | beam.Create(filenames) | beam.Map(_process_example)
